import { CsvFormatError } from '../formats/csv/CsvFormatError';
import { AbstractFormatError } from './AbstractFormatError';
import { AuthenticationError } from './AuthenticationError';
import { CollectionError } from './CollectionError';
import { EnvironmentMismatchError } from './EnvironmentMismatchError';
import { ExpectError } from './ExpectError';
import { KnowledgeScrapeError } from './KnowledgeScrapeError';
import { LimitReachedError } from './LimitReachedError';
import { MissingToolsError } from './MissingToolsError';
import { NotFoundError } from './NotFoundError';
import { NotYetImplementedError } from './NotYetImplementedError';
import { ParseError } from './ParseError';
import { PipelineExecutionError } from './PipelineExecutionError';
import { PipelineLogicError } from './PipelineLogicError';
import { PipelineUrlError } from './PipelineUrlError';
import { PromptbookFetchError } from './PromptbookFetchError';
import { UnexpectedError } from './UnexpectedError';
import { WrappedError } from './WrappedError';
/**
 * Index of all custom errors
 *
 * @public exported from `@promptbook/core`
 */
export declare const PROMPTBOOK_ERRORS: {
    readonly AbstractFormatError: typeof AbstractFormatError;
    readonly CsvFormatError: typeof CsvFormatError;
    readonly CollectionError: typeof CollectionError;
    readonly EnvironmentMismatchError: typeof EnvironmentMismatchError;
    readonly ExpectError: typeof ExpectError;
    readonly KnowledgeScrapeError: typeof KnowledgeScrapeError;
    readonly LimitReachedError: typeof LimitReachedError;
    readonly MissingToolsError: typeof MissingToolsError;
    readonly NotFoundError: typeof NotFoundError;
    readonly NotYetImplementedError: typeof NotYetImplementedError;
    readonly ParseError: typeof ParseError;
    readonly PipelineExecutionError: typeof PipelineExecutionError;
    readonly PipelineLogicError: typeof PipelineLogicError;
    readonly PipelineUrlError: typeof PipelineUrlError;
    readonly AuthenticationError: typeof AuthenticationError;
    readonly PromptbookFetchError: typeof PromptbookFetchError;
    readonly UnexpectedError: typeof UnexpectedError;
    readonly WrappedError: typeof WrappedError;
};
/**
 * Index of all javascript errors
 *
 * @private for internal usage
 */
export declare const COMMON_JAVASCRIPT_ERRORS: {
    readonly Error: ErrorConstructor;
    readonly EvalError: EvalErrorConstructor;
    readonly RangeError: RangeErrorConstructor;
    readonly ReferenceError: ReferenceErrorConstructor;
    readonly SyntaxError: SyntaxErrorConstructor;
    readonly TypeError: TypeErrorConstructor;
    readonly URIError: URIErrorConstructor;
    readonly AggregateError: AggregateErrorConstructor;
};
/**
 * Index of all errors
 *
 * @private for internal usage
 */
export declare const ALL_ERRORS: {
    readonly Error: ErrorConstructor;
    readonly EvalError: EvalErrorConstructor;
    readonly RangeError: RangeErrorConstructor;
    readonly ReferenceError: ReferenceErrorConstructor;
    readonly SyntaxError: SyntaxErrorConstructor;
    readonly TypeError: TypeErrorConstructor;
    readonly URIError: URIErrorConstructor;
    readonly AggregateError: AggregateErrorConstructor;
    readonly AbstractFormatError: typeof AbstractFormatError;
    readonly CsvFormatError: typeof CsvFormatError;
    readonly CollectionError: typeof CollectionError;
    readonly EnvironmentMismatchError: typeof EnvironmentMismatchError;
    readonly ExpectError: typeof ExpectError;
    readonly KnowledgeScrapeError: typeof KnowledgeScrapeError;
    readonly LimitReachedError: typeof LimitReachedError;
    readonly MissingToolsError: typeof MissingToolsError;
    readonly NotFoundError: typeof NotFoundError;
    readonly NotYetImplementedError: typeof NotYetImplementedError;
    readonly ParseError: typeof ParseError;
    readonly PipelineExecutionError: typeof PipelineExecutionError;
    readonly PipelineLogicError: typeof PipelineLogicError;
    readonly PipelineUrlError: typeof PipelineUrlError;
    readonly AuthenticationError: typeof AuthenticationError;
    readonly PromptbookFetchError: typeof PromptbookFetchError;
    readonly UnexpectedError: typeof UnexpectedError;
    readonly WrappedError: typeof WrappedError;
};
/**
 * Note: [💞] Ignore a discrepancy between file name and entity name
 */
