(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('spacetrim'), require('prettier'), require('prettier/parser-html'), require('crypto'), require('rxjs'), require('waitasecond'), require('crypto-js/enc-hex'), require('crypto-js/sha256'), require('path'), require('crypto-js'), require('mime-types'), require('papaparse')) :
    typeof define === 'function' && define.amd ? define(['exports', 'spacetrim', 'prettier', 'prettier/parser-html', 'crypto', 'rxjs', 'waitasecond', 'crypto-js/enc-hex', 'crypto-js/sha256', 'path', 'crypto-js', 'mime-types', 'papaparse'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["promptbook-markdown-utils"] = {}, global.spaceTrim, global.prettier, global.parserHtml, global.crypto, global.rxjs, global.waitasecond, global.hexEncoder, global.sha256, global.path, global.cryptoJs, global.mimeTypes, global.papaparse));
})(this, (function (exports, spaceTrim, prettier, parserHtml, crypto, rxjs, waitasecond, hexEncoder, sha256, path, cryptoJs, mimeTypes, papaparse) { 'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var spaceTrim__default = /*#__PURE__*/_interopDefaultLegacy(spaceTrim);
    var parserHtml__default = /*#__PURE__*/_interopDefaultLegacy(parserHtml);
    var hexEncoder__default = /*#__PURE__*/_interopDefaultLegacy(hexEncoder);
    var sha256__default = /*#__PURE__*/_interopDefaultLegacy(sha256);

    // ⚠️ WARNING: This code has been generated so that any manual changes will be overwritten
    /**
     * The version of the Book language
     *
     * @generated
     * @see https://github.com/webgptorg/book
     */
    const BOOK_LANGUAGE_VERSION = '1.0.0';
    /**
     * The version of the Promptbook engine
     *
     * @generated
     * @see https://github.com/webgptorg/promptbook
     */
    const PROMPTBOOK_ENGINE_VERSION = '0.89.0-33';
    /**
     * TODO: string_promptbook_version should be constrained to the all versions of Promptbook engine
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * This error indicates that the promptbook in a markdown format cannot be parsed into a valid promptbook object
     *
     * @public exported from `@promptbook/core`
     */
    class ParseError extends Error {
        constructor(message) {
            super(message);
            this.name = 'ParseError';
            Object.setPrototypeOf(this, ParseError.prototype);
        }
    }
    /**
     * TODO: Maybe split `ParseError` and `ApplyError`
     */

    /**
     * Makes first letter of a string uppercase
     *
     * @public exported from `@promptbook/utils`
     */
    function capitalize(word) {
        return word.substring(0, 1).toUpperCase() + word.substring(1);
    }

    /**
     * Extracts all code blocks from markdown.
     *
     * Note: There are multiple simmilar function:
     * - `extractBlock` just extracts the content of the code block which is also used as build-in function for postprocessing
     * - `extractJsonBlock` extracts exactly one valid JSON code block
     * - `extractOneBlockFromMarkdown` extracts exactly one code block with language of the code block
     * - `extractAllBlocksFromMarkdown` extracts all code blocks with language of the code block
     *
     * @param markdown any valid markdown
     * @returns code blocks with language and content
     * @throws {ParseError} if block is not closed properly
     * @public exported from `@promptbook/markdown-utils`
     */
    function extractAllBlocksFromMarkdown(markdown) {
        const codeBlocks = [];
        const lines = markdown.split('\n');
        // Note: [0] Ensure that the last block notated by gt > will be closed
        lines.push('');
        let currentCodeBlock = null;
        for (const line of lines) {
            if (line.startsWith('> ') || line === '>') {
                if (currentCodeBlock === null) {
                    currentCodeBlock = { blockNotation: '>', language: null, content: '' };
                } /* not else */
                if (currentCodeBlock.blockNotation === '>') {
                    if (currentCodeBlock.content !== '') {
                        currentCodeBlock.content += '\n';
                    }
                    currentCodeBlock.content += line.slice(2);
                }
            }
            else if (currentCodeBlock !== null && currentCodeBlock.blockNotation === '>' /* <- Note: [0] */) {
                codeBlocks.push(currentCodeBlock);
                currentCodeBlock = null;
            }
            /* not else */
            if (line.startsWith('```')) {
                const language = line.slice(3).trim() || null;
                if (currentCodeBlock === null) {
                    currentCodeBlock = { blockNotation: '```', language, content: '' };
                }
                else {
                    if (language !== null) {
                        throw new ParseError(`${capitalize(currentCodeBlock.language || 'the')} code block was not closed and already opening new ${language} code block`);
                    }
                    codeBlocks.push(currentCodeBlock);
                    currentCodeBlock = null;
                }
            }
            else if (currentCodeBlock !== null && currentCodeBlock.blockNotation === '```') {
                if (currentCodeBlock.content !== '') {
                    currentCodeBlock.content += '\n';
                }
                currentCodeBlock.content += line.split('\\`\\`\\`').join('```') /* <- TODO: Maybe make propper unescape */;
            }
        }
        if (currentCodeBlock !== null) {
            throw new ParseError(`${capitalize(currentCodeBlock.language || 'the')} code block was not closed at the end of the markdown`);
        }
        return codeBlocks;
    }
    /**
     * TODO: Maybe name for `blockNotation` instead of  '```' and '>'
     */

    /**
     * Extracts exactly ONE code block from markdown.
     *
     * - When there are multiple or no code blocks the function throws a `ParseError`
     *
     * Note: There are multiple simmilar function:
     * - `extractBlock` just extracts the content of the code block which is also used as build-in function for postprocessing
     * - `extractJsonBlock` extracts exactly one valid JSON code block
     * - `extractOneBlockFromMarkdown` extracts exactly one code block with language of the code block
     * - `extractAllBlocksFromMarkdown` extracts all code blocks with language of the code block
     *
     * @param markdown any valid markdown
     * @returns code block with language and content
     * @public exported from `@promptbook/markdown-utils`
     * @throws {ParseError} if there is not exactly one code block in the markdown
     */
    function extractOneBlockFromMarkdown(markdown) {
        const codeBlocks = extractAllBlocksFromMarkdown(markdown);
        if (codeBlocks.length !== 1) {
            throw new ParseError(spaceTrim__default["default"]((block) => `
                    There should be exactly 1 code block in task section, found ${codeBlocks.length} code blocks

                    ${block(codeBlocks.map((block, i) => `Block ${i + 1}:\n${block.content}`).join('\n\n\n'))}
                `));
        }
        return codeBlocks[0];
    }
    /***
     * TODO: [🍓][🌻] Decide of this is internal utility, external util OR validator/postprocessor
     */

    /**
     * Extracts code block from markdown.
     *
     * - When there are multiple or no code blocks the function throws a `ParseError`
     *
     * Note: There are multiple simmilar function:
     * - `extractBlock` just extracts the content of the code block which is also used as build-in function for postprocessing
     * - `extractJsonBlock` extracts exactly one valid JSON code block
     * - `extractOneBlockFromMarkdown` extracts exactly one code block with language of the code block
     * - `extractAllBlocksFromMarkdown` extracts all code blocks with language of the code block
     *
     * @public exported from `@promptbook/markdown-utils`
     * @throws {ParseError} if there is not exactly one code block in the markdown
     */
    function extractBlock(markdown) {
        const { content } = extractOneBlockFromMarkdown(markdown);
        return content;
    }

    /**
     * Returns the same value that is passed as argument.
     * No side effects.
     *
     * Note: It can be usefull for:
     *
     * 1) Leveling indentation
     * 2) Putting always-true or always-false conditions without getting eslint errors
     *
     * @param value any values
     * @returns the same values
     * @private within the repository
     */
    function just(value) {
        if (value === undefined) {
            return undefined;
        }
        return value;
    }

    /**
     * Warning message for the generated sections and files files
     *
     * @private within the repository
     */
    const GENERATOR_WARNING = `⚠️ WARNING: This code has been generated so that any manual changes will be overwritten`;
    /**
     * Name for the Promptbook
     *
     * TODO: [🗽] Unite branding and make single place for it
     *
     * @public exported from `@promptbook/core`
     */
    const NAME = `Promptbook`;
    /**
     * Email of the responsible person
     *
     * @public exported from `@promptbook/core`
     */
    const ADMIN_EMAIL = 'pavol@ptbk.io';
    /**
     * Name of the responsible person for the Promptbook on GitHub
     *
     * @public exported from `@promptbook/core`
     */
    const ADMIN_GITHUB_NAME = 'hejny';
    //            <- TODO: [🐊] Pick the best claim
    /**
     * When the title is not provided, the default title is used
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_BOOK_TITLE = `✨ Untitled Book`;
    /**
     * Maximum file size limit
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_MAX_FILE_SIZE = 100 * 1024 * 1024; // 100MB
    // <- TODO: [🧠] Better system for generator warnings - not always "code" and "by `@promptbook/cli`"
    /**
     * The maximum number of iterations for a loops
     *
     * @private within the repository - too low-level in comparison with other `MAX_...`
     */
    const LOOP_LIMIT = 1000;
    /**
     * Strings to represent various values in the context of parameter values
     *
     * @public exported from `@promptbook/utils`
     */
    const VALUE_STRINGS = {
        empty: '(nothing; empty string)',
        null: '(no value; null)',
        undefined: '(unknown value; undefined)',
        nan: '(not a number; NaN)',
        infinity: '(infinity; ∞)',
        negativeInfinity: '(negative infinity; -∞)',
        unserializable: '(unserializable value)',
        circular: '(circular JSON)',
    };
    /**
     * Small number limit
     *
     * @public exported from `@promptbook/utils`
     */
    const SMALL_NUMBER = 0.001;
    /**
     * Short time interval to prevent race conditions in milliseconds
     *
     * @private within the repository - too low-level in comparison with other `MAX_...`
     */
    const IMMEDIATE_TIME = 10;
    /**
     * The maximum length of the (generated) filename
     *
     * @public exported from `@promptbook/core`
     */
    const MAX_FILENAME_LENGTH = 30;
    /**
     * Strategy for caching the intermediate results for knowledge sources
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_INTERMEDIATE_FILES_STRATEGY = 'HIDE_AND_KEEP';
    //                                                     <- TODO: [😡] Change to 'VISIBLE'
    /**
     * The maximum number of (LLM) tasks running in parallel
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_MAX_PARALLEL_COUNT = 5; // <- TODO: [🤹‍♂️]
    /**
     * The maximum number of attempts to execute LLM task before giving up
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_MAX_EXECUTION_ATTEMPTS = 10; // <- TODO: [🤹‍♂️]
    // <- TODO: [🕝] Make also `BOOKS_DIRNAME_ALTERNATIVES`
    // TODO: Just `.promptbook` in config, hardcode subfolders like `download-cache` or `execution-cache`
    /**
     * Where to store the temporary downloads
     *
     * Note: When the folder does not exist, it is created recursively
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_DOWNLOAD_CACHE_DIRNAME = './.promptbook/download-cache';
    /**
     * Where to store the scrape cache
     *
     * Note: When the folder does not exist, it is created recursively
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_SCRAPE_CACHE_DIRNAME = './.promptbook/scrape-cache';
    // <- TODO: [🧜‍♂️]
    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_CSV_SETTINGS = Object.freeze({
        delimiter: ',',
        quoteChar: '"',
        newline: '\n',
        skipEmptyLines: true,
    });
    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    let DEFAULT_IS_VERBOSE = false;
    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    const DEFAULT_IS_AUTO_INSTALLED = false;
    /**
     * @@@
     *
     * @private within the repository
     */
    const IS_PIPELINE_LOGIC_VALIDATED = just(
    /**/
    // Note: In normal situations, we check the pipeline logic:
    true);
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     * TODO: [🧠][🧜‍♂️] Maybe join remoteServerUrl and path into single value
     */

    /**
     * Make error report URL for the given error
     *
     * @private private within the repository
     */
    function getErrorReportUrl(error) {
        const report = {
            title: `🐜 Error report from ${NAME}`,
            body: spaceTrim__default["default"]((block) => `


            \`${error.name || 'Error'}\` has occurred in the [${NAME}], please look into it @${ADMIN_GITHUB_NAME}.

            \`\`\`
            ${block(error.message || '(no error message)')}
            \`\`\`


            ## More info:

            - **Promptbook engine version:** ${PROMPTBOOK_ENGINE_VERSION}
            - **Book language version:** ${BOOK_LANGUAGE_VERSION}
            - **Time:** ${new Date().toISOString()}

            <details>
            <summary>Stack trace:</summary>

            ## Stack trace:

            \`\`\`stacktrace
            ${block(error.stack || '(empty)')}
            \`\`\`
            </details>

        `),
        };
        const reportUrl = new URL(`https://github.com/webgptorg/promptbook/issues/new`);
        reportUrl.searchParams.set('labels', 'bug');
        reportUrl.searchParams.set('assignees', ADMIN_GITHUB_NAME);
        reportUrl.searchParams.set('title', report.title);
        reportUrl.searchParams.set('body', report.body);
        return reportUrl;
    }

    /**
     * This error type indicates that the error should not happen and its last check before crashing with some other error
     *
     * @public exported from `@promptbook/core`
     */
    class UnexpectedError extends Error {
        constructor(message) {
            super(spaceTrim.spaceTrim((block) => `
                    ${block(message)}

                    Note: This error should not happen.
                    It's probbably a bug in the pipeline collection

                    Please report issue:
                    ${block(getErrorReportUrl(new Error(message)).href)}

                    Or contact us on ${ADMIN_EMAIL}

                `));
            this.name = 'UnexpectedError';
            Object.setPrototypeOf(this, UnexpectedError.prototype);
        }
    }

    /**
     * This error type indicates that somewhere in the code non-Error object was thrown and it was wrapped into the `WrappedError`
     *
     * @public exported from `@promptbook/core`
     */
    class WrappedError extends Error {
        constructor(whatWasThrown) {
            const tag = `[🤮]`;
            console.error(tag, whatWasThrown);
            super(spaceTrim.spaceTrim(`
                Non-Error object was thrown

                Note: Look for ${tag} in the console for more details
                Please report issue on ${ADMIN_EMAIL}
            `));
            this.name = 'WrappedError';
            Object.setPrototypeOf(this, WrappedError.prototype);
        }
    }

    /**
     * Helper used in catch blocks to assert that the error is an instance of `Error`
     *
     * @param whatWasThrown Any object that was thrown
     * @returns Nothing if the error is an instance of `Error`
     * @throws `WrappedError` or `UnexpectedError` if the error is not standard
     *
     * @private within the repository
     */
    function assertsError(whatWasThrown) {
        // Case 1: Handle error which was rethrown as `WrappedError`
        if (whatWasThrown instanceof WrappedError) {
            const wrappedError = whatWasThrown;
            throw wrappedError;
        }
        // Case 2: Handle unexpected errors
        if (whatWasThrown instanceof UnexpectedError) {
            const unexpectedError = whatWasThrown;
            throw unexpectedError;
        }
        // Case 3: Handle standard errors - keep them up to consumer
        if (whatWasThrown instanceof Error) {
            return;
        }
        // Case 4: Handle non-standard errors - wrap them into `WrappedError` and throw
        throw new WrappedError(whatWasThrown);
    }

    /**
     * Function isValidJsonString will tell you if the string is valid JSON or not
     *
     * @param value The string to check
     * @returns True if the string is a valid JSON string, false otherwise
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidJsonString(value /* <- [👨‍⚖️] */) {
        try {
            JSON.parse(value);
            return true;
        }
        catch (error) {
            assertsError(error);
            if (error.message.includes('Unexpected token')) {
                return false;
            }
            return false;
        }
    }

    /**
     * Extracts  extracts exactly one valid JSON code block
     *
     * - When given string is a valid JSON as it is, it just returns it
     * - When there is no JSON code block the function throws a `ParseError`
     * - When there are multiple JSON code blocks the function throws a `ParseError`
     *
     * Note: It is not important if marked as ```json BUT if it is VALID JSON
     * Note: There are multiple simmilar function:
     * - `extractBlock` just extracts the content of the code block which is also used as build-in function for postprocessing
     * - `extractJsonBlock` extracts exactly one valid JSON code block
     * - `extractOneBlockFromMarkdown` extracts exactly one code block with language of the code block
     * - `extractAllBlocksFromMarkdown` extracts all code blocks with language of the code block
     *
     * @public exported from `@promptbook/markdown-utils`
     * @throws {ParseError} if there is no valid JSON block in the markdown
     */
    function extractJsonBlock(markdown) {
        if (isValidJsonString(markdown)) {
            return markdown;
        }
        const codeBlocks = extractAllBlocksFromMarkdown(markdown);
        const jsonBlocks = codeBlocks.filter(({ content }) => isValidJsonString(content));
        if (jsonBlocks.length === 0) {
            throw new Error('There is no valid JSON block in the markdown');
        }
        if (jsonBlocks.length > 1) {
            throw new Error('There are multiple JSON code blocks in the markdown');
        }
        return jsonBlocks[0].content;
    }
    /**
     * TODO: Add some auto-healing logic + extract YAML, JSON5, TOML, etc.
     * TODO: [🏢] Make this logic part of `JsonFormatDefinition` or `isValidJsonString`
     */

    /**
     * Just says that the variable is not used but should be kept
     * No side effects.
     *
     * Note: It can be usefull for:
     *
     * 1) Suppressing eager optimization of unused imports
     * 2) Suppressing eslint errors of unused variables in the tests
     * 3) Keeping the type of the variable for type testing
     *
     * @param value any values
     * @returns void
     * @private within the repository
     */
    function keepUnused(...valuesToKeep) {
    }

    var PipelineCollection = [{title:"Prepare Knowledge from Markdown",pipelineUrl:"https://promptbook.studio/promptbook/prepare-knowledge-from-markdown.book",formfactorName:"GENERIC",parameters:[{name:"knowledgeContent",description:"Markdown document content",isInput:true,isOutput:false},{name:"knowledgePieces",description:"The knowledge JSON object",isInput:false,isOutput:true}],tasks:[{taskType:"PROMPT_TASK",name:"knowledge",title:"Knowledge",content:"You are experienced data researcher, extract the important knowledge from the document.\n\n# Rules\n\n-   Make pieces of information concise, clear, and easy to understand\n-   One piece of information should be approximately 1 paragraph\n-   Divide the paragraphs by markdown horizontal lines ---\n-   Omit irrelevant information\n-   Group redundant information\n-   Write just extracted information, nothing else\n\n# The document\n\nTake information from this document:\n\n> {knowledgeContent}",resultingParameterName:"knowledgePieces",dependentParameterNames:["knowledgeContent"]}],personas:[],preparations:[],knowledgeSources:[],knowledgePieces:[],sources:[{type:"BOOK",path:null,content:"# Prepare Knowledge from Markdown\n\n-   PIPELINE URL `https://promptbook.studio/promptbook/prepare-knowledge-from-markdown.book`\n-   INPUT PARAMETER `{knowledgeContent}` Markdown document content\n-   OUTPUT PARAMETER `{knowledgePieces}` The knowledge JSON object\n\n## Knowledge\n\n<!-- TODO: [🍆] -FORMAT JSON -->\n\n```markdown\nYou are experienced data researcher, extract the important knowledge from the document.\n\n# Rules\n\n-   Make pieces of information concise, clear, and easy to understand\n-   One piece of information should be approximately 1 paragraph\n-   Divide the paragraphs by markdown horizontal lines ---\n-   Omit irrelevant information\n-   Group redundant information\n-   Write just extracted information, nothing else\n\n# The document\n\nTake information from this document:\n\n> {knowledgeContent}\n```\n\n`-> {knowledgePieces}`\n"}],sourceFile:"./books/prepare-knowledge-from-markdown.book"},{title:"Prepare Keywords",pipelineUrl:"https://promptbook.studio/promptbook/prepare-knowledge-keywords.book",formfactorName:"GENERIC",parameters:[{name:"knowledgePieceContent",description:"The content",isInput:true,isOutput:false},{name:"keywords",description:"Keywords separated by comma",isInput:false,isOutput:true}],tasks:[{taskType:"PROMPT_TASK",name:"knowledge",title:"Knowledge",content:"You are experienced data researcher, detect the important keywords in the document.\n\n# Rules\n\n-   Write just keywords separated by comma\n\n# The document\n\nTake information from this document:\n\n> {knowledgePieceContent}",resultingParameterName:"keywords",dependentParameterNames:["knowledgePieceContent"]}],personas:[],preparations:[],knowledgeSources:[],knowledgePieces:[],sources:[{type:"BOOK",path:null,content:"# Prepare Keywords\n\n-   PIPELINE URL `https://promptbook.studio/promptbook/prepare-knowledge-keywords.book`\n-   INPUT PARAMETER `{knowledgePieceContent}` The content\n-   OUTPUT PARAMETER `{keywords}` Keywords separated by comma\n\n## Knowledge\n\n<!-- TODO: [🍆] -FORMAT JSON -->\n\n```markdown\nYou are experienced data researcher, detect the important keywords in the document.\n\n# Rules\n\n-   Write just keywords separated by comma\n\n# The document\n\nTake information from this document:\n\n> {knowledgePieceContent}\n```\n\n`-> {keywords}`\n"}],sourceFile:"./books/prepare-knowledge-keywords.book"},{title:"Prepare Knowledge-piece Title",pipelineUrl:"https://promptbook.studio/promptbook/prepare-knowledge-title.book",formfactorName:"GENERIC",parameters:[{name:"knowledgePieceContent",description:"The content",isInput:true,isOutput:false},{name:"title",description:"The title of the document",isInput:false,isOutput:true}],tasks:[{taskType:"PROMPT_TASK",name:"knowledge",title:"Knowledge",content:"You are experienced content creator, write best title for the document.\n\n# Rules\n\n-   Write just title, nothing else\n-   Write maximum 5 words for the title\n\n# The document\n\n> {knowledgePieceContent}",resultingParameterName:"title",expectations:{words:{min:1,max:8}},dependentParameterNames:["knowledgePieceContent"]}],personas:[],preparations:[],knowledgeSources:[],knowledgePieces:[],sources:[{type:"BOOK",path:null,content:"# Prepare Knowledge-piece Title\n\n-   PIPELINE URL `https://promptbook.studio/promptbook/prepare-knowledge-title.book`\n-   INPUT PARAMETER `{knowledgePieceContent}` The content\n-   OUTPUT PARAMETER `{title}` The title of the document\n\n## Knowledge\n\n-   EXPECT MIN 1 WORD\n-   EXPECT MAX 8 WORDS\n\n```markdown\nYou are experienced content creator, write best title for the document.\n\n# Rules\n\n-   Write just title, nothing else\n-   Write maximum 5 words for the title\n\n# The document\n\n> {knowledgePieceContent}\n```\n\n`-> {title}`\n"}],sourceFile:"./books/prepare-knowledge-title.book"},{title:"Prepare Persona",pipelineUrl:"https://promptbook.studio/promptbook/prepare-persona.book",formfactorName:"GENERIC",parameters:[{name:"availableModelNames",description:"List of available model names separated by comma (,)",isInput:true,isOutput:false},{name:"personaDescription",description:"Description of the persona",isInput:true,isOutput:false},{name:"modelRequirements",description:"Specific requirements for the model",isInput:false,isOutput:true}],tasks:[{taskType:"PROMPT_TASK",name:"make-model-requirements",title:"Make modelRequirements",content:"You are experienced AI engineer, you need to create virtual assistant.\nWrite\n\n## Example\n\n```json\n{\n\"modelName\": \"gpt-4o\",\n\"systemMessage\": \"You are experienced AI engineer and helpfull assistant.\",\n\"temperature\": 0.7\n}\n```\n\n## Instructions\n\n-   Your output format is JSON object\n-   Write just the JSON object, no other text should be present\n-   It contains the following keys:\n    -   `modelName`: The name of the model to use\n    -   `systemMessage`: The system message to provide context to the model\n    -   `temperature`: The sampling temperature to use\n\n### Key `modelName`\n\nPick from the following models:\n\n-   {availableModelNames}\n\n### Key `systemMessage`\n\nThe system message is used to communicate instructions or provide context to the model at the beginning of a conversation. It is displayed in a different format compared to user messages, helping the model understand its role in the conversation. The system message typically guides the model's behavior, sets the tone, or specifies desired output from the model. By utilizing the system message effectively, users can steer the model towards generating more accurate and relevant responses.\n\nFor example:\n\n> You are an experienced AI engineer and helpful assistant.\n\n> You are a friendly and knowledgeable chatbot.\n\n### Key `temperature`\n\nThe sampling temperature, between 0 and 1. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. If set to 0, the model will use log probability to automatically increase the temperature until certain thresholds are hit.\n\nYou can pick a value between 0 and 2. For example:\n\n-   `0.1`: Low temperature, extremely conservative and deterministic\n-   `0.5`: Medium temperature, balanced between conservative and creative\n-   `1.0`: High temperature, creative and bit random\n-   `1.5`: Very high temperature, extremely creative and often chaotic and unpredictable\n-   `2.0`: Maximum temperature, completely random and unpredictable, for some extreme creative use cases\n\n# The assistant\n\nTake this description of the persona:\n\n> {personaDescription}",resultingParameterName:"modelRequirements",format:"JSON",dependentParameterNames:["availableModelNames","personaDescription"]}],personas:[],preparations:[],knowledgeSources:[],knowledgePieces:[],sources:[{type:"BOOK",path:null,content:"# Prepare Persona\n\n-   PIPELINE URL `https://promptbook.studio/promptbook/prepare-persona.book`\n-   INPUT PARAMETER `{availableModelNames}` List of available model names separated by comma (,)\n-   INPUT PARAMETER `{personaDescription}` Description of the persona\n-   OUTPUT PARAMETER `{modelRequirements}` Specific requirements for the model\n\n## Make modelRequirements\n\n-   FORMAT JSON\n\n```markdown\nYou are experienced AI engineer, you need to create virtual assistant.\nWrite\n\n## Example\n\n\\`\\`\\`json\n{\n\"modelName\": \"gpt-4o\",\n\"systemMessage\": \"You are experienced AI engineer and helpfull assistant.\",\n\"temperature\": 0.7\n}\n\\`\\`\\`\n\n## Instructions\n\n-   Your output format is JSON object\n-   Write just the JSON object, no other text should be present\n-   It contains the following keys:\n    -   `modelName`: The name of the model to use\n    -   `systemMessage`: The system message to provide context to the model\n    -   `temperature`: The sampling temperature to use\n\n### Key `modelName`\n\nPick from the following models:\n\n-   {availableModelNames}\n\n### Key `systemMessage`\n\nThe system message is used to communicate instructions or provide context to the model at the beginning of a conversation. It is displayed in a different format compared to user messages, helping the model understand its role in the conversation. The system message typically guides the model's behavior, sets the tone, or specifies desired output from the model. By utilizing the system message effectively, users can steer the model towards generating more accurate and relevant responses.\n\nFor example:\n\n> You are an experienced AI engineer and helpful assistant.\n\n> You are a friendly and knowledgeable chatbot.\n\n### Key `temperature`\n\nThe sampling temperature, between 0 and 1. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. If set to 0, the model will use log probability to automatically increase the temperature until certain thresholds are hit.\n\nYou can pick a value between 0 and 2. For example:\n\n-   `0.1`: Low temperature, extremely conservative and deterministic\n-   `0.5`: Medium temperature, balanced between conservative and creative\n-   `1.0`: High temperature, creative and bit random\n-   `1.5`: Very high temperature, extremely creative and often chaotic and unpredictable\n-   `2.0`: Maximum temperature, completely random and unpredictable, for some extreme creative use cases\n\n# The assistant\n\nTake this description of the persona:\n\n> {personaDescription}\n```\n\n`-> {modelRequirements}`\n"}],sourceFile:"./books/prepare-persona.book"},{title:"Prepare Title",pipelineUrl:"https://promptbook.studio/promptbook/prepare-title.book",formfactorName:"GENERIC",parameters:[{name:"book",description:"The book to prepare the title for",isInput:true,isOutput:false},{name:"title",description:"Best title for the book",isInput:false,isOutput:true}],tasks:[{taskType:"PROMPT_TASK",name:"make-title",title:"Make title",content:"Make best title for given text which describes the workflow:\n\n## Rules\n\n-   Write just title, nothing else\n-   Title should be concise and clear - Write maximum ideally 2 words, maximum 5 words\n-   Title starts with emoticon\n-   Title should not mention the input and output of the workflow but the main purpose of the workflow\n    _For example, not \"✍ Convert Knowledge-piece to title\" but \"✍ Title\"_\n\n## The workflow\n\n> {book}",resultingParameterName:"title",expectations:{words:{min:1,max:8},lines:{min:1,max:1}},dependentParameterNames:["book"]}],personas:[],preparations:[],knowledgeSources:[],knowledgePieces:[],sources:[{type:"BOOK",path:null,content:"# Prepare Title\n\n-   PIPELINE URL `https://promptbook.studio/promptbook/prepare-title.book`\n-   INPUT PARAMETER `{book}` The book to prepare the title for\n-   OUTPUT PARAMETER `{title}` Best title for the book\n\n## Make title\n\n-   EXPECT MIN 1 Word\n-   EXPECT MAX 8 Words\n-   EXPECT EXACTLY 1 Line\n\n```markdown\nMake best title for given text which describes the workflow:\n\n## Rules\n\n-   Write just title, nothing else\n-   Title should be concise and clear - Write maximum ideally 2 words, maximum 5 words\n-   Title starts with emoticon\n-   Title should not mention the input and output of the workflow but the main purpose of the workflow\n    _For example, not \"✍ Convert Knowledge-piece to title\" but \"✍ Title\"_\n\n## The workflow\n\n> {book}\n```\n\n`-> {title}`\n"}],sourceFile:"./books/prepare-title.book"}];

    /**
     * Checks if value is valid email
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidEmail(email) {
        if (typeof email !== 'string') {
            return false;
        }
        if (email.split('\n').length > 1) {
            return false;
        }
        return /^.+@.+\..+$/.test(email);
    }

    /**
     * Tests if given string is valid URL.
     *
     * Note: This does not check if the file exists only if the path is valid
     * @public exported from `@promptbook/utils`
     */
    function isValidFilePath(filename) {
        if (typeof filename !== 'string') {
            return false;
        }
        if (filename.split('\n').length > 1) {
            return false;
        }
        if (filename.split(' ').length >
            5 /* <- TODO: [🧠][🈷] Make some better non-arbitrary way how to distinct filenames from informational texts */) {
            return false;
        }
        const filenameSlashes = filename.split('\\').join('/');
        // Absolute Unix path: /hello.txt
        if (/^(\/)/i.test(filenameSlashes)) {
            // console.log(filename, 'Absolute Unix path: /hello.txt');
            return true;
        }
        // Absolute Windows path: /hello.txt
        if (/^([A-Z]{1,2}:\/?)\//i.test(filenameSlashes)) {
            // console.log(filename, 'Absolute Windows path: /hello.txt');
            return true;
        }
        // Relative path: ./hello.txt
        if (/^(\.\.?\/)+/i.test(filenameSlashes)) {
            // console.log(filename, 'Relative path: ./hello.txt');
            return true;
        }
        // Allow paths like foo/hello
        if (/^[^/]+\/[^/]+/i.test(filenameSlashes)) {
            // console.log(filename, 'Allow paths like foo/hello');
            return true;
        }
        // Allow paths like hello.book
        if (/^[^/]+\.[^/]+$/i.test(filenameSlashes)) {
            // console.log(filename, 'Allow paths like hello.book');
            return true;
        }
        return false;
    }
    /**
     * TODO: [🍏] Implement for MacOs
     */

    /**
     * Tests if given string is valid URL.
     *
     * Note: Dataurl are considered perfectly valid.
     * Note: There are two simmilar functions:
     * - `isValidUrl` which tests any URL
     * - `isValidPipelineUrl` *(this one)* which tests just promptbook URL
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidUrl(url) {
        if (typeof url !== 'string') {
            return false;
        }
        try {
            if (url.startsWith('blob:')) {
                url = url.replace(/^blob:/, '');
            }
            const urlObject = new URL(url /* because fail is handled */);
            if (!['http:', 'https:', 'data:'].includes(urlObject.protocol)) {
                return false;
            }
            return true;
        }
        catch (error) {
            return false;
        }
    }

    /**
     * Function `validatePipelineString` will validate the if the string is a valid pipeline string
     * It does not check if the string is fully logically correct, but if it is a string that can be a pipeline string or the string looks completely different.
     *
     * @param {string} pipelineString the candidate for a pipeline string
     * @returns {PipelineString} the same string as input, but validated as valid
     * @throws {ParseError} if the string is not a valid pipeline string
     * @public exported from `@promptbook/core`
     */
    function validatePipelineString(pipelineString) {
        if (isValidJsonString(pipelineString)) {
            throw new ParseError('Expected a book, but got a JSON string');
        }
        else if (isValidUrl(pipelineString)) {
            throw new ParseError(`Expected a book, but got just the URL "${pipelineString}"`);
        }
        else if (isValidFilePath(pipelineString)) {
            throw new ParseError(`Expected a book, but got just the file path "${pipelineString}"`);
        }
        else if (isValidEmail(pipelineString)) {
            throw new ParseError(`Expected a book, but got just the email "${pipelineString}"`);
        }
        // <- TODO: Implement the validation + add tests when the pipeline logic considered as invalid
        return pipelineString;
    }
    /**
     * TODO: [🧠][🈴] Where is the best location for this file
     */

    /**
     * Prettify the html code
     *
     * @param content raw html code
     * @returns formatted html code
     * @private withing the package because of HUGE size of prettier dependency
     */
    function prettifyMarkdown(content) {
        try {
            return prettier.format(content, {
                parser: 'markdown',
                plugins: [parserHtml__default["default"]],
                // TODO: DRY - make some import or auto-copy of .prettierrc
                endOfLine: 'lf',
                tabWidth: 4,
                singleQuote: true,
                trailingComma: 'all',
                arrowParens: 'always',
                printWidth: 120,
                htmlWhitespaceSensitivity: 'ignore',
                jsxBracketSameLine: false,
                bracketSpacing: true,
            });
        }
        catch (error) {
            // TODO: [🟥] Detect browser / node and make it colorfull
            console.error('There was an error with prettifying the markdown, using the original as the fallback', {
                error,
                html: content,
            });
            return content;
        }
    }

    /**
     * Converts promptbook in JSON format to string format
     *
     * @deprecated TODO: [🥍][🧠] Backup original files in `PipelineJson` same as in Promptbook.studio
     * @param pipelineJson Promptbook in JSON format (.bookc)
     * @returns Promptbook in string format (.book.md)
     * @public exported from `@promptbook/core`
     */
    function pipelineJsonToString(pipelineJson) {
        const { title, pipelineUrl, bookVersion, description, parameters, tasks } = pipelineJson;
        let pipelineString = `# ${title}`;
        if (description) {
            pipelineString += '\n\n';
            pipelineString += description;
        }
        const commands = [];
        if (pipelineUrl) {
            commands.push(`PIPELINE URL ${pipelineUrl}`);
        }
        if (bookVersion !== `undefined`) {
            commands.push(`BOOK VERSION ${bookVersion}`);
        }
        // TODO: [main] !!5 This increases size of the bundle and is probbably not necessary
        pipelineString = prettifyMarkdown(pipelineString);
        for (const parameter of parameters.filter(({ isInput }) => isInput)) {
            commands.push(`INPUT PARAMETER ${taskParameterJsonToString(parameter)}`);
        }
        for (const parameter of parameters.filter(({ isOutput }) => isOutput)) {
            commands.push(`OUTPUT PARAMETER ${taskParameterJsonToString(parameter)}`);
        }
        pipelineString += '\n\n';
        pipelineString += commands.map((command) => `- ${command}`).join('\n');
        for (const task of tasks) {
            const { 
            /* Note: Not using:> name, */
            title, description, 
            /* Note: dependentParameterNames, */
            jokerParameterNames: jokers, taskType, content, postprocessingFunctionNames: postprocessing, expectations, format, resultingParameterName, } = task;
            pipelineString += '\n\n';
            pipelineString += `## ${title}`;
            if (description) {
                pipelineString += '\n\n';
                pipelineString += description;
            }
            const commands = [];
            let contentLanguage = 'text';
            if (taskType === 'PROMPT_TASK') {
                const { modelRequirements } = task;
                const { modelName, modelVariant } = modelRequirements || {};
                // Note: Do nothing, it is default
                // commands.push(`PROMPT`);
                if (modelVariant) {
                    commands.push(`MODEL VARIANT ${capitalize(modelVariant)}`);
                }
                if (modelName) {
                    commands.push(`MODEL NAME \`${modelName}\``);
                }
            }
            else if (taskType === 'SIMPLE_TASK') {
                commands.push(`SIMPLE TEMPLATE`);
                // Note: Nothing special here
            }
            else if (taskType === 'SCRIPT_TASK') {
                commands.push(`SCRIPT`);
                if (task.contentLanguage) {
                    contentLanguage = task.contentLanguage;
                }
                else {
                    contentLanguage = '';
                }
            }
            else if (taskType === 'DIALOG_TASK') {
                commands.push(`DIALOG`);
                // Note: Nothing special here
            } // <- }else if([🅱]
            if (jokers) {
                for (const joker of jokers) {
                    commands.push(`JOKER {${joker}}`);
                }
            } /* not else */
            if (postprocessing) {
                for (const postprocessingFunctionName of postprocessing) {
                    commands.push(`POSTPROCESSING \`${postprocessingFunctionName}\``);
                }
            } /* not else */
            if (expectations) {
                for (const [unit, { min, max }] of Object.entries(expectations)) {
                    if (min === max) {
                        commands.push(`EXPECT EXACTLY ${min} ${capitalize(unit + (min > 1 ? 's' : ''))}`);
                    }
                    else {
                        if (min !== undefined) {
                            commands.push(`EXPECT MIN ${min} ${capitalize(unit + (min > 1 ? 's' : ''))}`);
                        } /* not else */
                        if (max !== undefined) {
                            commands.push(`EXPECT MAX ${max} ${capitalize(unit + (max > 1 ? 's' : ''))}`);
                        }
                    }
                }
            } /* not else */
            if (format) {
                if (format === 'JSON') {
                    // TODO: @deprecated remove
                    commands.push(`FORMAT JSON`);
                }
            } /* not else */
            pipelineString += '\n\n';
            pipelineString += commands.map((command) => `- ${command}`).join('\n');
            pipelineString += '\n\n';
            pipelineString += '```' + contentLanguage;
            pipelineString += '\n';
            pipelineString += spaceTrim__default["default"](content);
            //                   <- TODO: [main] !!3 Escape
            //                   <- TODO: [🧠] Some clear strategy how to spaceTrim the blocks
            pipelineString += '\n';
            pipelineString += '```';
            pipelineString += '\n\n';
            pipelineString += `\`-> {${resultingParameterName}}\``; // <- TODO: [main] !!3 If the parameter here has description, add it and use taskParameterJsonToString
        }
        return validatePipelineString(pipelineString);
    }
    /**
     * @private internal utility of `pipelineJsonToString`
     */
    function taskParameterJsonToString(taskParameterJson) {
        const { name, description } = taskParameterJson;
        let parameterString = `{${name}}`;
        if (description) {
            parameterString = `${parameterString} ${description}`;
        }
        return parameterString;
    }
    /**
     * TODO: [🛋] Implement new features and commands into `pipelineJsonToString` + `taskParameterJsonToString` , use `stringifyCommand`
     * TODO: [🧠] Is there a way to auto-detect missing features in pipelineJsonToString
     * TODO: [🏛] Maybe make some markdown builder
     * TODO: [🏛] Escape all
     * TODO: [🧠] Should be in generated .book.md file GENERATOR_WARNING
     */

    /**
     * Orders JSON object by keys
     *
     * @returns The same type of object as the input re-ordered
     * @public exported from `@promptbook/utils`
     */
    function orderJson(options) {
        const { value, order } = options;
        const orderedValue = {
            ...(order === undefined ? {} : Object.fromEntries(order.map((key) => [key, undefined]))),
            ...value,
        };
        return orderedValue;
    }

    /**
     * Freezes the given object and all its nested objects recursively
     *
     * Note: `$` is used to indicate that this function is not a pure function - it mutates given object
     * Note: This function mutates the object and returns the original (but mutated-deep-freezed) object
     *
     * @returns The same object as the input, but deeply frozen
     * @public exported from `@promptbook/utils`
     */
    function $deepFreeze(objectValue) {
        if (Array.isArray(objectValue)) {
            return Object.freeze(objectValue.map((item) => $deepFreeze(item)));
        }
        const propertyNames = Object.getOwnPropertyNames(objectValue);
        for (const propertyName of propertyNames) {
            const value = objectValue[propertyName];
            if (value && typeof value === 'object') {
                $deepFreeze(value);
            }
        }
        Object.freeze(objectValue);
        return objectValue;
    }
    /**
     * TODO: [🧠] Is there a way how to meaningfully test this utility
     */

    /**
     * Checks if the value is [🚉] serializable as JSON
     * If not, throws an UnexpectedError with a rich error message and tracking
     *
     * - Almost all primitives are serializable BUT:
     * - `undefined` is not serializable
     * - `NaN` is not serializable
     * - Objects and arrays are serializable if all their properties are serializable
     * - Functions are not serializable
     * - Circular references are not serializable
     * - `Date` objects are not serializable
     * - `Map` and `Set` objects are not serializable
     * - `RegExp` objects are not serializable
     * - `Error` objects are not serializable
     * - `Symbol` objects are not serializable
     * - And much more...
     *
     * @throws UnexpectedError if the value is not serializable as JSON
     * @public exported from `@promptbook/utils`
     */
    function checkSerializableAsJson(options) {
        const { value, name, message } = options;
        if (value === undefined) {
            throw new UnexpectedError(`${name} is undefined`);
        }
        else if (value === null) {
            return;
        }
        else if (typeof value === 'boolean') {
            return;
        }
        else if (typeof value === 'number' && !isNaN(value)) {
            return;
        }
        else if (typeof value === 'string') {
            return;
        }
        else if (typeof value === 'symbol') {
            throw new UnexpectedError(`${name} is symbol`);
        }
        else if (typeof value === 'function') {
            throw new UnexpectedError(`${name} is function`);
        }
        else if (typeof value === 'object' && Array.isArray(value)) {
            for (let i = 0; i < value.length; i++) {
                checkSerializableAsJson({ name: `${name}[${i}]`, value: value[i], message });
            }
        }
        else if (typeof value === 'object') {
            if (value instanceof Date) {
                throw new UnexpectedError(spaceTrim__default["default"]((block) => `
                        \`${name}\` is Date

                        Use \`string_date_iso8601\` instead

                        Additional message for \`${name}\`:
                        ${block(message || '(nothing)')}
                    `));
            }
            else if (value instanceof Map) {
                throw new UnexpectedError(`${name} is Map`);
            }
            else if (value instanceof Set) {
                throw new UnexpectedError(`${name} is Set`);
            }
            else if (value instanceof RegExp) {
                throw new UnexpectedError(`${name} is RegExp`);
            }
            else if (value instanceof Error) {
                throw new UnexpectedError(spaceTrim__default["default"]((block) => `
                        \`${name}\` is unserialized Error

                        Use function \`serializeError\`

                        Additional message for \`${name}\`:
                        ${block(message || '(nothing)')}

                    `));
            }
            else {
                for (const [subName, subValue] of Object.entries(value)) {
                    if (subValue === undefined) {
                        // Note: undefined in object is serializable - it is just omited
                        continue;
                    }
                    checkSerializableAsJson({ name: `${name}.${subName}`, value: subValue, message });
                }
                try {
                    JSON.stringify(value); // <- TODO: [0]
                }
                catch (error) {
                    assertsError(error);
                    throw new UnexpectedError(spaceTrim__default["default"]((block) => `
                            \`${name}\` is not serializable

                            ${block(error.stack || error.message)}

                            Additional message for \`${name}\`:
                            ${block(message || '(nothing)')}
                        `));
                }
                /*
                TODO: [0] Is there some more elegant way to check circular references?
                const seen = new Set();
                const stack = [{ value }];
                while (stack.length > 0) {
                    const { value } = stack.pop()!;
                    if (typeof value === 'object' && value !== null) {
                        if (seen.has(value)) {
                            throw new UnexpectedError(`${name} has circular reference`);
                        }
                        seen.add(value);
                        if (Array.isArray(value)) {
                            stack.push(...value.map((value) => ({ value })));
                        } else {
                            stack.push(...Object.values(value).map((value) => ({ value })));
                        }
                    }
                }
                */
                return;
            }
        }
        else {
            throw new UnexpectedError(spaceTrim__default["default"]((block) => `
                    \`${name}\` is unknown type

                    Additional message for \`${name}\`:
                    ${block(message || '(nothing)')}
                `));
        }
    }
    /**
     * TODO: Can be return type more type-safe? like `asserts options.value is JsonValue`
     * TODO: [🧠][main] !!3 In-memory cache of same values to prevent multiple checks
     * Note: [🐠] This is how `checkSerializableAsJson` + `isSerializableAsJson` together can just retun true/false or rich error message
     */

    /**
     * @@@
     *
     * @public exported from `@promptbook/utils`
     */
    function deepClone(objectValue) {
        return JSON.parse(JSON.stringify(objectValue));
        /*
        TODO: [🧠] Is there a better implementation?
        > const propertyNames = Object.getOwnPropertyNames(objectValue);
        > for (const propertyName of propertyNames) {
        >     const value = (objectValue as really_any)[propertyName];
        >     if (value && typeof value === 'object') {
        >         deepClone(value);
        >     }
        > }
        > return Object.assign({}, objectValue);
        */
    }
    /**
     * TODO: [🧠] Is there a way how to meaningfully test this utility
     */

    /**
     * Utility to export a JSON object from a function
     *
     * 1) Checks if the value is serializable as JSON
     * 2) Makes a deep clone of the object
     * 2) Orders the object properties
     * 2) Deeply freezes the cloned object
     *
     * Note: This function does not mutates the given object
     *
     * @returns The same type of object as the input but read-only and re-ordered
     * @public exported from `@promptbook/utils`
     */
    function exportJson(options) {
        const { name, value, order, message } = options;
        checkSerializableAsJson({ name, value, message });
        const orderedValue = 
        // TODO: Fix error "Type instantiation is excessively deep and possibly infinite."
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        order === undefined
            ? deepClone(value)
            : orderJson({
                value: value,
                // <- Note: checkSerializableAsJson asserts that the value is serializable as JSON
                order: order,
            });
        $deepFreeze(orderedValue);
        return orderedValue;
    }
    /**
     * TODO: [🧠] Is there a way how to meaningfully test this utility
     */

    /**
     * Order of keys in the pipeline JSON
     *
     * @public exported from `@promptbook/core`
     */
    const ORDER_OF_PIPELINE_JSON = [
        // Note: [🍙] In this order will be pipeline serialized
        'title',
        'pipelineUrl',
        'bookVersion',
        'description',
        'formfactorName',
        'parameters',
        'tasks',
        'personas',
        'preparations',
        'knowledgeSources',
        'knowledgePieces',
        'sources', // <- TODO: [🧠] Where should the `sources` be
    ];
    /**
     * Nonce which is used for replacing things in strings
     *
     * @private within the repository
     */
    const REPLACING_NONCE = 'ptbkauk42kV2dzao34faw7FudQUHYPtW';
    /**
     * @@@
     *
     * @private within the repository
     */
    const RESERVED_PARAMETER_MISSING_VALUE = 'MISSING-' + REPLACING_NONCE;
    /**
     * @@@
     *
     * @private within the repository
     */
    const RESERVED_PARAMETER_RESTRICTED = 'RESTRICTED-' + REPLACING_NONCE;
    /**
     * The names of the parameters that are reserved for special purposes
     *
     * @public exported from `@promptbook/core`
     */
    const RESERVED_PARAMETER_NAMES = exportJson({
        name: 'RESERVED_PARAMETER_NAMES',
        message: `The names of the parameters that are reserved for special purposes`,
        value: [
            'content',
            'context',
            'knowledge',
            'examples',
            'modelName',
            'currentDate',
            // <- TODO: list here all command names
            // <- TODO: Add more like 'date', 'modelName',...
            // <- TODO: Add [emoji] + instructions ACRY when adding new reserved parameter
        ],
    });
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * This error indicates that the promptbook object has valid syntax (=can be parsed) but contains logical errors (like circular dependencies)
     *
     * @public exported from `@promptbook/core`
     */
    class PipelineLogicError extends Error {
        constructor(message) {
            super(message);
            this.name = 'PipelineLogicError';
            Object.setPrototypeOf(this, PipelineLogicError.prototype);
        }
    }

    /**
     * Tests if given string is valid semantic version
     *
     * Note: There are two simmilar functions:
     * - `isValidSemanticVersion` which tests any semantic version
     * - `isValidPromptbookVersion` *(this one)* which tests just Promptbook versions
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidSemanticVersion(version) {
        if (typeof version !== 'string') {
            return false;
        }
        if (version.startsWith('0.0.0')) {
            return false;
        }
        return /^\d+\.\d+\.\d+(-\d+)?$/i.test(version);
    }

    /**
     * Tests if given string is valid promptbook version
     * It looks into list of known promptbook versions.
     *
     * @see https://www.npmjs.com/package/promptbook?activeTab=versions
     * Note: When you are using for example promptbook 2.0.0 and there already is promptbook 3.0.0 it don`t know about it.
     * Note: There are two simmilar functions:
     * - `isValidSemanticVersion` which tests any semantic version
     * - `isValidPromptbookVersion` *(this one)* which tests just Promptbook versions
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidPromptbookVersion(version) {
        if (!isValidSemanticVersion(version)) {
            return false;
        }
        if ( /* version === '1.0.0' || */version === '2.0.0' || version === '3.0.0') {
            return false;
        }
        // <- TODO: [main] !!3 Check isValidPromptbookVersion against PROMPTBOOK_ENGINE_VERSIONS
        return true;
    }

    /**
     * Tests if given string is valid pipeline URL URL.
     *
     * Note: There are two simmilar functions:
     * - `isValidUrl` which tests any URL
     * - `isValidPipelineUrl` *(this one)* which tests just pipeline URL
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidPipelineUrl(url) {
        if (!isValidUrl(url)) {
            return false;
        }
        if (!url.startsWith('https://') && !url.startsWith('http://') /* <- Note: [👣] */) {
            return false;
        }
        if (url.includes('#')) {
            // TODO: [🐠]
            return false;
        }
        /*
        Note: [👣][🧠] Is it secure to allow pipeline URLs on private and unsecured networks?
        if (isUrlOnPrivateNetwork(url)) {
            return false;
        }
        */
        return true;
    }
    /**
     * TODO: [🐠] Maybe more info why the URL is invalid
     */

    /**
     * Validates PipelineJson if it is logically valid
     *
     * It checks:
     * -   if it has correct parameters dependency
     *
     * It does NOT check:
     * -   if it is valid json
     * -   if it is meaningful
     *
     * @param pipeline valid or invalid PipelineJson
     * @returns the same pipeline if it is logically valid
     * @throws {PipelineLogicError} on logical error in the pipeline
     * @public exported from `@promptbook/core`
     */
    function validatePipeline(pipeline) {
        if (IS_PIPELINE_LOGIC_VALIDATED) {
            validatePipeline_InnerFunction(pipeline);
        }
        else {
            try {
                validatePipeline_InnerFunction(pipeline);
            }
            catch (error) {
                if (!(error instanceof PipelineLogicError)) {
                    throw error;
                }
                console.error(spaceTrim.spaceTrim((block) => `
                        Pipeline is not valid but logic errors are temporarily disabled via \`IS_PIPELINE_LOGIC_VALIDATED\`

                        ${block(error.message)}
                    `));
            }
        }
        return pipeline;
    }
    /**
     * @private internal function for `validatePipeline`
     */
    function validatePipeline_InnerFunction(pipeline) {
        // TODO: [🧠] Maybe test if promptbook is a promise and make specific error case for that
        const pipelineIdentification = (() => {
            // Note: This is a 😐 implementation of [🚞]
            const _ = [];
            if (pipeline.sourceFile !== undefined) {
                _.push(`File: ${pipeline.sourceFile}`);
            }
            if (pipeline.pipelineUrl !== undefined) {
                _.push(`Url: ${pipeline.pipelineUrl}`);
            }
            return _.join('\n');
        })();
        if (pipeline.pipelineUrl !== undefined && !isValidPipelineUrl(pipeline.pipelineUrl)) {
            // <- Note: [🚲]
            throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                    Invalid promptbook URL "${pipeline.pipelineUrl}"

                    ${block(pipelineIdentification)}
                `));
        }
        if (pipeline.bookVersion !== undefined && !isValidPromptbookVersion(pipeline.bookVersion)) {
            // <- Note: [🚲]
            throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                    Invalid Promptbook Version "${pipeline.bookVersion}"

                    ${block(pipelineIdentification)}
                `));
        }
        // TODO: [🧠] Maybe do here some propper JSON-schema / ZOD checking
        if (!Array.isArray(pipeline.parameters)) {
            // TODO: [🧠] what is the correct error tp throw - maybe PromptbookSchemaError
            throw new ParseError(spaceTrim.spaceTrim((block) => `
                    Pipeline is valid JSON but with wrong structure

                    \`PipelineJson.parameters\` expected to be an array, but got ${typeof pipeline.parameters}

                    ${block(pipelineIdentification)}
                `));
        }
        // TODO: [🧠] Maybe do here some propper JSON-schema / ZOD checking
        if (!Array.isArray(pipeline.tasks)) {
            // TODO: [🧠] what is the correct error tp throw - maybe PromptbookSchemaError
            throw new ParseError(spaceTrim.spaceTrim((block) => `
                    Pipeline is valid JSON but with wrong structure

                    \`PipelineJson.tasks\` expected to be an array, but got ${typeof pipeline.tasks}

                    ${block(pipelineIdentification)}
                `));
        }
        /*
        TODO: [🧠][🅾] Should be empty pipeline valid or not
        // Note: Check that pipeline has some tasks
        if (pipeline.tasks.length === 0) {
            throw new PipelineLogicError(
                spaceTrim(
                    (block) => `
                      Pipeline must have at least one task

                      ${block(pipelineIdentification)}
                  `,
                ),
            );
        }
        */
        // Note: Check each parameter individually
        for (const parameter of pipeline.parameters) {
            if (parameter.isInput && parameter.isOutput) {
                throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `

                        Parameter \`{${parameter.name}}\` can not be both input and output

                        ${block(pipelineIdentification)}
                    `));
            }
            // Note: Testing that parameter is either intermediate or output BUT not created and unused
            if (!parameter.isInput &&
                !parameter.isOutput &&
                !pipeline.tasks.some((task) => task.dependentParameterNames.includes(parameter.name))) {
                throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                        Parameter \`{${parameter.name}}\` is created but not used

                        You can declare {${parameter.name}} as output parameter by adding in the header:
                        - OUTPUT PARAMETER \`{${parameter.name}}\` ${parameter.description || ''}

                        ${block(pipelineIdentification)}

                    `));
            }
            // Note: Testing that parameter is either input or result of some task
            if (!parameter.isInput && !pipeline.tasks.some((task) => task.resultingParameterName === parameter.name)) {
                throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                        Parameter \`{${parameter.name}}\` is declared but not defined

                        You can do one of these:
                        1) Remove declaration of \`{${parameter.name}}\`
                        2) Add task that results in \`-> {${parameter.name}}\`

                        ${block(pipelineIdentification)}
                    `));
            }
        }
        // Note: All input parameters are defined - so that they can be used as result of some task
        const definedParameters = new Set(pipeline.parameters.filter(({ isInput }) => isInput).map(({ name }) => name));
        // Note: Checking each task individually
        for (const task of pipeline.tasks) {
            if (definedParameters.has(task.resultingParameterName)) {
                throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                        Parameter \`{${task.resultingParameterName}}\` is defined multiple times

                        ${block(pipelineIdentification)}
                    `));
            }
            if (RESERVED_PARAMETER_NAMES.includes(task.resultingParameterName)) {
                throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                        Parameter name {${task.resultingParameterName}} is reserved, please use different name

                        ${block(pipelineIdentification)}
                    `));
            }
            definedParameters.add(task.resultingParameterName);
            if (task.jokerParameterNames && task.jokerParameterNames.length > 0) {
                if (!task.format &&
                    !task.expectations /* <- TODO: Require at least 1 -> min <- expectation to use jokers */) {
                    throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                            Joker parameters are used for {${task.resultingParameterName}} but no expectations are defined

                            ${block(pipelineIdentification)}
                        `));
                }
                for (const joker of task.jokerParameterNames) {
                    if (!task.dependentParameterNames.includes(joker)) {
                        throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                                Parameter \`{${joker}}\` is used for {${task.resultingParameterName}} as joker but not in \`dependentParameterNames\`

                                ${block(pipelineIdentification)}
                            `));
                    }
                }
            }
            if (task.expectations) {
                for (const [unit, { min, max }] of Object.entries(task.expectations)) {
                    if (min !== undefined && max !== undefined && min > max) {
                        throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                                Min expectation (=${min}) of ${unit} is higher than max expectation (=${max})

                                ${block(pipelineIdentification)}
                            `));
                    }
                    if (min !== undefined && min < 0) {
                        throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                                Min expectation of ${unit} must be zero or positive

                                ${block(pipelineIdentification)}
                            `));
                    }
                    if (max !== undefined && max <= 0) {
                        throw new PipelineLogicError(spaceTrim.spaceTrim((block) => `
                                Max expectation of ${unit} must be positive

                                ${block(pipelineIdentification)}
                            `));
                    }
                }
            }
        }
        // Note: Detect circular dependencies
        let resovedParameters = pipeline.parameters
            .filter(({ isInput }) => isInput)
            .map(({ name }) => name);
        // Note: All reserved parameters are resolved
        for (const reservedParameterName of RESERVED_PARAMETER_NAMES) {
            resovedParameters = [...resovedParameters, reservedParameterName];
        }
        let unresovedTasks = [...pipeline.tasks];
        let loopLimit = LOOP_LIMIT;
        while (unresovedTasks.length > 0) {
            if (loopLimit-- < 0) {
                // Note: Really UnexpectedError not LimitReachedError - this should not happen and be caught below
                throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                        Loop limit reached during detection of circular dependencies in \`validatePipeline\`

                        ${block(pipelineIdentification)}
                    `));
            }
            const currentlyResovedTasks = unresovedTasks.filter((task) => task.dependentParameterNames.every((name) => resovedParameters.includes(name)));
            if (currentlyResovedTasks.length === 0) {
                throw new PipelineLogicError(
                // TODO: [🐎] DRY
                spaceTrim.spaceTrim((block) => `

                        Can not resolve some parameters:
                        Either you are using a parameter that is not defined, or there are some circular dependencies.

                        ${block(pipelineIdentification)}

                        **Can not resolve:**
                        ${block(unresovedTasks
                .map(({ resultingParameterName, dependentParameterNames }) => `- Parameter \`{${resultingParameterName}}\` which depends on ${dependentParameterNames
                .map((dependentParameterName) => `\`{${dependentParameterName}}\``)
                .join(' and ')}`)
                .join('\n'))}

                        **Resolved:**
                        ${block(resovedParameters
                .filter((name) => !RESERVED_PARAMETER_NAMES.includes(name))
                .map((name) => `- Parameter \`{${name}}\``)
                .join('\n'))}


                        **Reserved (which are available):**
                        ${block(resovedParameters
                .filter((name) => RESERVED_PARAMETER_NAMES.includes(name))
                .map((name) => `- Parameter \`{${name}}\``)
                .join('\n'))}


                    `));
            }
            resovedParameters = [
                ...resovedParameters,
                ...currentlyResovedTasks.map(({ resultingParameterName }) => resultingParameterName),
            ];
            unresovedTasks = unresovedTasks.filter((task) => !currentlyResovedTasks.includes(task));
        }
        // Note: Check that formfactor is corresponding to the pipeline interface
        // TODO: !!6 Implement this
        // pipeline.formfactorName
    }
    /**
     * TODO: [🧞‍♀️] Do not allow joker + foreach
     * TODO: [🧠] Work with promptbookVersion
     * TODO: Use here some json-schema, Zod or something similar and change it to:
     *     > /**
     *     >  * Validates PipelineJson if it is logically valid.
     *     >  *
     *     >  * It checks:
     *     >  * -   it has a valid structure
     *     >  * -   ...
     *     >  ex port function validatePipeline(promptbook: really_unknown): asserts promptbook is PipelineJson {
     */
    /**
     * TODO: [🧳][main] !!4 Validate that all examples match expectations
     * TODO: [🧳][🐝][main] !!4 Validate that knowledge is valid (non-void)
     * TODO: [🧳][main] !!4 Validate that persona can be used only with CHAT variant
     * TODO: [🧳][main] !!4 Validate that parameter with reserved name not used RESERVED_PARAMETER_NAMES
     * TODO: [🧳][main] !!4 Validate that reserved parameter is not used as joker
     * TODO: [🧠] Validation not only logic itself but imports around - files and websites and rerefenced pipelines exists
     * TODO: [🛠] Actions, instruments (and maybe knowledge) => Functions and tools
     */

    /**
     * This error indicates that promptbook not found in the collection
     *
     * @public exported from `@promptbook/core`
     */
    class NotFoundError extends Error {
        constructor(message) {
            super(message);
            this.name = 'NotFoundError';
            Object.setPrototypeOf(this, NotFoundError.prototype);
        }
    }

    /**
     * This error indicates errors in referencing promptbooks between each other
     *
     * @public exported from `@promptbook/core`
     */
    class PipelineUrlError extends Error {
        constructor(message) {
            super(message);
            this.name = 'PipelineUrlError';
            Object.setPrototypeOf(this, PipelineUrlError.prototype);
        }
    }

    /**
     * Parses the task and returns the list of all parameter names
     *
     * @param template the string template with parameters in {curly} braces
     * @returns the list of parameter names
     * @public exported from `@promptbook/utils`
     */
    function extractParameterNames(template) {
        const matches = template.matchAll(/{\w+}/g);
        const parameterNames = new Set();
        for (const match of matches) {
            const parameterName = match[0].slice(1, -1);
            parameterNames.add(parameterName);
        }
        return parameterNames;
    }

    /**
     * Unprepare just strips the preparation data of the pipeline
     *
     * @deprecated In future version this function will be removed or deprecated
     * @public exported from `@promptbook/core`
     */
    function unpreparePipeline(pipeline) {
        let { personas, knowledgeSources, tasks } = pipeline;
        personas = personas.map((persona) => ({ ...persona, modelRequirements: undefined, preparationIds: undefined }));
        knowledgeSources = knowledgeSources.map((knowledgeSource) => ({ ...knowledgeSource, preparationIds: undefined }));
        tasks = tasks.map((task) => {
            let { dependentParameterNames } = task;
            const parameterNames = extractParameterNames(task.preparedContent || '');
            dependentParameterNames = dependentParameterNames.filter((dependentParameterName) => !parameterNames.has(dependentParameterName));
            const taskUnprepared = { ...task, dependentParameterNames };
            delete taskUnprepared.preparedContent;
            return taskUnprepared;
        });
        return exportJson({
            name: 'pipelineJson',
            message: `Result of \`unpreparePipeline\``,
            order: ORDER_OF_PIPELINE_JSON,
            value: {
                ...pipeline,
                tasks,
                knowledgeSources,
                knowledgePieces: [],
                personas,
                preparations: [],
            },
        });
    }
    /**
     * TODO: [🧿] Maybe do same process with same granularity and subfinctions as `preparePipeline`
     * TODO: Write tests for `preparePipeline`
     * TODO: [🍙] Make some standard order of json properties
     */

    /**
     * Library of pipelines that groups together pipelines for an application.
     * This implementation is a very thin wrapper around the Array / Map of pipelines.
     *
     * @private internal function of `createCollectionFromJson`, use `createCollectionFromJson` instead
     * @see https://github.com/webgptorg/pipeline#pipeline-collection
     */
    class SimplePipelineCollection {
        /**
         * Constructs a pipeline collection from pipelines
         *
         * @param pipelines @@@
         *
         * Note: During the construction logic of all pipelines are validated
         * Note: It is not recommended to use this constructor directly, use `createCollectionFromJson` *(or other variant)* instead
         */
        constructor(...pipelines) {
            this.collection = new Map();
            for (const pipeline of pipelines) {
                // TODO: [👠] DRY
                if (pipeline.pipelineUrl === undefined) {
                    throw new PipelineUrlError(spaceTrim.spaceTrim(`
                        Pipeline with name "${pipeline.title}" does not have defined URL

                        File:
                        ${pipeline.sourceFile || 'Unknown'}

                        Note: Pipelines without URLs are called anonymous pipelines
                              They can be used as standalone pipelines, but they cannot be referenced by other pipelines
                              And also they cannot be used in the pipeline collection

                    `));
                }
                // Note: [🐨]
                validatePipeline(pipeline);
                // TODO: [🦄] DRY
                // Note: [🦄]
                if (
                // TODO: [🐽]
                this.collection.has(pipeline.pipelineUrl) &&
                    pipelineJsonToString(unpreparePipeline(pipeline)) !==
                        pipelineJsonToString(unpreparePipeline(this.collection.get(pipeline.pipelineUrl)))) {
                    const existing = this.collection.get(pipeline.pipelineUrl);
                    throw new PipelineUrlError(spaceTrim.spaceTrim(`
                        Pipeline with URL ${pipeline.pipelineUrl} is already in the collection 🍎

                        Conflicting files:
                        ${existing.sourceFile || 'Unknown'}
                        ${pipeline.sourceFile || 'Unknown'}

                        Note: You have probably forgotten to run "ptbk make" to update the collection
                        Note: Pipelines with the same URL are not allowed
                              Only exepction is when the pipelines are identical

                    `));
                }
                // Note: [🧠] Overwrite existing pipeline with the same URL
                this.collection.set(pipeline.pipelineUrl, pipeline);
            }
        }
        /**
         * Gets all pipelines in the collection
         */
        listPipelines() {
            return Array.from(this.collection.keys());
        }
        /**
         * Gets pipeline by its URL
         *
         * Note: This is not a direct fetching from the URL, but a lookup in the collection
         */
        getPipelineByUrl(url) {
            const pipeline = this.collection.get(url);
            if (!pipeline) {
                if (this.listPipelines().length === 0) {
                    throw new NotFoundError(spaceTrim.spaceTrim(`
                            Pipeline with url "${url}" not found

                            No pipelines available
                        `));
                }
                throw new NotFoundError(spaceTrim.spaceTrim((block) => `
                        Pipeline with url "${url}" not found

                        Available pipelines:
                        ${block(this.listPipelines()
                .map((pipelineUrl) => `- ${pipelineUrl}`)
                .join('\n'))}

                    `));
            }
            return pipeline;
        }
        /**
         * Checks whether given prompt was defined in any pipeline in the collection
         */
        isResponsibleForPrompt(prompt) {
            return true;
        }
    }

    /**
     * Creates PipelineCollection from array of PipelineJson or PipelineString
     *
     * Note: Functions `collectionToJson` and `createCollectionFromJson` are complementary
     * Note: Syntax, parsing, and logic consistency checks are performed on all sources during build
     *
     * @param promptbookSources
     * @returns PipelineCollection
     * @public exported from `@promptbook/core`
     */
    function createCollectionFromJson(...promptbooks) {
        return new SimplePipelineCollection(...promptbooks);
    }

    /**
     * This error type indicates that some tools are missing for pipeline execution or preparation
     *
     * @public exported from `@promptbook/core`
     */
    class MissingToolsError extends Error {
        constructor(message) {
            super(spaceTrim.spaceTrim((block) => `
                    ${block(message)}

                    Note: You have probbably forgot to provide some tools for pipeline execution or preparation

                `));
            this.name = 'MissingToolsError';
            Object.setPrototypeOf(this, MissingToolsError.prototype);
        }
    }

    /**
     * Generates random token
     *
     * Note: This function is cryptographically secure (it uses crypto.randomBytes internally)
     *
     * @private internal helper function
     * @returns secure random token
     */
    function $randomToken(randomness) {
        return crypto.randomBytes(randomness).toString('hex');
    }
    /**
     * TODO: Maybe use nanoid instead https://github.com/ai/nanoid
     */

    /**
     * This error indicates errors during the execution of the pipeline
     *
     * @public exported from `@promptbook/core`
     */
    class PipelineExecutionError extends Error {
        constructor(message) {
            // Added id parameter
            super(message);
            this.name = 'PipelineExecutionError';
            // TODO: [🐙] DRY - Maybe $randomId
            this.id = `error-${$randomToken(8 /* <- TODO: To global config + Use Base58 to avoid simmilar char conflicts   */)}`;
            Object.setPrototypeOf(this, PipelineExecutionError.prototype);
        }
    }
    /**
     * TODO: [🧠][🌂] Add id to all errors
     */

    /**
     * Determine if the pipeline is fully prepared
     *
     * @see https://github.com/webgptorg/promptbook/discussions/196
     *
     * @public exported from `@promptbook/core`
     */
    function isPipelinePrepared(pipeline) {
        // Note: Ignoring `pipeline.preparations` @@@
        // Note: Ignoring `pipeline.knowledgePieces` @@@
        if (pipeline.title === undefined || pipeline.title === '' || pipeline.title === DEFAULT_BOOK_TITLE) {
            return false;
        }
        if (!pipeline.personas.every((persona) => persona.modelRequirements !== undefined)) {
            return false;
        }
        if (!pipeline.knowledgeSources.every((knowledgeSource) => knowledgeSource.preparationIds !== undefined)) {
            return false;
        }
        /*
        TODO: [🧠][🍫] `tasks` can not be determined if they are fully prepared SO ignoring them
        > if (!pipeline.tasks.every(({ preparedContent }) => preparedContent === undefined)) {
        >     return false;
        > }
        */
        return true;
    }
    /**
     * TODO: [🔃][main] If the pipeline was prepared with different version or different set of models, prepare it once again
     * TODO: [🐠] Maybe base this on `makeValidator`
     * TODO: [🧊] Pipeline can be partially prepared, this should return true ONLY if fully prepared
     * TODO: [🧿] Maybe do same process with same granularity and subfinctions as `preparePipeline`
     *     - [🏍] ? Is context in each task
     *     - [♨] Are examples prepared
     *     - [♨] Are tasks prepared
     */

    /**
     * Recursively converts JSON strings to JSON objects

     * @public exported from `@promptbook/utils`
     */
    function jsonStringsToJsons(object) {
        if (object === null) {
            return object;
        }
        if (Array.isArray(object)) {
            return object.map(jsonStringsToJsons);
        }
        if (typeof object !== 'object') {
            return object;
        }
        const newObject = { ...object };
        for (const [key, value] of Object.entries(object)) {
            if (typeof value === 'string' && isValidJsonString(value)) {
                newObject[key] = JSON.parse(value);
            }
            else {
                newObject[key] = jsonStringsToJsons(value);
            }
        }
        return newObject;
    }
    /**
     * TODO: Type the return type correctly
     */

    /**
     * This error indicates problems parsing the format value
     *
     * For example, when the format value is not a valid JSON or CSV
     * This is not thrown directly but in extended classes
     *
     * @public exported from `@promptbook/core`
     */
    class AbstractFormatError extends Error {
        // Note: To allow instanceof do not put here error `name`
        // public readonly name = 'AbstractFormatError';
        constructor(message) {
            super(message);
            Object.setPrototypeOf(this, AbstractFormatError.prototype);
        }
    }

    /**
     * This error indicates problem with parsing of CSV
     *
     * @public exported from `@promptbook/core`
     */
    class CsvFormatError extends AbstractFormatError {
        constructor(message) {
            super(message);
            this.name = 'CsvFormatError';
            Object.setPrototypeOf(this, CsvFormatError.prototype);
        }
    }

    /**
     * AuthenticationError is thrown from login function which is dependency of remote server
     *
     * @public exported from `@promptbook/core`
     */
    class AuthenticationError extends Error {
        constructor(message) {
            super(message);
            this.name = 'AuthenticationError';
            Object.setPrototypeOf(this, AuthenticationError.prototype);
        }
    }

    /**
     * This error indicates that the pipeline collection cannot be propperly loaded
     *
     * @public exported from `@promptbook/core`
     */
    class CollectionError extends Error {
        constructor(message) {
            super(message);
            this.name = 'CollectionError';
            Object.setPrototypeOf(this, CollectionError.prototype);
        }
    }

    /**
     * This error type indicates that you try to use a feature that is not available in the current environment
     *
     * @public exported from `@promptbook/core`
     */
    class EnvironmentMismatchError extends Error {
        constructor(message) {
            super(message);
            this.name = 'EnvironmentMismatchError';
            Object.setPrototypeOf(this, EnvironmentMismatchError.prototype);
        }
    }

    /**
     * This error occurs when some expectation is not met in the execution of the pipeline
     *
     * @public exported from `@promptbook/core`
     * Note: Do not throw this error, its reserved for `checkExpectations` and `createPipelineExecutor` and public ONLY to be serializable through remote server
     * Note: Always thrown in `checkExpectations` and catched in `createPipelineExecutor` and rethrown as `PipelineExecutionError`
     * Note: This is a kindof subtype of PipelineExecutionError
     */
    class ExpectError extends Error {
        constructor(message) {
            super(message);
            this.name = 'ExpectError';
            Object.setPrototypeOf(this, ExpectError.prototype);
        }
    }

    /**
     * This error indicates that the promptbook can not retrieve knowledge from external sources
     *
     * @public exported from `@promptbook/core`
     */
    class KnowledgeScrapeError extends Error {
        constructor(message) {
            super(message);
            this.name = 'KnowledgeScrapeError';
            Object.setPrototypeOf(this, KnowledgeScrapeError.prototype);
        }
    }

    /**
     * This error type indicates that some limit was reached
     *
     * @public exported from `@promptbook/core`
     */
    class LimitReachedError extends Error {
        constructor(message) {
            super(message);
            this.name = 'LimitReachedError';
            Object.setPrototypeOf(this, LimitReachedError.prototype);
        }
    }

    /**
     * This error type indicates that some part of the code is not implemented yet
     *
     * @public exported from `@promptbook/core`
     */
    class NotYetImplementedError extends Error {
        constructor(message) {
            super(spaceTrim.spaceTrim((block) => `
                    ${block(message)}

                    Note: This feature is not implemented yet but it will be soon.

                    If you want speed up the implementation or just read more, look here:
                    https://github.com/webgptorg/promptbook

                    Or contact us on pavol@ptbk.io

                `));
            this.name = 'NotYetImplementedError';
            Object.setPrototypeOf(this, NotYetImplementedError.prototype);
        }
    }

    /**
     * Error thrown when a fetch request fails
     *
     * @public exported from `@promptbook/core`
     */
    class PromptbookFetchError extends Error {
        constructor(message) {
            super(message);
            this.name = 'PromptbookFetchError';
            Object.setPrototypeOf(this, PromptbookFetchError.prototype);
        }
    }

    /**
     * Index of all custom errors
     *
     * @public exported from `@promptbook/core`
     */
    const PROMPTBOOK_ERRORS = {
        AbstractFormatError,
        CsvFormatError,
        CollectionError,
        EnvironmentMismatchError,
        ExpectError,
        KnowledgeScrapeError,
        LimitReachedError,
        MissingToolsError,
        NotFoundError,
        NotYetImplementedError,
        ParseError,
        PipelineExecutionError,
        PipelineLogicError,
        PipelineUrlError,
        AuthenticationError,
        PromptbookFetchError,
        UnexpectedError,
        WrappedError,
        // TODO: [🪑]> VersionMismatchError,
    };
    /**
     * Index of all javascript errors
     *
     * @private for internal usage
     */
    const COMMON_JAVASCRIPT_ERRORS = {
        Error,
        EvalError,
        RangeError,
        ReferenceError,
        SyntaxError,
        TypeError,
        URIError,
        AggregateError,
        /*
      Note: Not widely supported
      > InternalError,
      > ModuleError,
      > HeapError,
      > WebAssemblyCompileError,
      > WebAssemblyRuntimeError,
      */
    };
    /**
     * Index of all errors
     *
     * @private for internal usage
     */
    const ALL_ERRORS = {
        ...PROMPTBOOK_ERRORS,
        ...COMMON_JAVASCRIPT_ERRORS,
    };
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Deserializes the error object
     *
     * @public exported from `@promptbook/utils`
     */
    function deserializeError(error) {
        const { name, stack, id } = error; // Added id
        let { message } = error;
        let ErrorClass = ALL_ERRORS[error.name];
        if (ErrorClass === undefined) {
            ErrorClass = Error;
            message = `${name}: ${message}`;
        }
        if (stack !== undefined && stack !== '') {
            message = spaceTrim__default["default"]((block) => `
                ${block(message)}

                Original stack trace:
                ${block(stack || '')}
            `);
        }
        const deserializedError = new ErrorClass(message);
        deserializedError.id = id; // Assign id to the error object
        return deserializedError;
    }

    /**
     * Asserts that the execution of a Promptbook is successful
     *
     * Note: If there are only warnings, the execution is still successful but the warnings are logged in the console
     *
     * @param executionResult - The partial result of the Promptbook execution
     * @throws {PipelineExecutionError} If the execution is not successful or if multiple errors occurred
     * @private internal helper function of `asPromise` method of `ExecutionTask`
     */
    function assertsTaskSuccessful(executionResult) {
        const { isSuccessful, errors, warnings } = executionResult;
        for (const warning of warnings) {
            console.warn(warning.message);
            // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
        }
        if (isSuccessful === true) {
            return;
        }
        if (errors.length === 0) {
            throw new PipelineExecutionError(`Promptbook Execution failed because of unknown reason`);
        }
        else if (errors.length === 1) {
            throw deserializeError(errors[0]);
        }
        else {
            throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                    Multiple errors occurred during Promptbook execution

                    ${block(errors
            .map(({ name, stack, message }, index) => spaceTrim.spaceTrim((block) => `
                                        ${name} ${index + 1}:
                                        ${block(stack || message)}
                                    `))
            .join('\n'))}
                `));
        }
    }
    /**
     * TODO: [🧠] Can this return type be better typed than void
     */

    /**
     * Helper to create a new task
     *
     * @private internal helper function
     */
    function createTask(options) {
        const { taskType, taskProcessCallback } = options;
        // TODO: [🐙] DRY
        const taskId = `${taskType.toLowerCase().substring(0, 4)}-${$randomToken(8 /* <- TODO: To global config + Use Base58 to avoid simmilar char conflicts   */)}`;
        let status = 'RUNNING';
        const createdAt = new Date();
        let updatedAt = createdAt;
        const errors = [];
        const warnings = [];
        let currentValue = {};
        const partialResultSubject = new rxjs.Subject();
        // <- Note: Not using `BehaviorSubject` because on error we can't access the last value
        const finalResultPromise = /* not await */ taskProcessCallback((newOngoingResult) => {
            Object.assign(currentValue, newOngoingResult);
            // <- TODO: assign deep
            partialResultSubject.next(newOngoingResult);
        });
        finalResultPromise
            .catch((error) => {
            errors.push(error);
            partialResultSubject.error(error);
        })
            .then((executionResult) => {
            if (executionResult) {
                try {
                    updatedAt = new Date();
                    errors.push(...executionResult.errors);
                    warnings.push(...executionResult.warnings);
                    // <- TODO: [🌂] Only unique errors and warnings should be added (or filtered)
                    // TODO: [🧠] !! errors, warning, isSuccessful  are redundant both in `ExecutionTask` and `ExecutionTask.currentValue`
                    //            Also maybe move `ExecutionTask.currentValue.usage` -> `ExecutionTask.usage`
                    //            And delete `ExecutionTask.currentValue.preparedPipeline`
                    assertsTaskSuccessful(executionResult);
                    status = 'FINISHED';
                    currentValue = jsonStringsToJsons(executionResult);
                    // <- TODO: [🧠] Is this a good idea to convert JSON strins to JSONs?
                    partialResultSubject.next(executionResult);
                }
                catch (error) {
                    assertsError(error);
                    status = 'ERROR';
                    errors.push(error);
                    partialResultSubject.error(error);
                }
            }
            partialResultSubject.complete();
        });
        async function asPromise(options) {
            const { isCrashedOnError = true } = options || {};
            const finalResult = await finalResultPromise;
            if (isCrashedOnError) {
                assertsTaskSuccessful(finalResult);
            }
            return finalResult;
        }
        return {
            taskType,
            taskId,
            get status() {
                return status;
                // <- Note: [1] Theese must be getters to allow changing the value in the future
            },
            get createdAt() {
                return createdAt;
                // <- Note: [1]
            },
            get updatedAt() {
                return updatedAt;
                // <- Note: [1]
            },
            asPromise,
            asObservable() {
                return partialResultSubject.asObservable();
            },
            get errors() {
                return errors;
                // <- Note: [1]
            },
            get warnings() {
                return warnings;
                // <- Note: [1]
            },
            get currentValue() {
                return currentValue;
                // <- Note: [1]
            },
        };
    }
    /**
     * TODO: Maybe allow to terminate the task and add getter `isFinished` or `status`
     * TODO: [🐚] Split into more files and make `PrepareTask` & `RemoteTask` + split the function
     */

    /**
     * Serializes an error into a [🚉] JSON-serializable object
     *
     * @public exported from `@promptbook/utils`
     */
    function serializeError(error) {
        const { name, message, stack } = error;
        const { id } = error;
        if (!Object.keys(ALL_ERRORS).includes(name)) {
            console.error(spaceTrim__default["default"]((block) => `

                    Cannot serialize error with name "${name}"

                    Authors of Promptbook probably forgot to add this error into the list of errors:
                    https://github.com/webgptorg/promptbook/blob/main/src/errors/0-index.ts


                    ${block(stack || message)}

                `));
        }
        return {
            name: name,
            message,
            stack,
            id, // Include id in the serialized object
        };
    }

    /**
     * Async version of Array.forEach
     *
     * @param array - Array to iterate over
     * @param options - Options for the function
     * @param callbackfunction - Function to call for each item
     * @public exported from `@promptbook/utils`
     * @deprecated [🪂] Use queues instead
     */
    async function forEachAsync(array, options, callbackfunction) {
        const { maxParallelCount = Infinity } = options;
        let index = 0;
        let runningTasks = [];
        const tasks = [];
        for (const item of array) {
            const currentIndex = index++;
            const task = callbackfunction(item, currentIndex, array);
            tasks.push(task);
            runningTasks.push(task);
            /* not await */ Promise.resolve(task).then(() => {
                runningTasks = runningTasks.filter((t) => t !== task);
            });
            if (maxParallelCount < runningTasks.length) {
                await Promise.race(runningTasks);
            }
        }
        await Promise.all(tasks);
    }

    /**
     * Represents the uncertain value
     *
     * @public exported from `@promptbook/core`
     */
    const ZERO_VALUE = $deepFreeze({ value: 0 });
    /**
     * Represents the uncertain value
     *
     * @public exported from `@promptbook/core`
     */
    const UNCERTAIN_ZERO_VALUE = $deepFreeze({ value: 0, isUncertain: true });
    /**
     * Represents the usage with no resources consumed
     *
     * @public exported from `@promptbook/core`
     */
    const ZERO_USAGE = $deepFreeze({
        price: ZERO_VALUE,
        input: {
            tokensCount: ZERO_VALUE,
            charactersCount: ZERO_VALUE,
            wordsCount: ZERO_VALUE,
            sentencesCount: ZERO_VALUE,
            linesCount: ZERO_VALUE,
            paragraphsCount: ZERO_VALUE,
            pagesCount: ZERO_VALUE,
        },
        output: {
            tokensCount: ZERO_VALUE,
            charactersCount: ZERO_VALUE,
            wordsCount: ZERO_VALUE,
            sentencesCount: ZERO_VALUE,
            linesCount: ZERO_VALUE,
            paragraphsCount: ZERO_VALUE,
            pagesCount: ZERO_VALUE,
        },
    });
    /**
     * Represents the usage with unknown resources consumed
     *
     * @public exported from `@promptbook/core`
     */
    $deepFreeze({
        price: UNCERTAIN_ZERO_VALUE,
        input: {
            tokensCount: UNCERTAIN_ZERO_VALUE,
            charactersCount: UNCERTAIN_ZERO_VALUE,
            wordsCount: UNCERTAIN_ZERO_VALUE,
            sentencesCount: UNCERTAIN_ZERO_VALUE,
            linesCount: UNCERTAIN_ZERO_VALUE,
            paragraphsCount: UNCERTAIN_ZERO_VALUE,
            pagesCount: UNCERTAIN_ZERO_VALUE,
        },
        output: {
            tokensCount: UNCERTAIN_ZERO_VALUE,
            charactersCount: UNCERTAIN_ZERO_VALUE,
            wordsCount: UNCERTAIN_ZERO_VALUE,
            sentencesCount: UNCERTAIN_ZERO_VALUE,
            linesCount: UNCERTAIN_ZERO_VALUE,
            paragraphsCount: UNCERTAIN_ZERO_VALUE,
            pagesCount: UNCERTAIN_ZERO_VALUE,
        },
    });
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Function `addUsage` will add multiple usages into one
     *
     * Note: If you provide 0 values, it returns ZERO_USAGE
     *
     * @public exported from `@promptbook/core`
     */
    function addUsage(...usageItems) {
        return usageItems.reduce((acc, item) => {
            var _a;
            acc.price.value += ((_a = item.price) === null || _a === void 0 ? void 0 : _a.value) || 0;
            for (const key of Object.keys(acc.input)) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                //@ts-ignore
                if (item.input[key]) {
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    //@ts-ignore
                    acc.input[key].value += item.input[key].value || 0;
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    //@ts-ignore
                    if (item.input[key].isUncertain) {
                        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                        //@ts-ignore
                        acc.input[key].isUncertain = true;
                    }
                }
            }
            for (const key of Object.keys(acc.output)) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                //@ts-ignore
                if (item.output[key]) {
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    //@ts-ignore
                    acc.output[key].value += item.output[key].value || 0;
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    //@ts-ignore
                    if (item.output[key].isUncertain) {
                        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                        //@ts-ignore
                        acc.output[key].isUncertain = true;
                    }
                }
            }
            return acc;
        }, deepClone(ZERO_USAGE));
    }

    /**
     * Intercepts LLM tools and counts total usage of the tools
     *
     * @param llmTools LLM tools to be intercepted with usage counting
     * @returns LLM tools with same functionality with added total cost counting
     * @public exported from `@promptbook/core`
     */
    function countUsage(llmTools) {
        let totalUsage = ZERO_USAGE;
        const spending = new rxjs.Subject();
        const proxyTools = {
            get title() {
                // TODO: [🧠] Maybe put here some suffix
                return llmTools.title;
            },
            get description() {
                // TODO: [🧠] Maybe put here some suffix
                return llmTools.description;
            },
            checkConfiguration() {
                return /* not await */ llmTools.checkConfiguration();
            },
            listModels() {
                return /* not await */ llmTools.listModels();
            },
            spending() {
                return spending.asObservable();
            },
            getTotalUsage() {
                // <- Note: [🥫] Not using getter `get totalUsage` but `getTotalUsage` to allow this object to be proxied
                return totalUsage;
            },
        };
        if (llmTools.callChatModel !== undefined) {
            proxyTools.callChatModel = async (prompt) => {
                // console.info('[🚕] callChatModel through countTotalUsage');
                const promptResult = await llmTools.callChatModel(prompt);
                totalUsage = addUsage(totalUsage, promptResult.usage);
                spending.next(promptResult.usage);
                return promptResult;
            };
        }
        if (llmTools.callCompletionModel !== undefined) {
            proxyTools.callCompletionModel = async (prompt) => {
                // console.info('[🚕] callCompletionModel through countTotalUsage');
                const promptResult = await llmTools.callCompletionModel(prompt);
                totalUsage = addUsage(totalUsage, promptResult.usage);
                spending.next(promptResult.usage);
                return promptResult;
            };
        }
        if (llmTools.callEmbeddingModel !== undefined) {
            proxyTools.callEmbeddingModel = async (prompt) => {
                // console.info('[🚕] callEmbeddingModel through countTotalUsage');
                const promptResult = await llmTools.callEmbeddingModel(prompt);
                totalUsage = addUsage(totalUsage, promptResult.usage);
                spending.next(promptResult.usage);
                return promptResult;
            };
        }
        // <- Note: [🤖]
        return proxyTools;
    }
    /**
     * TODO: [🧠][💸] Maybe make some common abstraction `interceptLlmTools` and use here (or use javascript Proxy?)
     * TODO: [🧠] Is there some meaningfull way how to test this util
     * TODO: [🧠][🌯] Maybe a way how to hide ability to `get totalUsage`
     *     > const [llmToolsWithUsage,getUsage] = countTotalUsage(llmTools);
     * TODO: [👷‍♂️] @@@ Manual about construction of llmTools
     */

    /**
     * Multiple LLM Execution Tools is a proxy server that uses multiple execution tools internally and exposes the executor interface externally.
     *
     * Note: Internal utility of `joinLlmExecutionTools` but exposed type
     * @public exported from `@promptbook/core`
     */
    class MultipleLlmExecutionTools {
        /**
         * Gets array of execution tools in order of priority
         */
        constructor(...llmExecutionTools) {
            this.llmExecutionTools = llmExecutionTools;
        }
        get title() {
            return 'Multiple LLM Providers';
        }
        get description() {
            return this.llmExecutionTools.map(({ title }, index) => `${index + 1}) \`${title}\``).join('\n');
        }
        /**
         * Check the configuration of all execution tools
         */
        async checkConfiguration() {
            // TODO: Maybe do it in parallel
            for (const llmExecutionTools of this.llmExecutionTools) {
                await llmExecutionTools.checkConfiguration();
            }
        }
        /**
         * List all available models that can be used
         * This lists is a combination of all available models from all execution tools
         */
        async listModels() {
            const availableModels = [];
            for (const llmExecutionTools of this.llmExecutionTools) {
                // TODO: [🪂] Obtain models in parallel
                const models = await llmExecutionTools.listModels();
                availableModels.push(...models);
            }
            return availableModels;
        }
        /**
         * Calls the best available chat model
         */
        callChatModel(prompt) {
            return this.callCommonModel(prompt);
        }
        /**
         * Calls the best available completion model
         */
        callCompletionModel(prompt) {
            return this.callCommonModel(prompt);
        }
        /**
         * Calls the best available embedding model
         */
        callEmbeddingModel(prompt) {
            return this.callCommonModel(prompt);
        }
        // <- Note: [🤖]
        /**
         * Calls the best available model
         *
         * Note: This should be private or protected but is public to be usable with duck typing
         */
        async callCommonModel(prompt) {
            const errors = [];
            llm: for (const llmExecutionTools of this.llmExecutionTools) {
                try {
                    variant: switch (prompt.modelRequirements.modelVariant) {
                        case 'CHAT':
                            if (llmExecutionTools.callChatModel === undefined) {
                                continue llm;
                            }
                            return await llmExecutionTools.callChatModel(prompt);
                            break variant;
                        case 'COMPLETION':
                            if (llmExecutionTools.callCompletionModel === undefined) {
                                continue llm;
                            }
                            return await llmExecutionTools.callCompletionModel(prompt);
                            break variant;
                        case 'EMBEDDING':
                            if (llmExecutionTools.callEmbeddingModel === undefined) {
                                continue llm;
                            }
                            return await llmExecutionTools.callEmbeddingModel(prompt);
                            break variant;
                        // <- case [🤖]:
                        default:
                            throw new UnexpectedError(`Unknown model variant "${prompt.modelRequirements.modelVariant}"`);
                    }
                }
                catch (error) {
                    assertsError(error);
                    if (error instanceof UnexpectedError) {
                        throw error;
                    }
                    errors.push({ llmExecutionTools, error });
                }
            }
            if (errors.length === 1) {
                throw errors[0].error;
            }
            else if (errors.length > 1) {
                throw new PipelineExecutionError(
                // TODO: Tell which execution tools failed like
                //     1) OpenAI throw PipelineExecutionError: Parameter `{knowledge}` is not defined
                //     2) AnthropicClaude throw PipelineExecutionError: Parameter `{knowledge}` is not defined
                //     3) ...
                spaceTrim__default["default"]((block) => `
                          All execution tools failed:

                          ${block(errors
                .map(({ error, llmExecutionTools }, i) => `${i + 1}) **${llmExecutionTools.title}** thrown **${error.name || 'Error'}:** ${error.message}`)
                .join('\n'))}

                    `));
            }
            else if (this.llmExecutionTools.length === 0) {
                throw new PipelineExecutionError(`You have not provided any \`LlmExecutionTools\``);
            }
            else {
                throw new PipelineExecutionError(spaceTrim__default["default"]((block) => `
                          You have not provided any \`LlmExecutionTools\` that support model variant "${prompt.modelRequirements.modelVariant}"

                          Available \`LlmExecutionTools\`:
                          ${block(this.description)}

                    `));
            }
        }
    }
    /**
     * TODO: [🧠][🎛] Aggregating multiple models - have result not only from one first available model BUT all of them
     * TODO: [🏖] If no llmTools have for example not defined `callCompletionModel` this will still return object with defined `callCompletionModel` which just throws `PipelineExecutionError`, make it undefined instead
     *       Look how `countTotalUsage` (and `cacheLlmTools`) implements it
     */

    /**
     * Joins multiple LLM Execution Tools into one
     *
     * @returns {LlmExecutionTools} Single wrapper for multiple LlmExecutionTools
     *
     * 0) If there is no LlmExecutionTools, it warns and returns valid but empty LlmExecutionTools
     * 1) If there is only one LlmExecutionTools, it returns it wrapped in a proxy object
     * 2) If there are multiple LlmExecutionTools, first will be used first, second will be used if the first hasn`t defined model variant or fails, etc.
     * 3) When all LlmExecutionTools fail, it throws an error with a list of all errors merged into one
     *
     *
     * Tip: You don't have to use this function directly, just pass an array of LlmExecutionTools to the `ExecutionTools`
     *
     * @public exported from `@promptbook/core`
     */
    function joinLlmExecutionTools(...llmExecutionTools) {
        if (llmExecutionTools.length === 0) {
            const warningMessage = spaceTrim__default["default"](`
            You have not provided any \`LlmExecutionTools\`
            This means that you won't be able to execute any prompts that require large language models like GPT-4 or Anthropic's Claude.

            Technically, it's not an error, but it's probably not what you want because it does not make sense to use Promptbook without language models.
        `);
            // TODO: [🟥] Detect browser / node and make it colorfull
            console.warn(warningMessage);
            // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
            /*
            return {
                async listModels() {
                    // TODO: [🟥] Detect browser / node and make it colorfull
                    console.warn(
                        spaceTrim(
                            (block) => `

                                You can't list models because you have no LLM Execution Tools defined:

                                tl;dr

                                ${block(warningMessage)}
                            `,
                        ),
                    );
                    return [];
                },
            };
            */
        }
        return new MultipleLlmExecutionTools(...llmExecutionTools);
    }
    /**
     * TODO: [👷‍♂️] @@@ Manual about construction of llmTools
     */

    /**
     * Takes an item or an array of items and returns an array of items
     *
     * 1) Any item except array and undefined returns array with that one item (also null)
     * 2) Undefined returns empty array
     * 3) Array returns itself
     *
     * @private internal utility
     */
    function arrayableToArray(input) {
        if (input === undefined) {
            return [];
        }
        if (input instanceof Array) {
            return input;
        }
        return [input];
    }

    /**
     * Prepares the persona for the pipeline
     *
     * @see https://github.com/webgptorg/promptbook/discussions/22
     * @public exported from `@promptbook/core`
     */
    async function preparePersona(personaDescription, tools, options) {
        const { isVerbose = DEFAULT_IS_VERBOSE } = options;
        if (tools === undefined || tools.llm === undefined) {
            throw new MissingToolsError('LLM tools are required for preparing persona');
        }
        // TODO: [🌼] In future use `ptbk make` and made getPipelineCollection
        const collection = createCollectionFromJson(...PipelineCollection);
        const preparePersonaExecutor = createPipelineExecutor({
            pipeline: await collection.getPipelineByUrl('https://promptbook.studio/promptbook/prepare-persona.book'),
            tools,
        });
        // TODO: [🚐] Make arrayable LLMs -> single LLM DRY
        const _llms = arrayableToArray(tools.llm);
        const llmTools = _llms.length === 1 ? _llms[0] : joinLlmExecutionTools(..._llms);
        const availableModels = await llmTools.listModels();
        const availableModelNames = availableModels
            .filter(({ modelVariant }) => modelVariant === 'CHAT')
            .map(({ modelName }) => modelName)
            .join(',');
        const result = await preparePersonaExecutor({ availableModelNames, personaDescription }).asPromise();
        const { outputParameters } = result;
        const { modelRequirements: modelRequirementsRaw } = outputParameters;
        const modelRequirements = JSON.parse(modelRequirementsRaw);
        if (isVerbose) {
            console.info(`PERSONA ${personaDescription}`, modelRequirements);
        }
        const { modelName, systemMessage, temperature } = modelRequirements;
        return {
            modelVariant: 'CHAT',
            modelName,
            systemMessage,
            temperature,
        };
    }
    /**
     * TODO: [🔃][main] If the persona was prepared with different version or different set of models, prepare it once again
     * TODO: [🏢] Check validity of `modelName` in pipeline
     * TODO: [🏢] Check validity of `systemMessage` in pipeline
     * TODO: [🏢] Check validity of `temperature` in pipeline
     */

    /**
     * @@@
     *
     * Note: `$` is used to indicate that this function is not a pure function - it access global scope
     *
     *  @private internal function of `$Register`
     */
    function $getGlobalScope() {
        return Function('return this')();
    }

    /**
     * @@@
     *
     * @param text @@@
     * @returns @@@
     * @example 'HELLO_WORLD'
     * @example 'I_LOVE_PROMPTBOOK'
     * @public exported from `@promptbook/utils`
     */
    function normalizeTo_SCREAMING_CASE(text) {
        let charType;
        let lastCharType = 'OTHER';
        let normalizedName = '';
        for (const char of text) {
            let normalizedChar;
            if (/^[a-z]$/.test(char)) {
                charType = 'LOWERCASE';
                normalizedChar = char.toUpperCase();
            }
            else if (/^[A-Z]$/.test(char)) {
                charType = 'UPPERCASE';
                normalizedChar = char;
            }
            else if (/^[0-9]$/.test(char)) {
                charType = 'NUMBER';
                normalizedChar = char;
            }
            else {
                charType = 'OTHER';
                normalizedChar = '_';
            }
            if (charType !== lastCharType &&
                !(lastCharType === 'UPPERCASE' && charType === 'LOWERCASE') &&
                !(lastCharType === 'NUMBER') &&
                !(charType === 'NUMBER')) {
                normalizedName += '_';
            }
            normalizedName += normalizedChar;
            lastCharType = charType;
        }
        normalizedName = normalizedName.replace(/_+/g, '_');
        normalizedName = normalizedName.replace(/_?\/_?/g, '/');
        normalizedName = normalizedName.replace(/^_/, '');
        normalizedName = normalizedName.replace(/_$/, '');
        return normalizedName;
    }
    /**
     * TODO: Tests
     *     > expect(encodeRoutePath({ uriId: 'VtG7sR9rRJqwNEdM2', name: 'Moje tabule' })).toEqual('/VtG7sR9rRJqwNEdM2/Moje tabule');
     *     > expect(encodeRoutePath({ uriId: 'VtG7sR9rRJqwNEdM2', name: 'ěščřžžýáíúů' })).toEqual('/VtG7sR9rRJqwNEdM2/escrzyaieuu');
     *     > expect(encodeRoutePath({ uriId: 'VtG7sR9rRJqwNEdM2', name: '  ahoj  ' })).toEqual('/VtG7sR9rRJqwNEdM2/ahoj');
     *     > expect(encodeRoutePath({ uriId: 'VtG7sR9rRJqwNEdM2', name: '  ahoj_ahojAhoj    ahoj  ' })).toEqual('/VtG7sR9rRJqwNEdM2/ahoj-ahoj-ahoj-ahoj');
     * TODO: [🌺] Use some intermediate util splitWords
     */

    /**
     * @@@
     *
     * @param text @@@
     * @returns @@@
     * @example 'hello_world'
     * @example 'i_love_promptbook'
     * @public exported from `@promptbook/utils`
     */
    function normalizeTo_snake_case(text) {
        return normalizeTo_SCREAMING_CASE(text).toLowerCase();
    }

    /**
     * Register is @@@
     *
     * Note: `$` is used to indicate that this function is not a pure function - it accesses and adds variables in global scope.
     *
     * @private internal utility, exported are only signleton instances of this class
     */
    class $Register {
        constructor(registerName) {
            this.registerName = registerName;
            const storageName = `_promptbook_${normalizeTo_snake_case(registerName)}`;
            const globalScope = $getGlobalScope();
            if (globalScope[storageName] === undefined) {
                globalScope[storageName] = [];
            }
            else if (!Array.isArray(globalScope[storageName])) {
                throw new UnexpectedError(`Expected (global) ${storageName} to be an array, but got ${typeof globalScope[storageName]}`);
            }
            this.storage = globalScope[storageName];
        }
        list() {
            // <- TODO: ReadonlyDeep<ReadonlyArray<TRegistered>>
            return this.storage;
        }
        register(registered) {
            const { packageName, className } = registered;
            const existingRegistrationIndex = this.storage.findIndex((item) => item.packageName === packageName && item.className === className);
            const existingRegistration = this.storage[existingRegistrationIndex];
            if (!existingRegistration) {
                this.storage.push(registered);
            }
            else {
                this.storage[existingRegistrationIndex] = registered;
            }
            return {
                registerName: this.registerName,
                packageName,
                className,
                get isDestroyed() {
                    return false;
                },
                destroy() {
                    throw new NotYetImplementedError(`Registration to ${this.registerName} is permanent in this version of Promptbook`);
                },
            };
        }
    }

    /**
     * @@@
     *
     * Note: `$` is used to indicate that this interacts with the global scope
     * @singleton Only one instance of each register is created per build, but thare can be more @@@
     * @public exported from `@promptbook/core`
     */
    const $scrapersMetadataRegister = new $Register('scrapers_metadata');
    /**
     * TODO: [®] DRY Register logic
     */

    /**
     * @@@
     *
     * Note: `$` is used to indicate that this interacts with the global scope
     * @singleton Only one instance of each register is created per build, but thare can be more @@@
     * @public exported from `@promptbook/core`
     */
    const $scrapersRegister = new $Register('scraper_constructors');
    /**
     * TODO: [®] DRY Register logic
     */

    /**
     * Creates a message with all registered scrapers
     *
     * Note: This function is used to create a (error) message when there is no scraper for particular mime type
     *
     * @private internal function of `createScrapersFromConfiguration` and `createScrapersFromEnv`
     */
    function $registeredScrapersMessage(availableScrapers) {
        /**
         * Mixes registered scrapers from $scrapersMetadataRegister and $scrapersRegister
         */
        const all = [];
        for (const { packageName, className, mimeTypes, documentationUrl, isAvilableInBrowser, } of $scrapersMetadataRegister.list()) {
            if (all.some((item) => item.packageName === packageName && item.className === className)) {
                continue;
            }
            all.push({ packageName, className, mimeTypes, documentationUrl, isAvilableInBrowser });
        }
        for (const { packageName, className, mimeTypes, documentationUrl, isAvilableInBrowser, } of $scrapersRegister.list()) {
            if (all.some((item) => item.packageName === packageName && item.className === className)) {
                continue;
            }
            all.push({ packageName, className, mimeTypes, documentationUrl, isAvilableInBrowser });
        }
        for (const { metadata } of availableScrapers) {
            all.push(metadata);
        }
        const metadata = all.map((metadata) => {
            const isMetadataAviailable = $scrapersMetadataRegister
                .list()
                .find(({ packageName, className }) => metadata.packageName === packageName && metadata.className === className);
            const isInstalled = $scrapersRegister
                .list()
                .find(({ packageName, className }) => metadata.packageName === packageName && metadata.className === className);
            const isAvilableInTools = availableScrapers.some(({ metadata: { packageName, className } }) => metadata.packageName === packageName && metadata.className === className);
            return { ...metadata, isMetadataAviailable, isInstalled, isAvilableInTools };
        });
        if (metadata.length === 0) {
            return spaceTrim__default["default"](`
            **No scrapers are available**

            This is a unexpected behavior, you are probably using some broken version of Promptbook
            At least there should be available the metadata of the scrapers
        `);
        }
        return spaceTrim__default["default"]((block) => `
            Available scrapers are:
            ${block(metadata
        .map(({ packageName, className, isMetadataAviailable, isInstalled, mimeTypes, isAvilableInBrowser, isAvilableInTools, }, i) => {
        const more = [];
        // TODO: [🧠] Maybe use `documentationUrl`
        if (isMetadataAviailable) {
            more.push(`⬜ Metadata registered`);
        } // not else
        if (isInstalled) {
            more.push(`🟩 Installed`);
        } // not else
        if (isAvilableInTools) {
            more.push(`🟦 Available in tools`);
        } // not else
        if (!isMetadataAviailable && isInstalled) {
            more.push(`When no metadata registered but scraper is installed, it is an unexpected behavior`);
        } // not else
        if (!isInstalled && isAvilableInTools) {
            more.push(`When the scraper is not installed but available in tools, it is an unexpected compatibility behavior`);
        } // not else
        if (!isAvilableInBrowser) {
            more.push(`Not usable in browser`);
        }
        const moreText = more.length === 0 ? '' : ` *(${more.join('; ')})*`;
        return `${i + 1}) \`${className}\` from \`${packageName}\` compatible to scrape ${mimeTypes
            .map((mimeType) => `"${mimeType}"`)
            .join(', ')}${moreText}`;
    })
        .join('\n'))}

            Legend:
            - ⬜ **Metadata registered** means that Promptbook knows about the scraper, it is similar to registration in some registry
            - 🟩 **Installed** means that you have imported package with particular scraper
            - 🟦 **Available in tools** means that you have passed scraper as dependency into prepare or execution process

        `);
    }
    /**
     * TODO: [®] DRY Register logic
     */

    const defaultDiacriticsRemovalMap = [
        {
            base: 'A',
            letters: '\u0041\u24B6\uFF21\u00C0\u00C1\u00C2\u1EA6\u1EA4\u1EAA\u1EA8\u00C3\u0100\u0102\u1EB0\u1EAE\u1EB4\u1EB2\u0226\u01E0\u00C4\u01DE\u1EA2\u00C5\u01FA\u01CD\u0200\u0202\u1EA0\u1EAC\u1EB6\u1E00\u0104\u023A\u2C6F',
        },
        { base: 'AA', letters: '\uA732' },
        { base: 'AE', letters: '\u00C6\u01FC\u01E2' },
        { base: 'AO', letters: '\uA734' },
        { base: 'AU', letters: '\uA736' },
        { base: 'AV', letters: '\uA738\uA73A' },
        { base: 'AY', letters: '\uA73C' },
        {
            base: 'B',
            letters: '\u0042\u24B7\uFF22\u1E02\u1E04\u1E06\u0243\u0182\u0181',
        },
        {
            base: 'C',
            letters: '\u0043\u24B8\uFF23\u0106\u0108\u010A\u010C\u00C7\u1E08\u0187\u023B\uA73E',
        },
        {
            base: 'D',
            letters: '\u0044\u24B9\uFF24\u1E0A\u010E\u1E0C\u1E10\u1E12\u1E0E\u0110\u018B\u018A\u0189\uA779\u00D0',
        },
        { base: 'DZ', letters: '\u01F1\u01C4' },
        { base: 'Dz', letters: '\u01F2\u01C5' },
        {
            base: 'E',
            letters: '\u0045\u24BA\uFF25\u00C8\u00C9\u00CA\u1EC0\u1EBE\u1EC4\u1EC2\u1EBC\u0112\u1E14\u1E16\u0114\u0116\u00CB\u1EBA\u011A\u0204\u0206\u1EB8\u1EC6\u0228\u1E1C\u0118\u1E18\u1E1A\u0190\u018E',
        },
        { base: 'F', letters: '\u0046\u24BB\uFF26\u1E1E\u0191\uA77B' },
        {
            base: 'G',
            letters: '\u0047\u24BC\uFF27\u01F4\u011C\u1E20\u011E\u0120\u01E6\u0122\u01E4\u0193\uA7A0\uA77D\uA77E',
        },
        {
            base: 'H',
            letters: '\u0048\u24BD\uFF28\u0124\u1E22\u1E26\u021E\u1E24\u1E28\u1E2A\u0126\u2C67\u2C75\uA78D',
        },
        {
            base: 'I',
            letters: '\u0049\u24BE\uFF29\u00CC\u00CD\u00CE\u0128\u012A\u012C\u0130\u00CF\u1E2E\u1EC8\u01CF\u0208\u020A\u1ECA\u012E\u1E2C\u0197',
        },
        { base: 'J', letters: '\u004A\u24BF\uFF2A\u0134\u0248' },
        {
            base: 'K',
            letters: '\u004B\u24C0\uFF2B\u1E30\u01E8\u1E32\u0136\u1E34\u0198\u2C69\uA740\uA742\uA744\uA7A2',
        },
        {
            base: 'L',
            letters: '\u004C\u24C1\uFF2C\u013F\u0139\u013D\u1E36\u1E38\u013B\u1E3C\u1E3A\u0141\u023D\u2C62\u2C60\uA748\uA746\uA780',
        },
        { base: 'LJ', letters: '\u01C7' },
        { base: 'Lj', letters: '\u01C8' },
        { base: 'M', letters: '\u004D\u24C2\uFF2D\u1E3E\u1E40\u1E42\u2C6E\u019C' },
        {
            base: 'N',
            letters: '\u004E\u24C3\uFF2E\u01F8\u0143\u00D1\u1E44\u0147\u1E46\u0145\u1E4A\u1E48\u0220\u019D\uA790\uA7A4',
        },
        { base: 'NJ', letters: '\u01CA' },
        { base: 'Nj', letters: '\u01CB' },
        {
            base: 'O',
            letters: '\u004F\u24C4\uFF2F\u00D2\u00D3\u00D4\u1ED2\u1ED0\u1ED6\u1ED4\u00D5\u1E4C\u022C\u1E4E\u014C\u1E50\u1E52\u014E\u022E\u0230\u00D6\u022A\u1ECE\u0150\u01D1\u020C\u020E\u01A0\u1EDC\u1EDA\u1EE0\u1EDE\u1EE2\u1ECC\u1ED8\u01EA\u01EC\u00D8\u01FE\u0186\u019F\uA74A\uA74C',
        },
        { base: 'OI', letters: '\u01A2' },
        { base: 'OO', letters: '\uA74E' },
        { base: 'OU', letters: '\u0222' },
        { base: 'OE', letters: '\u008C\u0152' },
        { base: 'oe', letters: '\u009C\u0153' },
        {
            base: 'P',
            letters: '\u0050\u24C5\uFF30\u1E54\u1E56\u01A4\u2C63\uA750\uA752\uA754',
        },
        { base: 'Q', letters: '\u0051\u24C6\uFF31\uA756\uA758\u024A' },
        {
            base: 'R',
            letters: '\u0052\u24C7\uFF32\u0154\u1E58\u0158\u0210\u0212\u1E5A\u1E5C\u0156\u1E5E\u024C\u2C64\uA75A\uA7A6\uA782',
        },
        {
            base: 'S',
            letters: '\u0053\u24C8\uFF33\u1E9E\u015A\u1E64\u015C\u1E60\u0160\u1E66\u1E62\u1E68\u0218\u015E\u2C7E\uA7A8\uA784',
        },
        {
            base: 'T',
            letters: '\u0054\u24C9\uFF34\u1E6A\u0164\u1E6C\u021A\u0162\u1E70\u1E6E\u0166\u01AC\u01AE\u023E\uA786',
        },
        { base: 'TZ', letters: '\uA728' },
        {
            base: 'U',
            letters: '\u0055\u24CA\uFF35\u00D9\u00DA\u00DB\u0168\u1E78\u016A\u1E7A\u016C\u00DC\u01DB\u01D7\u01D5\u01D9\u1EE6\u016E\u0170\u01D3\u0214\u0216\u01AF\u1EEA\u1EE8\u1EEE\u1EEC\u1EF0\u1EE4\u1E72\u0172\u1E76\u1E74\u0244',
        },
        { base: 'V', letters: '\u0056\u24CB\uFF36\u1E7C\u1E7E\u01B2\uA75E\u0245' },
        { base: 'VY', letters: '\uA760' },
        {
            base: 'W',
            letters: '\u0057\u24CC\uFF37\u1E80\u1E82\u0174\u1E86\u1E84\u1E88\u2C72',
        },
        { base: 'X', letters: '\u0058\u24CD\uFF38\u1E8A\u1E8C' },
        {
            base: 'Y',
            letters: '\u0059\u24CE\uFF39\u1EF2\u00DD\u0176\u1EF8\u0232\u1E8E\u0178\u1EF6\u1EF4\u01B3\u024E\u1EFE',
        },
        {
            base: 'Z',
            letters: '\u005A\u24CF\uFF3A\u0179\u1E90\u017B\u017D\u1E92\u1E94\u01B5\u0224\u2C7F\u2C6B\uA762',
        },
        {
            base: 'a',
            letters: '\u0061\u24D0\uFF41\u1E9A\u00E0\u00E1\u00E2\u1EA7\u1EA5\u1EAB\u1EA9\u00E3\u0101\u0103\u1EB1\u1EAF\u1EB5\u1EB3\u0227\u01E1\u00E4\u01DF\u1EA3\u00E5\u01FB\u01CE\u0201\u0203\u1EA1\u1EAD\u1EB7\u1E01\u0105\u2C65\u0250',
        },
        { base: 'aa', letters: '\uA733' },
        { base: 'ae', letters: '\u00E6\u01FD\u01E3' },
        { base: 'ao', letters: '\uA735' },
        { base: 'au', letters: '\uA737' },
        { base: 'av', letters: '\uA739\uA73B' },
        { base: 'ay', letters: '\uA73D' },
        {
            base: 'b',
            letters: '\u0062\u24D1\uFF42\u1E03\u1E05\u1E07\u0180\u0183\u0253',
        },
        {
            base: 'c',
            letters: '\u0063\u24D2\uFF43\u0107\u0109\u010B\u010D\u00E7\u1E09\u0188\u023C\uA73F\u2184',
        },
        {
            base: 'd',
            letters: '\u0064\u24D3\uFF44\u1E0B\u010F\u1E0D\u1E11\u1E13\u1E0F\u0111\u018C\u0256\u0257\uA77A',
        },
        { base: 'dz', letters: '\u01F3\u01C6' },
        {
            base: 'e',
            letters: '\u0065\u24D4\uFF45\u00E8\u00E9\u00EA\u1EC1\u1EBF\u1EC5\u1EC3\u1EBD\u0113\u1E15\u1E17\u0115\u0117\u00EB\u1EBB\u011B\u0205\u0207\u1EB9\u1EC7\u0229\u1E1D\u0119\u1E19\u1E1B\u0247\u025B\u01DD',
        },
        { base: 'f', letters: '\u0066\u24D5\uFF46\u1E1F\u0192\uA77C' },
        {
            base: 'g',
            letters: '\u0067\u24D6\uFF47\u01F5\u011D\u1E21\u011F\u0121\u01E7\u0123\u01E5\u0260\uA7A1\u1D79\uA77F',
        },
        {
            base: 'h',
            letters: '\u0068\u24D7\uFF48\u0125\u1E23\u1E27\u021F\u1E25\u1E29\u1E2B\u1E96\u0127\u2C68\u2C76\u0265',
        },
        { base: 'hv', letters: '\u0195' },
        {
            base: 'i',
            letters: '\u0069\u24D8\uFF49\u00EC\u00ED\u00EE\u0129\u012B\u012D\u00EF\u1E2F\u1EC9\u01D0\u0209\u020B\u1ECB\u012F\u1E2D\u0268\u0131',
        },
        { base: 'j', letters: '\u006A\u24D9\uFF4A\u0135\u01F0\u0249' },
        {
            base: 'k',
            letters: '\u006B\u24DA\uFF4B\u1E31\u01E9\u1E33\u0137\u1E35\u0199\u2C6A\uA741\uA743\uA745\uA7A3',
        },
        {
            base: 'l',
            letters: '\u006C\u24DB\uFF4C\u0140\u013A\u013E\u1E37\u1E39\u013C\u1E3D\u1E3B\u017F\u0142\u019A\u026B\u2C61\uA749\uA781\uA747',
        },
        { base: 'lj', letters: '\u01C9' },
        { base: 'm', letters: '\u006D\u24DC\uFF4D\u1E3F\u1E41\u1E43\u0271\u026F' },
        {
            base: 'n',
            letters: '\u006E\u24DD\uFF4E\u01F9\u0144\u00F1\u1E45\u0148\u1E47\u0146\u1E4B\u1E49\u019E\u0272\u0149\uA791\uA7A5',
        },
        { base: 'nj', letters: '\u01CC' },
        {
            base: 'o',
            letters: '\u006F\u24DE\uFF4F\u00F2\u00F3\u00F4\u1ED3\u1ED1\u1ED7\u1ED5\u00F5\u1E4D\u022D\u1E4F\u014D\u1E51\u1E53\u014F\u022F\u0231\u00F6\u022B\u1ECF\u0151\u01D2\u020D\u020F\u01A1\u1EDD\u1EDB\u1EE1\u1EDF\u1EE3\u1ECD\u1ED9\u01EB\u01ED\u00F8\u01FF\u0254\uA74B\uA74D\u0275',
        },
        { base: 'oi', letters: '\u01A3' },
        { base: 'ou', letters: '\u0223' },
        { base: 'oo', letters: '\uA74F' },
        {
            base: 'p',
            letters: '\u0070\u24DF\uFF50\u1E55\u1E57\u01A5\u1D7D\uA751\uA753\uA755',
        },
        { base: 'q', letters: '\u0071\u24E0\uFF51\u024B\uA757\uA759' },
        {
            base: 'r',
            letters: '\u0072\u24E1\uFF52\u0155\u1E59\u0159\u0211\u0213\u1E5B\u1E5D\u0157\u1E5F\u024D\u027D\uA75B\uA7A7\uA783',
        },
        {
            base: 's',
            letters: '\u0073\u24E2\uFF53\u00DF\u015B\u1E65\u015D\u1E61\u0161\u1E67\u1E63\u1E69\u0219\u015F\u023F\uA7A9\uA785\u1E9B',
        },
        {
            base: 't',
            letters: '\u0074\u24E3\uFF54\u1E6B\u1E97\u0165\u1E6D\u021B\u0163\u1E71\u1E6F\u0167\u01AD\u0288\u2C66\uA787',
        },
        { base: 'tz', letters: '\uA729' },
        {
            base: 'u',
            letters: '\u0075\u24E4\uFF55\u00F9\u00FA\u00FB\u0169\u1E79\u016B\u1E7B\u016D\u00FC\u01DC\u01D8\u01D6\u01DA\u1EE7\u016F\u0171\u01D4\u0215\u0217\u01B0\u1EEB\u1EE9\u1EEF\u1EED\u1EF1\u1EE5\u1E73\u0173\u1E77\u1E75\u0289',
        },
        { base: 'v', letters: '\u0076\u24E5\uFF56\u1E7D\u1E7F\u028B\uA75F\u028C' },
        { base: 'vy', letters: '\uA761' },
        {
            base: 'w',
            letters: '\u0077\u24E6\uFF57\u1E81\u1E83\u0175\u1E87\u1E85\u1E98\u1E89\u2C73',
        },
        { base: 'x', letters: '\u0078\u24E7\uFF58\u1E8B\u1E8D' },
        {
            base: 'y',
            letters: '\u0079\u24E8\uFF59\u1EF3\u00FD\u0177\u1EF9\u0233\u1E8F\u00FF\u1EF7\u1E99\u1EF5\u01B4\u024F\u1EFF',
        },
        {
            base: 'z',
            letters: '\u007A\u24E9\uFF5A\u017A\u1E91\u017C\u017E\u1E93\u1E95\u01B6\u0225\u0240\u2C6C\uA763',
        },
    ];
    /**
     * Map of letters from diacritic variant to diacritless variant
     * Contains lowercase and uppercase separatelly
     *
     * > "á" => "a"
     * > "ě" => "e"
     * > "Ă" => "A"
     * > ...
     *
     * @public exported from `@promptbook/utils`
     */
    const DIACRITIC_VARIANTS_LETTERS = {};
    // tslint:disable-next-line: prefer-for-of
    for (let i = 0; i < defaultDiacriticsRemovalMap.length; i++) {
        const letters = defaultDiacriticsRemovalMap[i].letters;
        // tslint:disable-next-line: prefer-for-of
        for (let j = 0; j < letters.length; j++) {
            DIACRITIC_VARIANTS_LETTERS[letters[j]] = defaultDiacriticsRemovalMap[i].base;
        }
    }
    // <- TODO: [🍓] Put to maker function to save execution time if not needed
    /*
      @see https://stackoverflow.com/questions/990904/remove-accents-diacritics-in-a-string-in-javascript
       Licensed under the Apache License, Version 2.0 (the "License");
       you may not use this file except in compliance with the License.
       You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    */

    /**
     * @@@
     *
     * @param input @@@
     * @returns @@@
     * @public exported from `@promptbook/utils`
     */
    function removeDiacritics(input) {
        /*eslint no-control-regex: "off"*/
        return input.replace(/[^\u0000-\u007E]/g, (a) => {
            return DIACRITIC_VARIANTS_LETTERS[a] || a;
        });
    }
    /**
     * TODO: [Ж] Variant for cyrillic (and in general non-latin) letters
     */

    /**
     * @@@
     *
     * @param text @@@
     * @returns @@@
     * @example 'hello-world'
     * @example 'i-love-promptbook'
     * @public exported from `@promptbook/utils`
     */
    function normalizeToKebabCase(text) {
        text = removeDiacritics(text);
        let charType;
        let lastCharType = 'OTHER';
        let normalizedName = '';
        for (const char of text) {
            let normalizedChar;
            if (/^[a-z]$/.test(char)) {
                charType = 'LOWERCASE';
                normalizedChar = char;
            }
            else if (/^[A-Z]$/.test(char)) {
                charType = 'UPPERCASE';
                normalizedChar = char.toLowerCase();
            }
            else if (/^[0-9]$/.test(char)) {
                charType = 'NUMBER';
                normalizedChar = char;
            }
            else {
                charType = 'OTHER';
                normalizedChar = '-';
            }
            if (charType !== lastCharType &&
                !(lastCharType === 'UPPERCASE' && charType === 'LOWERCASE') &&
                !(lastCharType === 'NUMBER') &&
                !(charType === 'NUMBER')) {
                normalizedName += '-';
            }
            normalizedName += normalizedChar;
            lastCharType = charType;
        }
        normalizedName = normalizedName.split(/-+/g).join('-');
        normalizedName = normalizedName.split(/-?\/-?/g).join('/');
        normalizedName = normalizedName.replace(/^-/, '');
        normalizedName = normalizedName.replace(/-$/, '');
        return normalizedName;
    }
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Creates unique name for the source
     *
     * @public exported from `@promptbook/editable`
     */
    function knowledgeSourceContentToName(knowledgeSourceContent) {
        const hash = cryptoJs.SHA256(hexEncoder__default["default"].parse(JSON.stringify(knowledgeSourceContent)))
            //    <- TODO: [🥬] Encapsulate sha256 to some private utility function
            .toString( /* hex */)
            .substring(0, 20);
        //    <- TODO: [🥬] Make some system for hashes and ids of promptbook
        const semanticName = normalizeToKebabCase(knowledgeSourceContent.substring(0, 20));
        const pieces = ['source', semanticName, hash].filter((piece) => piece !== '');
        const name = pieces.join('-').split('--').join('-');
        // <- TODO: Use MAX_FILENAME_LENGTH
        return name;
    }
    /**
     * TODO: [🐱‍🐉][🧠] Make some smart crop NOT source-i-m-pavol-a-develop-... BUT source-i-m-pavol-a-developer-...
     */

    /**
     * @@@
     *
     * @private for `FileCacheStorage`
     */
    function nameToSubfolderPath(name) {
        return [name.substr(0, 1).toLowerCase(), name.substr(1, 1).toLowerCase()];
    }

    /**
     * Convert file extension to mime type
     *
     * @private within the repository
     */
    function extensionToMimeType(value) {
        return mimeTypes.lookup(value) || 'application/octet-stream';
    }

    /**
     * Get the file extension from a file name
     *
     * @private within the repository
     */
    function getFileExtension(value) {
        const match = value.match(/\.([0-9a-z]+)(?:[?#]|$)/i);
        return match ? match[1].toLowerCase() : null;
    }

    /**
     * Checks if the file exists
     *
     * @private within the repository
     */
    async function isFileExisting(filename, fs) {
        const isReadAccessAllowed = await fs
            .access(filename, fs.constants.R_OK)
            .then(() => true)
            .catch(() => false);
        if (!isReadAccessAllowed) {
            return false;
        }
        const isFile = await fs
            .stat(filename)
            .then((fileStat) => fileStat.isFile())
            .catch(() => false);
        return isFile;
    }
    /**
     * Note: Not [~🟢~] because it is not directly dependent on `fs
     * TODO: [🐠] This can be a validator - with variants that return true/false and variants that throw errors with meaningless messages
     * TODO: [🖇] What about symlinks?
     */

    /**
     * Convert mime type to file extension
     *
     * Note: If the mime type is invalid, `null` is returned
     *
     * @private within the repository
     */
    function mimeTypeToExtension(value) {
        return mimeTypes.extension(value) || null;
    }

    /**
     * Removes emojis from a string and fix whitespaces
     *
     * @param text with emojis
     * @returns text without emojis
     * @public exported from `@promptbook/utils`
     */
    function removeEmojis(text) {
        // Replace emojis (and also ZWJ sequence) with hyphens
        text = text.replace(/(\p{Extended_Pictographic})\p{Modifier_Symbol}/gu, '$1');
        text = text.replace(/(\p{Extended_Pictographic})[\u{FE00}-\u{FE0F}]/gu, '$1');
        text = text.replace(/(\p{Extended_Pictographic})(\u{200D}\p{Extended_Pictographic})*/gu, '$1');
        text = text.replace(/\p{Extended_Pictographic}/gu, '');
        return text;
    }

    /**
     * @@@
     *
     * @param value @@@
     * @returns @@@
     * @example @@@
     * @public exported from `@promptbook/utils`
     */
    function titleToName(value) {
        if (isValidUrl(value)) {
            value = value.replace(/^https?:\/\//, '');
            value = value.replace(/\.html$/, '');
        }
        else if (isValidFilePath(value)) {
            value = path.basename(value);
            // Note: Keeping extension in the name
        }
        value = value.split('/').join('-');
        value = removeEmojis(value);
        value = normalizeToKebabCase(value);
        // TODO: [🧠] Maybe warn or add some padding to short name which are not good identifiers
        return value;
    }

    /**
     * The built-in `fetch' function with a lightweight error handling wrapper as default fetch function used in Promptbook scrapers
     *
     * @public exported from `@promptbook/core`
     */
    const promptbookFetch = async (urlOrRequest, init) => {
        try {
            return await fetch(urlOrRequest, init);
        }
        catch (error) {
            assertsError(error);
            let url;
            if (typeof urlOrRequest === 'string') {
                url = urlOrRequest;
            }
            else if (urlOrRequest instanceof Request) {
                url = urlOrRequest.url;
            }
            throw new PromptbookFetchError(spaceTrim__default["default"]((block) => `
                    Can not fetch "${url}"

                    Fetch error:
                    ${block(error.message)}

                `));
        }
    };
    /**
     * TODO: [🧠] Maybe rename because it is not used only for scrapers but also in `$getCompiledBook`
     */

    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    async function makeKnowledgeSourceHandler(knowledgeSource, tools, options) {
        // console.log('!! makeKnowledgeSourceHandler', knowledgeSource);
        var _a;
        const { fetch = promptbookFetch } = tools;
        const { knowledgeSourceContent } = knowledgeSource;
        let { name } = knowledgeSource;
        const { rootDirname = null, 
        // <- TODO: process.cwd() if running in Node.js
        isVerbose = DEFAULT_IS_VERBOSE, } = options || {};
        if (!name) {
            name = knowledgeSourceContentToName(knowledgeSourceContent);
        }
        if (isValidUrl(knowledgeSourceContent)) {
            const url = knowledgeSourceContent;
            const response = await fetch(url); // <- TODO: [🧠] Scraping and fetch proxy
            const mimeType = ((_a = response.headers.get('content-type')) === null || _a === void 0 ? void 0 : _a.split(';')[0]) || 'text/html';
            if (tools.fs === undefined || !url.endsWith('.pdf' /* <- TODO: [💵] */)) {
                return {
                    source: name,
                    filename: null,
                    url,
                    mimeType,
                    /*
                  TODO: [🥽]
                      > async asBlob() {
                      >     // TODO: [👨🏻‍🤝‍👨🏻] This can be called multiple times BUT when called second time, response in already consumed
                      >     const content = await response.blob();
                      >     return content;
                      > },
                  */
                    async asJson() {
                        // TODO: [👨🏻‍🤝‍👨🏻]
                        const content = await response.json();
                        return content;
                    },
                    async asText() {
                        // TODO: [👨🏻‍🤝‍👨🏻]
                        const content = await response.text();
                        return content;
                    },
                };
            }
            const basename = url.split('/').pop() || titleToName(url);
            const hash = sha256__default["default"](hexEncoder__default["default"].parse(url)).toString( /* hex */);
            //    <- TODO: [🥬] Encapsulate sha256 to some private utility function
            const rootDirname = path.join(process.cwd(), DEFAULT_DOWNLOAD_CACHE_DIRNAME);
            const filepath = path.join(...nameToSubfolderPath(hash /* <- TODO: [🎎] Maybe add some SHA256 prefix */), `${basename.substring(0, MAX_FILENAME_LENGTH)}.${mimeTypeToExtension(mimeType)}`);
            await tools.fs.mkdir(path.dirname(path.join(rootDirname, filepath)), { recursive: true });
            const fileContent = Buffer.from(await response.arrayBuffer());
            if (fileContent.length > DEFAULT_MAX_FILE_SIZE /* <- TODO: Allow to pass different value to remote server */) {
                throw new LimitReachedError(`File is too large (${Math.round(fileContent.length / 1024 / 1024)}MB). Maximum allowed size is ${Math.round(DEFAULT_MAX_FILE_SIZE / 1024 / 1024)}MB.`);
            }
            await tools.fs.writeFile(path.join(rootDirname, filepath), fileContent);
            // TODO: [💵] Check the file security
            // TODO: [🧹][🧠] Delete the file after the scraping is done
            return makeKnowledgeSourceHandler({ name, knowledgeSourceContent: filepath }, tools, {
                ...options,
                rootDirname,
            });
        }
        else if (isValidFilePath(knowledgeSourceContent)) {
            if (tools.fs === undefined) {
                throw new EnvironmentMismatchError('Can not import file knowledge without filesystem tools');
                //          <- TODO: [🧠] What is the best error type here`
            }
            if (rootDirname === null) {
                throw new EnvironmentMismatchError('Can not import file knowledge in non-file pipeline');
                //          <- TODO: [🧠] What is the best error type here`
            }
            const filename = path.join(rootDirname, knowledgeSourceContent).split('\\').join('/');
            const fileExtension = getFileExtension(filename);
            const mimeType = extensionToMimeType(fileExtension || '');
            if (!(await isFileExisting(filename, tools.fs))) {
                throw new NotFoundError(spaceTrim__default["default"]((block) => `
                          Can not make source handler for file which does not exist:

                          File:
                          ${block(knowledgeSourceContent)}

                          Full file path:
                          ${block(filename)}
                      `));
            }
            // TODO: [🧠][😿] Test security file - file is scoped to the project (BUT maybe do this in `filesystemTools`)
            return {
                source: name,
                filename,
                url: null,
                mimeType,
                /*
                TODO: [🥽]
                    > async asBlob() {
                    >     const content = await tools.fs!.readFile(filename);
                    >     return new Blob(
                    >         [
                    >             content,
                    >             // <- TODO: [🥽] This is NOT tested, test it
                    >         ],
                    >         { type: mimeType },
                    >     );
                    > },
                */
                async asJson() {
                    return JSON.parse(await tools.fs.readFile(filename, 'utf-8'));
                },
                async asText() {
                    return await tools.fs.readFile(filename, 'utf-8');
                },
            };
        }
        else {
            return {
                source: name,
                filename: null,
                url: null,
                mimeType: 'text/markdown',
                asText() {
                    return knowledgeSource.knowledgeSourceContent;
                },
                asJson() {
                    throw new UnexpectedError('Did not expect that `markdownScraper` would need to get the content `asJson`');
                },
                /*
                TODO: [🥽]
                    > asBlob() {
                    >     throw new UnexpectedError(
                    >         'Did not expect that `markdownScraper` would need to get the content `asBlob`',
                    >     );
                    > },
                */
            };
        }
    }

    /**
     * Prepares the knowle
     *
     * @see https://github.com/webgptorg/promptbook/discussions/41
     * @public exported from `@promptbook/core`
     */
    async function prepareKnowledgePieces(knowledgeSources, tools, options) {
        const { maxParallelCount = DEFAULT_MAX_PARALLEL_COUNT, rootDirname, isVerbose = DEFAULT_IS_VERBOSE } = options;
        const knowledgePreparedUnflatten = new Array(knowledgeSources.length);
        await forEachAsync(knowledgeSources, { maxParallelCount }, async (knowledgeSource, index) => {
            try {
                let partialPieces = null;
                const sourceHandler = await makeKnowledgeSourceHandler(knowledgeSource, tools, { rootDirname, isVerbose });
                const scrapers = arrayableToArray(tools.scrapers);
                for (const scraper of scrapers) {
                    if (!scraper.metadata.mimeTypes.includes(sourceHandler.mimeType)
                    // <- TODO: [🦔] Implement mime-type wildcards
                    ) {
                        continue;
                    }
                    const partialPiecesUnchecked = await scraper.scrape(sourceHandler);
                    if (partialPiecesUnchecked !== null) {
                        partialPieces = [...partialPiecesUnchecked];
                        // <- TODO: [🪓] Here should be no need for spreading new array, just `partialPieces = partialPiecesUnchecked`
                        break;
                    }
                    console.warn(spaceTrim__default["default"]((block) => `
                            Cannot scrape knowledge from source despite the scraper \`${scraper.metadata.className}\` supports the mime type "${sourceHandler.mimeType}".

                            The source:
                            ${block(knowledgeSource.knowledgeSourceContent
                    .split('\n')
                    .map((line) => `> ${line}`)
                    .join('\n'))}

                            ${block($registeredScrapersMessage(scrapers))}


                        `));
                    // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
                }
                if (partialPieces === null) {
                    throw new KnowledgeScrapeError(spaceTrim__default["default"]((block) => `
                            Cannot scrape knowledge

                            The source:
                            > ${block(knowledgeSource.knowledgeSourceContent
                    .split('\n')
                    .map((line) => `> ${line}`)
                    .join('\n'))}

                            No scraper found for the mime type "${sourceHandler.mimeType}"

                            ${block($registeredScrapersMessage(scrapers))}


                        `));
                }
                const pieces = partialPieces.map((partialPiece) => ({
                    ...partialPiece,
                    sources: [
                        {
                            name: knowledgeSource.name,
                            // line, column <- TODO: [☀]
                            // <- TODO: [❎]
                        },
                    ],
                }));
                knowledgePreparedUnflatten[index] = pieces;
            }
            catch (error) {
                assertsError(error);
                console.warn(error);
                // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
            }
        });
        const knowledgePrepared = knowledgePreparedUnflatten.flat();
        return knowledgePrepared;
    }
    /*
    TODO: [🧊] This is how it can look in future
    > type PrepareKnowledgeKnowledge = {
    >   /**
    >    * Unprepared knowledge
    >    * /
    >   readonly knowledgeSources: ReadonlyArray<KnowledgeSourceJson>;
    > };
    >
    > export async function prepareKnowledgePieces(
    >   knowledge: PrepareKnowledgeKnowledge,
    >   options: PrepareAndScrapeOptions,
    > ):
    */
    /**
     * TODO: [🧊] In future one preparation can take data from previous preparation and save tokens and time
     *       Put `knowledgePieces` into `PrepareKnowledgeOptions`
     * TODO: [🪂] More than max things can run in parallel by acident [1,[2a,2b,_],[3a,3b,_]]
     * TODO: [🧠][❎] Do here propper M:N mapping
     *       [x] One source can make multiple pieces
     *       [ ] One piece can have multiple sources
     */

    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    async function prepareTasks(pipeline, tools, options) {
        const { maxParallelCount = DEFAULT_MAX_PARALLEL_COUNT } = options;
        const { tasks, parameters, knowledgePiecesCount } = pipeline;
        // TODO: [🖌][🧠] Implement some `mapAsync` function
        const tasksPrepared = new Array(tasks.length);
        await forEachAsync(tasks, { maxParallelCount /* <- TODO: [🪂] When there are subtasks, this maximul limit can be broken */ }, async (task, index) => {
            let { /* preparedContent <- TODO: Maybe use [🧊] */ dependentParameterNames } = task;
            let preparedContent = undefined;
            if (task.taskType === 'PROMPT_TASK' &&
                knowledgePiecesCount > 0 &&
                !dependentParameterNames.includes('knowledge')) {
                preparedContent = spaceTrim.spaceTrim(`
                    {content}

                    ## Knowledge

                    {knowledge}
                `);
                // <- TODO: [🧠][🧻] Cutomize shape/language/formatting of the addition to the prompt
                dependentParameterNames = [
                    ...dependentParameterNames,
                    'knowledge',
                    // <- [🏷] There is the reverse process to remove {knowledge} from `dependentParameterNames`
                ];
            }
            const preparedTask = {
                ...task,
                dependentParameterNames,
                preparedContent,
                // <- TODO: [🍙] Make some standard order of json properties
            };
            tasksPrepared[index] = preparedTask;
        });
        return { tasksPrepared };
    }
    /**
     * TODO: [😂] Adding knowledge should be convert to async high-level abstractions, simmilar thing with expectations to sync high-level abstractions
     * TODO: [🧠] Add context to each task (if missing)
     * TODO: [🧠] What is better name `prepareTask` or `prepareTaskAndParameters`
     * TODO: [♨][main] !!3 Prepare index the examples and maybe tasks
     * TODO: Write tests for `preparePipeline`
     * TODO: [🏏] Leverage the batch API and build queues @see https://platform.openai.com/docs/guides/batch
     * TODO: [🧊] In future one preparation can take data from previous preparation and save tokens and time
     * TODO: [🛠] Actions, instruments (and maybe knowledge) => Functions and tools
     */

    /**
     * Prepare pipeline locally
     *
     * @see https://github.com/webgptorg/promptbook/discussions/196
     *
     * Note: This function does not validate logic of the pipeline
     * Note: This function acts as part of compilation process
     * Note: When the pipeline is already prepared, it returns the same pipeline
     * @public exported from `@promptbook/core`
     */
    async function preparePipeline(pipeline, tools, options) {
        if (isPipelinePrepared(pipeline)) {
            return pipeline;
        }
        const { rootDirname, maxParallelCount = DEFAULT_MAX_PARALLEL_COUNT, isVerbose = DEFAULT_IS_VERBOSE } = options;
        const { parameters, tasks, 
        /*
        <- TODO: [🧠][🪑] `promptbookVersion` */
        knowledgeSources /*
        <- TODO: [🧊] `knowledgePieces` */, personas /*
        <- TODO: [🧊] `preparations` */, sources, } = pipeline;
        if (tools === undefined || tools.llm === undefined) {
            throw new MissingToolsError('LLM tools are required for preparing the pipeline');
        }
        // TODO: [🚐] Make arrayable LLMs -> single LLM DRY
        const _llms = arrayableToArray(tools.llm);
        const llmTools = _llms.length === 1 ? _llms[0] : joinLlmExecutionTools(..._llms);
        const llmToolsWithUsage = countUsage(llmTools);
        //    <- TODO: [🌯]
        /*
        TODO: [🧠][🪑][🔃] Should this be done or not
        if (promptbookVersion !== PROMPTBOOK_ENGINE_VERSION) {
            throw new VersionMismatchError(`Can not prepare the pipeline`, promptbookVersion);
        }
        */
        // TODO: [🔃][main] If the pipeline was prepared with different version or different set of models, prepare it once again
        // ----- ID -----
        const currentPreparation = {
            id: 1,
            // TODO: [🍥]> date: $getCurrentDate(),
            promptbookVersion: PROMPTBOOK_ENGINE_VERSION,
            usage: ZERO_USAGE,
        };
        const preparations = [
            // ...preparations
            // <- TODO: [🧊]
            currentPreparation,
        ];
        // ----- /ID -----
        // ----- Title preparation -----
        let title = pipeline.title;
        if (title === undefined || title === '' || title === DEFAULT_BOOK_TITLE) {
            // TODO: [🌼] In future use `ptbk make` and made getPipelineCollection
            const collection = createCollectionFromJson(...PipelineCollection);
            const prepareTitleExecutor = createPipelineExecutor({
                pipeline: await collection.getPipelineByUrl('https://promptbook.studio/promptbook/prepare-title.book'),
                tools,
            });
            const result = await prepareTitleExecutor({
                book: sources.map(({ content }) => content).join('\n\n'),
            }).asPromise();
            const { outputParameters } = result;
            const { title: titleRaw } = outputParameters;
            if (isVerbose) {
                console.info(`The title is "${titleRaw}"`);
            }
            title = titleRaw || DEFAULT_BOOK_TITLE;
        }
        // ----- /Title preparation -----
        // ----- Personas preparation -----
        // TODO: Extract to similar function as `prepareTasks`
        // TODO: [🖌][🧠] Implement some `mapAsync` function
        const preparedPersonas = new Array(personas.length);
        await forEachAsync(personas, { maxParallelCount /* <- TODO: [🪂] When there are subtasks, this maximul limit can be broken */ }, async (persona, index) => {
            const modelRequirements = await preparePersona(persona.description, { ...tools, llm: llmToolsWithUsage }, {
                rootDirname,
                maxParallelCount /* <- TODO:  [🪂] */,
                isVerbose,
            });
            const preparedPersona = {
                ...persona,
                modelRequirements,
                preparationIds: [/* TODO: [🧊] -> */ currentPreparation.id],
                // <- TODO: [🍙] Make some standard order of json properties
            };
            preparedPersonas[index] = preparedPersona;
        });
        // ----- /Personas preparation -----
        // ----- Knowledge preparation -----
        // TODO: Extract to similar function as `prepareTasks`
        const knowledgeSourcesPrepared = knowledgeSources.map((source) => ({
            ...source,
            preparationIds: [/* TODO: [🧊] -> */ currentPreparation.id],
        }));
        const partialknowledgePiecesPrepared = await prepareKnowledgePieces(knowledgeSources /* <- TODO: [🧊] {knowledgeSources, knowledgePieces} */, { ...tools, llm: llmToolsWithUsage }, {
            ...options,
            rootDirname,
            maxParallelCount /* <- TODO:  [🪂] */,
            isVerbose,
        });
        const knowledgePiecesPrepared = partialknowledgePiecesPrepared.map((piece) => ({
            ...piece,
            preparationIds: [/* TODO: [🧊] -> */ currentPreparation.id],
            // <- TODO: [🍙] Make some standard order of json properties
        }));
        // ----- /Knowledge preparation -----
        // ----- Tasks preparation -----
        const { tasksPrepared /* TODO: parameters: parametersPrepared*/ } = await prepareTasks({
            parameters,
            tasks,
            knowledgePiecesCount: knowledgePiecesPrepared.length,
        }, { ...tools, llm: llmToolsWithUsage }, {
            rootDirname,
            maxParallelCount /* <- TODO:  [🪂] */,
            isVerbose,
        });
        // ----- /Tasks preparation -----
        // TODO: [😂] Use here all `AsyncHighLevelAbstraction`
        // Note: Count total usage
        currentPreparation.usage = llmToolsWithUsage.getTotalUsage();
        return exportJson({
            name: 'pipelineJson',
            message: `Result of \`preparePipeline\``,
            order: ORDER_OF_PIPELINE_JSON,
            value: {
                ...pipeline,
                // <- TODO: Probbably deeply clone the pipeline because `$exportJson` freezes the subobjects
                title,
                knowledgeSources: knowledgeSourcesPrepared,
                knowledgePieces: knowledgePiecesPrepared,
                tasks: [...tasksPrepared],
                // <- TODO: [🪓] Here should be no need for spreading new array, just ` tasks: tasksPrepared`
                personas: preparedPersonas,
                preparations: [...preparations],
                // <- TODO: [🪓] Here should be no need for spreading new array, just `preparations`
            },
        });
    }
    /**
     * TODO: Write tests for `preparePipeline` and `preparePipelineOnRemoteServer`
     * TODO: [🏏] Leverage the batch API and build queues @see https://platform.openai.com/docs/guides/batch
     * TODO: [🧊] In future one preparation can take data from previous preparation and save tokens and time
     * TODO: [🛠] Actions, instruments (and maybe knowledge) => Functions and tools
     * TODO: [🧠][♏] Maybe if expecting JSON (In Anthropic Claude and other models without non-json) and its not specified in prompt content, append the instructions
     *       @see https://docs.anthropic.com/en/docs/test-and-evaluate/strengthen-guardrails/increase-consistency#specify-the-desired-output-format
     */

    /**
     * Format either small or big number
     *
     * @public exported from `@promptbook/utils`
     */
    function numberToString(value) {
        if (value === 0) {
            return '0';
        }
        else if (Number.isNaN(value)) {
            return VALUE_STRINGS.nan;
        }
        else if (value === Infinity) {
            return VALUE_STRINGS.infinity;
        }
        else if (value === -Infinity) {
            return VALUE_STRINGS.negativeInfinity;
        }
        for (let exponent = 0; exponent < 15; exponent++) {
            const factor = 10 ** exponent;
            const valueRounded = Math.round(value * factor) / factor;
            if (Math.abs(value - valueRounded) / value < SMALL_NUMBER) {
                return valueRounded.toFixed(exponent);
            }
        }
        return value.toString();
    }

    /**
     * Function `valueToString` will convert the given value to string
     * This is useful and used in the `templateParameters` function
     *
     * Note: This function is not just calling `toString` method
     *       It's more complex and can handle this conversion specifically for LLM models
     *       See `VALUE_STRINGS`
     *
     * Note: There are 2 similar functions
     * - `valueToString` converts value to string for LLM models as human-readable string
     * - `asSerializable` converts value to string to preserve full information to be able to convert it back
     *
     * @public exported from `@promptbook/utils`
     */
    function valueToString(value) {
        try {
            if (value === '') {
                return VALUE_STRINGS.empty;
            }
            else if (value === null) {
                return VALUE_STRINGS.null;
            }
            else if (value === undefined) {
                return VALUE_STRINGS.undefined;
            }
            else if (typeof value === 'string') {
                return value;
            }
            else if (typeof value === 'number') {
                return numberToString(value);
            }
            else if (value instanceof Date) {
                return value.toISOString();
            }
            else {
                try {
                    return JSON.stringify(value);
                }
                catch (error) {
                    if (error instanceof TypeError && error.message.includes('circular structure')) {
                        return VALUE_STRINGS.circular;
                    }
                    throw error;
                }
            }
        }
        catch (error) {
            assertsError(error);
            console.error(error);
            return VALUE_STRINGS.unserializable;
        }
    }

    /**
     * Parses the given script and returns the list of all used variables that are not defined in the script
     *
     * @param script from which to extract the variables
     * @returns the list of variable names
     * @throws {ParseError} if the script is invalid
     * @public exported from `@promptbook/javascript`
     */
    function extractVariablesFromJavascript(script) {
        const variables = new Set();
        const originalScript = script;
        script = `(()=>{${script}})()`;
        try {
            for (let i = 0; i < LOOP_LIMIT; i++)
                try {
                    eval(script); // <- TODO: Use `JavascriptExecutionTools.execute` here
                }
                catch (error) {
                    if (!(error instanceof ReferenceError)) {
                        throw error;
                    }
                    /*
                    Note: Parsing the error
                          🌟 Most devices:
                          [PipelineUrlError: thing is not defined]

                          🍏 iPhone`s Safari:
                          [PipelineUrlError: Can't find variable: thing]
                    */
                    let variableName = undefined;
                    if (error.message.startsWith(`Can't`)) {
                        // 🍏 Case
                        variableName = error.message.split(' ').pop();
                    }
                    else {
                        // 🌟 Case
                        variableName = error.message.split(' ').shift();
                    }
                    if (variableName === undefined) {
                        throw error;
                    }
                    if (script.includes(variableName + '(')) {
                        script = `const ${variableName} = ()=>'';` + script;
                    }
                    else {
                        variables.add(variableName);
                        script = `const ${variableName} = '';` + script;
                    }
                }
        }
        catch (error) {
            assertsError(error);
            throw new ParseError(spaceTrim.spaceTrim((block) => `
                    Can not extract variables from the script
                    ${block(error.stack || error.message)}

                    Found variables:
                    ${Array.from(variables)
            .map((variableName, i) => `${i + 1}) ${variableName}`)
            .join('\n')}


                    The script:

                    \`\`\`javascript
                    ${block(originalScript)}
                    \`\`\`
                `));
        }
        return variables;
    }
    /**
     * TODO: [🔣] Support for multiple languages - python, java,...
     */

    /**
     * Parses the task and returns the set of all used parameters
     *
     * @param task the task with used parameters
     * @returns the set of parameter names
     * @throws {ParseError} if the script is invalid
     * @public exported from `@promptbook/core` <- Note: [👖] This utility is so tightly interconnected with the Promptbook that it is not exported as util but in core
     */
    function extractParameterNamesFromTask(task) {
        const { title, description, taskType, content, preparedContent, jokerParameterNames, foreach } = task;
        const parameterNames = new Set();
        let contentParameters;
        if (taskType !== 'SCRIPT_TASK') {
            contentParameters = extractParameterNames(content);
        }
        else {
            // TODO: What if script is not javascript?
            // const { contentLanguage } = task;
            // if (contentLanguage !== 'javascript') {
            contentParameters = extractVariablesFromJavascript(content);
        }
        for (const parameterName of [
            ...extractParameterNames(title),
            ...extractParameterNames(description || ''),
            ...contentParameters,
            ...extractParameterNames(preparedContent || ''),
        ]) {
            parameterNames.add(parameterName);
        }
        for (const jokerName of jokerParameterNames || []) {
            parameterNames.add(jokerName);
        }
        parameterNames.delete('content');
        //                      <- Note {websiteContent} is used in `preparedContent`
        // Note: [🍭] Fixing dependent subparameterName from FOREACH command
        if (foreach !== undefined) {
            for (const subparameterName of foreach.inputSubparameterNames) {
                if (parameterNames.has(subparameterName)) {
                    parameterNames.delete(subparameterName);
                    parameterNames.add(foreach.parameterName);
                    // <- TODO: [🏮] Warn/logic error when `subparameterName` not used
                }
            }
        }
        return parameterNames;
    }
    /**
     * TODO: [🔣] If script require contentLanguage
     */

    /**
     * Create difference set of two sets.
     *
     * @deprecated use new javascript set methods instead @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set
     * @public exported from `@promptbook/utils`
     */
    function difference(a, b, isEqual = (a, b) => a === b) {
        const diff = new Set();
        for (const itemA of Array.from(a)) {
            if (!Array.from(b).some((itemB) => isEqual(itemA, itemB))) {
                diff.add(itemA);
            }
        }
        return diff;
    }
    /**
     * TODO: [🧠][💯] Maybe also implement symmetricDifference
     */

    /**
     * Creates a new set with all elements that are present in either set
     *
     * @deprecated use new javascript set methods instead @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set
     * @public exported from `@promptbook/utils`
     */
    function union(...sets) {
        const union = new Set();
        for (const set of sets) {
            for (const item of Array.from(set)) {
                union.add(item);
            }
        }
        return union;
    }

    /**
     * @@@
     *
     * @public exported from `@promptbook/core`
     */
    const MANDATORY_CSV_SETTINGS = Object.freeze({
        header: true,
        // encoding: 'utf-8',
    });

    /**
     * Function to check if a string is valid CSV
     *
     * @param value The string to check
     * @returns True if the string is a valid CSV string, false otherwise
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidCsvString(value) {
        try {
            // A simple check for CSV format: at least one comma and no invalid characters
            if (value.includes(',') && /^[\w\s,"']+$/.test(value)) {
                return true;
            }
            return false;
        }
        catch (error) {
            assertsError(error);
            return false;
        }
    }

    /**
     * Definition for CSV spreadsheet
     *
     * @public exported from `@promptbook/core`
     *                          <- TODO: [🏢] Export from package `@promptbook/csv`
     */
    const CsvFormatDefinition = {
        formatName: 'CSV',
        aliases: ['SPREADSHEET', 'TABLE'],
        isValid(value, settings, schema) {
            return isValidCsvString(value);
        },
        canBeValid(partialValue, settings, schema) {
            return true;
        },
        heal(value, settings, schema) {
            throw new Error('Not implemented');
        },
        subvalueDefinitions: [
            {
                subvalueName: 'ROW',
                async mapValues(value, outputParameterName, settings, mapCallback) {
                    // TODO: [👨🏾‍🤝‍👨🏼] DRY csv parsing
                    const csv = papaparse.parse(value, { ...settings, ...MANDATORY_CSV_SETTINGS });
                    if (csv.errors.length !== 0) {
                        throw new CsvFormatError(spaceTrim__default["default"]((block) => `
                                CSV parsing error

                                Error(s) from CSV parsing:
                                ${block(csv.errors.map((error) => error.message).join('\n\n'))}

                                The CSV setings:
                                ${block(JSON.stringify({ ...settings, ...MANDATORY_CSV_SETTINGS }, null, 2))}

                                The CSV data:
                                ${block(value)}
                            `));
                    }
                    const mappedData = await Promise.all(csv.data.map(async (row, index) => {
                        if (row[outputParameterName]) {
                            throw new CsvFormatError(`Can not overwrite existing column "${outputParameterName}" in CSV row`);
                        }
                        return {
                            ...row,
                            [outputParameterName]: await mapCallback(row, index),
                        };
                    }));
                    return papaparse.unparse(mappedData, { ...settings, ...MANDATORY_CSV_SETTINGS });
                },
            },
            {
                subvalueName: 'CELL',
                async mapValues(value, outputParameterName, settings, mapCallback) {
                    // TODO: [👨🏾‍🤝‍👨🏼] DRY csv parsing
                    const csv = papaparse.parse(value, { ...settings, ...MANDATORY_CSV_SETTINGS });
                    if (csv.errors.length !== 0) {
                        throw new CsvFormatError(spaceTrim__default["default"]((block) => `
                                CSV parsing error

                                Error(s) from CSV parsing:
                                ${block(csv.errors.map((error) => error.message).join('\n\n'))}

                                The CSV setings:
                                ${block(JSON.stringify({ ...settings, ...MANDATORY_CSV_SETTINGS }, null, 2))}

                                The CSV data:
                                ${block(value)}
                            `));
                    }
                    const mappedData = await Promise.all(csv.data.map(async (row, rowIndex) => {
                        return /* not await */ Promise.all(Object.entries(row).map(async ([key, value], columnIndex) => {
                            const index = rowIndex * Object.keys(row).length + columnIndex;
                            return /* not await */ mapCallback({ [key]: value }, index);
                        }));
                    }));
                    return papaparse.unparse(mappedData, { ...settings, ...MANDATORY_CSV_SETTINGS });
                },
            },
        ],
    };
    /**
     * TODO: [🍓] In `CsvFormatDefinition` implement simple `isValid`
     * TODO: [🍓] In `CsvFormatDefinition` implement partial `canBeValid`
     * TODO: [🍓] In `CsvFormatDefinition` implement `heal
     * TODO: [🍓] In `CsvFormatDefinition` implement `subvalueDefinitions`
     * TODO: [🏢] Allow to expect something inside CSV objects and other formats
     */

    /**
     * Definition for JSON format
     *
     * @private still in development [🏢]
     */
    const JsonFormatDefinition = {
        formatName: 'JSON',
        mimeType: 'application/json',
        isValid(value, settings, schema) {
            return isValidJsonString(value);
        },
        canBeValid(partialValue, settings, schema) {
            return true;
        },
        heal(value, settings, schema) {
            throw new Error('Not implemented');
        },
        subvalueDefinitions: [],
    };
    /**
     * TODO: [🧠] Maybe propper instance of object
     * TODO: [0] Make string_serialized_json
     * TODO: [1] Make type for JSON Settings and Schema
     * TODO: [🧠] What to use for validating JSONs - JSON Schema, ZoD, typescript types/interfaces,...?
     * TODO: [🍓] In `JsonFormatDefinition` implement simple `isValid`
     * TODO: [🍓] In `JsonFormatDefinition` implement partial `canBeValid`
     * TODO: [🍓] In `JsonFormatDefinition` implement `heal
     * TODO: [🍓] In `JsonFormatDefinition` implement `subvalueDefinitions`
     * TODO: [🏢] Allow to expect something inside JSON objects and other formats
     */

    /**
     * Definition for any text - this will be always valid
     *
     * Note: This is not useful for validation, but for splitting and mapping with `subvalueDefinitions`
     *
     * @public exported from `@promptbook/core`
     */
    const TextFormatDefinition = {
        formatName: 'TEXT',
        isValid(value) {
            return typeof value === 'string';
        },
        canBeValid(partialValue) {
            return typeof partialValue === 'string';
        },
        heal() {
            throw new UnexpectedError('It does not make sense to call `TextFormatDefinition.heal`');
        },
        subvalueDefinitions: [
            {
                subvalueName: 'LINE',
                async mapValues(value, outputParameterName, settings, mapCallback) {
                    const lines = value.split('\n');
                    const mappedLines = await Promise.all(lines.map((lineContent, lineNumber) => 
                    // TODO: [🧠] Maybe option to skip empty line
                    /* not await */ mapCallback({
                        lineContent,
                        // TODO: [🧠] Maybe also put here `lineNumber`
                    }, lineNumber)));
                    return mappedLines.join('\n');
                },
            },
            // <- TODO: [🧠][🤠] Here should be all words, characters, lines, paragraphs, pages available as subvalues
        ],
    };
    /**
     * TODO: [1] Make type for XML Text and Schema
     * TODO: [🧠][🤠] Here should be all words, characters, lines, paragraphs, pages available as subvalues
     * TODO: [🍓] In `TextFormatDefinition` implement simple `isValid`
     * TODO: [🍓] In `TextFormatDefinition` implement partial `canBeValid`
     * TODO: [🍓] In `TextFormatDefinition` implement `heal
     * TODO: [🍓] In `TextFormatDefinition` implement `subvalueDefinitions`
     * TODO: [🏢] Allow to expect something inside each item of list and other formats
     */

    /**
     * Function to check if a string is valid XML
     *
     * @param value
     * @returns True if the string is a valid XML string, false otherwise
     *
     * @public exported from `@promptbook/utils`
     */
    function isValidXmlString(value) {
        try {
            const parser = new DOMParser();
            const parsedDocument = parser.parseFromString(value, 'application/xml');
            const parserError = parsedDocument.getElementsByTagName('parsererror');
            if (parserError.length > 0) {
                return false;
            }
            return true;
        }
        catch (error) {
            assertsError(error);
            return false;
        }
    }

    /**
     * Definition for XML format
     *
     * @private still in development [🏢]
     */
    const XmlFormatDefinition = {
        formatName: 'XML',
        mimeType: 'application/xml',
        isValid(value, settings, schema) {
            return isValidXmlString(value);
        },
        canBeValid(partialValue, settings, schema) {
            return true;
        },
        heal(value, settings, schema) {
            throw new Error('Not implemented');
        },
        subvalueDefinitions: [],
    };
    /**
     * TODO: [🧠] Maybe propper instance of object
     * TODO: [0] Make string_serialized_xml
     * TODO: [1] Make type for XML Settings and Schema
     * TODO: [🧠] What to use for validating XMLs - XSD,...
     * TODO: [🍓] In `XmlFormatDefinition` implement simple `isValid`
     * TODO: [🍓] In `XmlFormatDefinition` implement partial `canBeValid`
     * TODO: [🍓] In `XmlFormatDefinition` implement `heal
     * TODO: [🍓] In `XmlFormatDefinition` implement `subvalueDefinitions`
     * TODO: [🏢] Allow to expect something inside XML and other formats
     */

    /**
     * Definitions for all formats supported by Promptbook
     *
     * @private internal index of `...` <- TODO [🏢]
     */
    const FORMAT_DEFINITIONS = [
        JsonFormatDefinition,
        XmlFormatDefinition,
        TextFormatDefinition,
        CsvFormatDefinition,
    ];
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Maps available parameters to expected parameters
     *
     * The strategy is:
     * 1) @@@
     * 2) @@@
     *
     * @throws {PipelineExecutionError} @@@
     * @private within the repository used in `createPipelineExecutor`
     */
    function mapAvailableToExpectedParameters(options) {
        const { expectedParameters, availableParameters } = options;
        const availableParametersNames = new Set(Object.keys(availableParameters));
        const expectedParameterNames = new Set(Object.keys(expectedParameters));
        const mappedParameters = {};
        // Phase 1️⃣: Matching mapping
        for (const parameterName of Array.from(union(availableParametersNames, expectedParameterNames))) {
            // Situation: Parameter is available and expected
            if (availableParametersNames.has(parameterName) && expectedParameterNames.has(parameterName)) {
                mappedParameters[parameterName] = availableParameters[parameterName];
                // <- Note: [👩‍👩‍👧] Maybe detect parameter collision here?
                availableParametersNames.delete(parameterName);
                expectedParameterNames.delete(parameterName);
            }
            // Situation: Parameter is available but NOT expected
            else if (availableParametersNames.has(parameterName) && !expectedParameterNames.has(parameterName)) ;
            // Situation: Parameter is NOT available BUT expected
            else if (!availableParametersNames.has(parameterName) && expectedParameterNames.has(parameterName)) ;
        }
        if (expectedParameterNames.size === 0) {
            // Note: [👨‍👨‍👧] Now we can freeze `mappedParameters` to prevent @@@
            Object.freeze(mappedParameters);
            return mappedParameters;
        }
        // Phase 2️⃣: Non-matching mapping
        if (expectedParameterNames.size !== availableParametersNames.size) {
            throw new PipelineExecutionError(spaceTrim__default["default"]((block) => `
                    Can not map available parameters to expected parameters

                    Mapped parameters:
                    ${block(Object.keys(mappedParameters)
            .map((parameterName) => `- {${parameterName}}`)
            .join('\n'))}

                    Expected parameters which can not be mapped:
                    ${block(Array.from(expectedParameterNames)
            .map((parameterName) => `- {${parameterName}}`)
            .join('\n'))}

                    Remaining available parameters:
                    ${block(Array.from(availableParametersNames)
            .map((parameterName) => `- {${parameterName}}`)
            .join('\n'))}

                `));
        }
        const expectedParameterNamesArray = Array.from(expectedParameterNames);
        const availableParametersNamesArray = Array.from(availableParametersNames);
        for (let i = 0; i < expectedParameterNames.size; i++) {
            mappedParameters[expectedParameterNamesArray[i]] = availableParameters[availableParametersNamesArray[i]];
        }
        // Note: [👨‍👨‍👧] Now we can freeze `mappedParameters` to prevent @@@
        Object.freeze(mappedParameters);
        return mappedParameters;
    }

    /**
     * Replaces parameters in template with values from parameters object
     *
     * Note: This function is not places strings into string,
     *       It's more complex and can handle this operation specifically for LLM models
     *
     * @param template the template with parameters in {curly} braces
     * @param parameters the object with parameters
     * @returns the template with replaced parameters
     * @throws {PipelineExecutionError} if parameter is not defined, not closed, or not opened
     * @public exported from `@promptbook/utils`
     */
    function templateParameters(template, parameters) {
        for (const [parameterName, parameterValue] of Object.entries(parameters)) {
            if (parameterValue === RESERVED_PARAMETER_MISSING_VALUE) {
                throw new UnexpectedError(`Parameter \`{${parameterName}}\` has missing value`);
            }
            else if (parameterValue === RESERVED_PARAMETER_RESTRICTED) {
                // TODO: [🍵]
                throw new UnexpectedError(`Parameter \`{${parameterName}}\` is restricted to use`);
            }
        }
        let replacedTemplates = template;
        let match;
        let loopLimit = LOOP_LIMIT;
        while ((match = /^(?<precol>.*){(?<parameterName>\w+)}(.*)/m /* <- Not global */
            .exec(replacedTemplates))) {
            if (loopLimit-- < 0) {
                throw new LimitReachedError('Loop limit reached during parameters replacement in `templateParameters`');
            }
            const precol = match.groups.precol;
            const parameterName = match.groups.parameterName;
            if (parameterName === '') {
                // Note: Skip empty placeholders. It's used to avoid confusion with JSON-like strings
                continue;
            }
            if (parameterName.indexOf('{') !== -1 || parameterName.indexOf('}') !== -1) {
                throw new PipelineExecutionError('Parameter is already opened or not closed');
            }
            if (parameters[parameterName] === undefined) {
                throw new PipelineExecutionError(`Parameter \`{${parameterName}}\` is not defined`);
            }
            let parameterValue = parameters[parameterName];
            if (parameterValue === undefined) {
                throw new PipelineExecutionError(`Parameter \`{${parameterName}}\` is not defined`);
            }
            parameterValue = valueToString(parameterValue);
            // Escape curly braces in parameter values to prevent prompt-injection
            parameterValue = parameterValue.replace(/[{}]/g, '\\$&');
            if (parameterValue.includes('\n') && /^\s*\W{0,3}\s*$/.test(precol)) {
                parameterValue = parameterValue
                    .split('\n')
                    .map((line, index) => (index === 0 ? line : `${precol}${line}`))
                    .join('\n');
            }
            replacedTemplates =
                replacedTemplates.substring(0, match.index + precol.length) +
                    parameterValue +
                    replacedTemplates.substring(match.index + precol.length + parameterName.length + 2);
        }
        // [💫] Check if there are parameters that are not closed properly
        if (/{\w+$/.test(replacedTemplates)) {
            throw new PipelineExecutionError('Parameter is not closed');
        }
        // [💫] Check if there are parameters that are not opened properly
        if (/^\w+}/.test(replacedTemplates)) {
            throw new PipelineExecutionError('Parameter is not opened');
        }
        return replacedTemplates;
    }

    /**
     * Counts number of characters in the text
     *
     * @public exported from `@promptbook/utils`
     */
    function countCharacters(text) {
        // Remove null characters
        text = text.replace(/\0/g, '');
        // Replace emojis (and also ZWJ sequence) with hyphens
        text = text.replace(/(\p{Extended_Pictographic})\p{Modifier_Symbol}/gu, '$1');
        text = text.replace(/(\p{Extended_Pictographic})[\u{FE00}-\u{FE0F}]/gu, '$1');
        text = text.replace(/\p{Extended_Pictographic}(\u{200D}\p{Extended_Pictographic})*/gu, '-');
        return text.length;
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Number of characters per standard line with 11pt Arial font size.
     *
     * @public exported from `@promptbook/utils`
     */
    const CHARACTERS_PER_STANDARD_LINE = 63;
    /**
     * Number of lines per standard A4 page with 11pt Arial font size and standard margins and spacing.
     *
     * @public exported from `@promptbook/utils`
     */
    const LINES_PER_STANDARD_PAGE = 44;
    /**
     * TODO: [🧠] Should be this `constants.ts` or `config.ts`?
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Counts number of lines in the text
     *
     * Note: This does not check only for the presence of newlines, but also for the length of the standard line.
     *
     * @public exported from `@promptbook/utils`
     */
    function countLines(text) {
        text = text.replace('\r\n', '\n');
        text = text.replace('\r', '\n');
        const lines = text.split('\n');
        return lines.reduce((count, line) => count + Math.ceil(line.length / CHARACTERS_PER_STANDARD_LINE), 0);
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Counts number of pages in the text
     *
     * Note: This does not check only for the count of newlines, but also for the length of the standard line and length of the standard page.
     *
     * @public exported from `@promptbook/utils`
     */
    function countPages(text) {
        return Math.ceil(countLines(text) / LINES_PER_STANDARD_PAGE);
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Counts number of paragraphs in the text
     *
     * @public exported from `@promptbook/utils`
     */
    function countParagraphs(text) {
        return text.split(/\n\s*\n/).filter((paragraph) => paragraph.trim() !== '').length;
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Split text into sentences
     *
     * @public exported from `@promptbook/utils`
     */
    function splitIntoSentences(text) {
        return text.split(/[.!?]+/).filter((sentence) => sentence.trim() !== '');
    }
    /**
     * Counts number of sentences in the text
     *
     * @public exported from `@promptbook/utils`
     */
    function countSentences(text) {
        return splitIntoSentences(text).length;
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Counts number of words in the text
     *
     * @public exported from `@promptbook/utils`
     */
    function countWords(text) {
        text = text.replace(/[\p{Extended_Pictographic}]/gu, 'a');
        text = removeDiacritics(text);
        // Add spaces before uppercase letters preceded by lowercase letters (for camelCase)
        text = text.replace(/([a-z])([A-Z])/g, '$1 $2');
        return text.split(/[^a-zа-я0-9]+/i).filter((word) => word.length > 0).length;
    }
    /**
     * TODO: [🥴] Implement counting in formats - like JSON, CSV, XML,...
     */

    /**
     * Index of all counter functions
     *
     * @public exported from `@promptbook/utils`
     */
    const CountUtils = {
        CHARACTERS: countCharacters,
        WORDS: countWords,
        SENTENCES: countSentences,
        PARAGRAPHS: countParagraphs,
        LINES: countLines,
        PAGES: countPages,
    };
    /**
     * TODO: [🧠][🤠] This should be probbably as part of `TextFormatDefinition`
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Function checkExpectations will check if the expectations on given value are met
     *
     * Note: There are two simmilar functions:
     * - `checkExpectations` which throws an error if the expectations are not met
     * - `isPassingExpectations` which returns a boolean
     *
     * @throws {ExpectError} if the expectations are not met
     * @returns {void} Nothing
     * @private internal function of `createPipelineExecutor`
     */
    function checkExpectations(expectations, value) {
        for (const [unit, { max, min }] of Object.entries(expectations)) {
            const amount = CountUtils[unit.toUpperCase()](value);
            if (min && amount < min) {
                throw new ExpectError(`Expected at least ${min} ${unit} but got ${amount}`);
            } /* not else */
            if (max && amount > max) {
                throw new ExpectError(`Expected at most ${max} ${unit} but got ${amount}`);
            }
        }
    }
    /**
     * TODO: [💝] Unite object for expecting amount and format
     * TODO: [🧠][🤠] This should be part of `TextFormatDefinition`
     * Note: [💝] and [🤠] are interconnected together
     */

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function executeAttempts(options) {
        const { jokerParameterNames, priority, maxAttempts, // <- Note: [💂]
        preparedContent, parameters, task, preparedPipeline, tools, $executionReport, pipelineIdentification, maxExecutionAttempts, } = options;
        const $ongoingTaskResult = {
            $result: null,
            $resultString: null,
            $expectError: null,
            $scriptPipelineExecutionErrors: [],
        };
        // TODO: [🚐] Make arrayable LLMs -> single LLM DRY
        const _llms = arrayableToArray(tools.llm);
        const llmTools = _llms.length === 1 ? _llms[0] : joinLlmExecutionTools(..._llms);
        attempts: for (let attempt = -jokerParameterNames.length; attempt < maxAttempts; attempt++) {
            const isJokerAttempt = attempt < 0;
            const jokerParameterName = jokerParameterNames[jokerParameterNames.length + attempt];
            // TODO: [🧠][🍭] JOKERS, EXPECTATIONS, POSTPROCESSING and FOREACH
            if (isJokerAttempt && !jokerParameterName) {
                throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                        Joker not found in attempt ${attempt}

                        ${block(pipelineIdentification)}
                    `));
            }
            $ongoingTaskResult.$result = null;
            $ongoingTaskResult.$resultString = null;
            $ongoingTaskResult.$expectError = null;
            if (isJokerAttempt) {
                if (parameters[jokerParameterName] === undefined) {
                    throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                            Joker parameter {${jokerParameterName}} not defined

                            ${block(pipelineIdentification)}
                        `));
                    // <- TODO: This is maybe `PipelineLogicError` which should be detected in `validatePipeline` and here just thrown as `UnexpectedError`
                }
                else {
                    $ongoingTaskResult.$resultString = parameters[jokerParameterName];
                }
            }
            try {
                if (!isJokerAttempt) {
                    taskType: switch (task.taskType) {
                        case 'SIMPLE_TASK':
                            $ongoingTaskResult.$resultString = templateParameters(preparedContent, parameters);
                            break taskType;
                        case 'PROMPT_TASK':
                            {
                                const modelRequirements = {
                                    modelVariant: 'CHAT',
                                    ...(preparedPipeline.defaultModelRequirements || {}),
                                    ...(task.modelRequirements || {}),
                                }; /* <- Note: [🤛] */
                                $ongoingTaskResult.$prompt = {
                                    title: task.title,
                                    pipelineUrl: `${preparedPipeline.pipelineUrl
                                    ? preparedPipeline.pipelineUrl
                                    : 'anonymous' /* <- TODO: [🧠] How to deal with anonymous pipelines, do here some auto-url like SHA-256 based ad-hoc identifier? */}#${task.name
                                // <- TODO: Here should be maybe also subformat index to distinguish between same task with different subformat values
                                }`,
                                    parameters,
                                    content: preparedContent,
                                    modelRequirements,
                                    expectations: {
                                        ...(preparedPipeline.personas.find(({ name }) => name === task.personaName) || {}),
                                        ...task.expectations,
                                    },
                                    format: task.format,
                                    postprocessingFunctionNames: task.postprocessingFunctionNames,
                                }; // <- TODO: Not very good type guard
                                variant: switch (modelRequirements.modelVariant) {
                                    case 'CHAT':
                                        $ongoingTaskResult.$chatResult = await llmTools.callChatModel(
                                        // <- TODO: [🧁] Check that `callChatModel` is defined
                                        $deepFreeze($ongoingTaskResult.$prompt));
                                        // TODO: [🍬] Destroy chatThread
                                        $ongoingTaskResult.$result = $ongoingTaskResult.$chatResult;
                                        $ongoingTaskResult.$resultString = $ongoingTaskResult.$chatResult.content;
                                        break variant;
                                    case 'COMPLETION':
                                        $ongoingTaskResult.$completionResult = await llmTools.callCompletionModel(
                                        // <- TODO: [🧁] Check that `callCompletionModel` is defined
                                        $deepFreeze($ongoingTaskResult.$prompt));
                                        $ongoingTaskResult.$result = $ongoingTaskResult.$completionResult;
                                        $ongoingTaskResult.$resultString = $ongoingTaskResult.$completionResult.content;
                                        break variant;
                                    case 'EMBEDDING':
                                        throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                                Embedding model can not be used in pipeline

                                                This should be catched during parsing

                                                ${block(pipelineIdentification)}

                                            `));
                                        break variant;
                                    // <- case [🤖]:
                                    default:
                                        throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                                Unknown model variant "${task.modelRequirements.modelVariant}"

                                                ${block(pipelineIdentification)}

                                            `));
                                }
                            }
                            break;
                        case 'SCRIPT_TASK':
                            if (arrayableToArray(tools.script).length === 0) {
                                throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                        No script execution tools are available

                                        ${block(pipelineIdentification)}
                                    `));
                            }
                            if (!task.contentLanguage) {
                                throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                        Script language is not defined for SCRIPT TASK "${task.name}"

                                        ${block(pipelineIdentification)}
                                    `));
                            }
                            // TODO: DRY [☯]
                            scripts: for (const scriptTools of arrayableToArray(tools.script)) {
                                try {
                                    $ongoingTaskResult.$resultString = await scriptTools.execute($deepFreeze({
                                        scriptLanguage: task.contentLanguage,
                                        script: preparedContent,
                                        parameters,
                                    }));
                                    break scripts;
                                }
                                catch (error) {
                                    assertsError(error);
                                    if (error instanceof UnexpectedError) {
                                        throw error;
                                    }
                                    $ongoingTaskResult.$scriptPipelineExecutionErrors.push(error);
                                }
                            }
                            if ($ongoingTaskResult.$resultString !== null) {
                                break taskType;
                            }
                            if ($ongoingTaskResult.$scriptPipelineExecutionErrors.length === 1) {
                                throw $ongoingTaskResult.$scriptPipelineExecutionErrors[0];
                            }
                            else {
                                throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                        Script execution failed ${$ongoingTaskResult.$scriptPipelineExecutionErrors.length}x

                                        ${block(pipelineIdentification)}

                                        ${block($ongoingTaskResult.$scriptPipelineExecutionErrors
                                .map((error) => '- ' + error.message)
                                .join('\n\n'))}
                                    `));
                            }
                            // Note: This line is unreachable because of the break taskType above
                            break taskType;
                        case 'DIALOG_TASK':
                            if (tools.userInterface === undefined) {
                                throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                        User interface tools are not available

                                        ${block(pipelineIdentification)}
                                    `));
                            }
                            // TODO: [🌹] When making next attempt for `DIALOG TASK`, preserve the previous user input
                            $ongoingTaskResult.$resultString = await tools.userInterface.promptDialog($deepFreeze({
                                promptTitle: task.title,
                                promptMessage: templateParameters(task.description || '', parameters),
                                defaultValue: templateParameters(preparedContent, parameters),
                                // TODO: [🧠] Figure out how to define placeholder in .book.md file
                                placeholder: undefined,
                                priority,
                            }));
                            break taskType;
                        // <- case: [🅱]
                        default:
                            throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                    Unknown execution type "${task.taskType}"

                                    ${block(pipelineIdentification)}
                                `));
                    }
                }
                if (!isJokerAttempt && task.postprocessingFunctionNames) {
                    for (const functionName of task.postprocessingFunctionNames) {
                        let postprocessingError = null;
                        scripts: for (const scriptTools of arrayableToArray(tools.script)) {
                            try {
                                $ongoingTaskResult.$resultString = await scriptTools.execute({
                                    scriptLanguage: `javascript` /* <- TODO: Try it in each languages; In future allow postprocessing with arbitrary combination of languages to combine */,
                                    script: `${functionName}(resultString)`,
                                    parameters: {
                                        resultString: $ongoingTaskResult.$resultString || '',
                                        // Note: No ...parametersForTask, because working with result only
                                    },
                                });
                                postprocessingError = null;
                                break scripts;
                            }
                            catch (error) {
                                assertsError(error);
                                if (error instanceof UnexpectedError) {
                                    throw error;
                                }
                                postprocessingError = error;
                                $ongoingTaskResult.$scriptPipelineExecutionErrors.push(error);
                            }
                        }
                        if (postprocessingError) {
                            throw postprocessingError;
                        }
                    }
                }
                // TODO: [💝] Unite object for expecting amount and format
                if (task.format) {
                    if (task.format === 'JSON') {
                        if (!isValidJsonString($ongoingTaskResult.$resultString || '')) {
                            // TODO: [🏢] Do more universally via `FormatDefinition`
                            try {
                                $ongoingTaskResult.$resultString = extractJsonBlock($ongoingTaskResult.$resultString || '');
                            }
                            catch (error) {
                                keepUnused(error);
                                throw new ExpectError(spaceTrim.spaceTrim((block) => `
                                        Expected valid JSON string

                                        ${block(
                            /*<- Note: No need for `pipelineIdentification`, it will be catched and added later */ '')}
                                    `));
                            }
                        }
                    }
                    else {
                        throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                                Unknown format "${task.format}"

                                ${block(pipelineIdentification)}
                            `));
                    }
                }
                // TODO: [💝] Unite object for expecting amount and format
                if (task.expectations) {
                    checkExpectations(task.expectations, $ongoingTaskResult.$resultString || '');
                }
                break attempts;
            }
            catch (error) {
                if (!(error instanceof ExpectError)) {
                    throw error;
                }
                $ongoingTaskResult.$expectError = error;
            }
            finally {
                if (!isJokerAttempt &&
                    task.taskType === 'PROMPT_TASK' &&
                    $ongoingTaskResult.$prompt
                //    <- Note:  [2] When some expected parameter is not defined, error will occur in templateParameters
                //              In that case we don’t want to make a report about it because it’s not a llm execution error
                ) {
                    // TODO: [🧠] Maybe put other taskTypes into report
                    $executionReport.promptExecutions.push({
                        prompt: {
                            ...$ongoingTaskResult.$prompt,
                            // <- TODO: [🧠] How to pick everyhing except `pipelineUrl`
                        },
                        result: $ongoingTaskResult.$result || undefined,
                        error: $ongoingTaskResult.$expectError === null
                            ? undefined
                            : serializeError($ongoingTaskResult.$expectError),
                    });
                }
            }
            if ($ongoingTaskResult.$expectError !== null && attempt === maxAttempts - 1) {
                throw new PipelineExecutionError(spaceTrim.spaceTrim((block) => {
                    var _a, _b, _c;
                    return `
                        LLM execution failed ${maxExecutionAttempts}x

                        ${block(pipelineIdentification)}

                        ---
                        The Prompt:
                        ${block((((_a = $ongoingTaskResult.$prompt) === null || _a === void 0 ? void 0 : _a.content) || '')
                    .split('\n')
                    .map((line) => `> ${line}`)
                    .join('\n'))}

                        Last error ${((_b = $ongoingTaskResult.$expectError) === null || _b === void 0 ? void 0 : _b.name) || ''}:
                        ${block((((_c = $ongoingTaskResult.$expectError) === null || _c === void 0 ? void 0 : _c.message) || '')
                    .split('\n')
                    .map((line) => `> ${line}`)
                    .join('\n'))}

                        Last result:
                        ${block($ongoingTaskResult.$resultString === null
                    ? 'null'
                    : spaceTrim.spaceTrim($ongoingTaskResult.$resultString)
                        .split('\n')
                        .map((line) => `> ${line}`)
                        .join('\n'))}
                        ---
                    `;
                }));
            }
        }
        if ($ongoingTaskResult.$resultString === null) {
            throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                    Something went wrong and prompt result is null

                    ${block(pipelineIdentification)}
                `));
        }
        return $ongoingTaskResult.$resultString;
    }
    /**
     * TODO: Break into smaller functions
     */

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function executeFormatSubvalues(options) {
        const { task, jokerParameterNames, parameters, priority, csvSettings, pipelineIdentification } = options;
        if (task.foreach === undefined) {
            return /* not await */ executeAttempts(options);
        }
        if (jokerParameterNames.length !== 0) {
            throw new UnexpectedError(spaceTrim__default["default"]((block) => `
                    JOKER parameters are not supported together with FOREACH command

                    [🧞‍♀️] This should be prevented in \`validatePipeline\`

                    ${block(pipelineIdentification)}
                `));
        }
        const parameterValue = parameters[task.foreach.parameterName] || '';
        const formatDefinition = FORMAT_DEFINITIONS.find((formatDefinition) => [formatDefinition.formatName, ...(formatDefinition.aliases || [])].includes(task.foreach.formatName));
        if (formatDefinition === undefined) {
            throw new UnexpectedError(
            // <- TODO: [🧠][🧐] Should be formats fixed per promptbook version or behave as plugins (=> change UnexpectedError)
            spaceTrim__default["default"]((block) => `
                    Unsupported format "${task.foreach.formatName}"

                    Available formats:
                    ${block(FORMAT_DEFINITIONS.map((formatDefinition) => formatDefinition.formatName)
            .map((formatName) => `- ${formatName}`)
            .join('\n'))}

                    [⛷] This should never happen because format name should be validated during parsing

                    ${block(pipelineIdentification)}
                `));
        }
        const subvalueDefinition = formatDefinition.subvalueDefinitions.find((subvalueDefinition) => [subvalueDefinition.subvalueName, ...(subvalueDefinition.aliases || [])].includes(task.foreach.subformatName));
        if (subvalueDefinition === undefined) {
            throw new UnexpectedError(
            // <- TODO: [🧠][🧐] Should be formats fixed per promptbook version or behave as plugins (=> change UnexpectedError)
            spaceTrim__default["default"]((block) => `
                    Unsupported subformat name "${task.foreach.subformatName}" for format "${task.foreach.formatName}"

                    Available subformat names for format "${formatDefinition.formatName}":
                    ${block(formatDefinition.subvalueDefinitions
            .map((subvalueDefinition) => subvalueDefinition.subvalueName)
            .map((subvalueName) => `- ${subvalueName}`)
            .join('\n'))}

                    [⛷] This should never happen because subformat name should be validated during parsing

                    ${block(pipelineIdentification)}
                `));
        }
        let formatSettings;
        if (formatDefinition.formatName === 'CSV') {
            formatSettings = csvSettings;
            // <- TODO: [🤹‍♂️] More universal, make simmilar pattern for other formats for example \n vs \r\n in text
        }
        const resultString = await subvalueDefinition.mapValues(parameterValue, task.foreach.outputSubparameterName, formatSettings, async (subparameters, index) => {
            let mappedParameters;
            // TODO: [🤹‍♂️][🪂] Limit to N concurrent executions
            // TODO: When done [🐚] Report progress also for each subvalue here
            try {
                mappedParameters = mapAvailableToExpectedParameters({
                    expectedParameters: Object.fromEntries(task.foreach.inputSubparameterNames.map((subparameterName) => [subparameterName, null])),
                    availableParameters: subparameters,
                });
            }
            catch (error) {
                if (!(error instanceof PipelineExecutionError)) {
                    throw error;
                }
                throw new PipelineExecutionError(spaceTrim__default["default"]((block) => `
                        ${error.message}

                        This is error in FOREACH command
                        You have probbably passed wrong data to pipeline or wrong data was generated which are processed by FOREACH command

                        ${block(pipelineIdentification)}
                        Subparameter index: ${index}
                    `));
            }
            const allSubparameters = {
                ...parameters,
                ...mappedParameters,
            };
            // Note: [👨‍👨‍👧] Now we can freeze `subparameters` because we are sure that all and only used parameters are defined and are not going to be changed
            Object.freeze(allSubparameters);
            const subresultString = await executeAttempts({
                ...options,
                priority: priority + index,
                parameters: allSubparameters,
                pipelineIdentification: spaceTrim__default["default"]((block) => `
                        ${block(pipelineIdentification)}
                        Subparameter index: ${index}
                    `),
            });
            return subresultString;
        });
        return resultString;
    }

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function getContextForTask(task) {
        return RESERVED_PARAMETER_MISSING_VALUE /* <- TODO: [🏍] Implement */;
    }

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function getExamplesForTask(task) {
        return RESERVED_PARAMETER_MISSING_VALUE /* <- TODO: [♨] Implement */;
    }

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function getKnowledgeForTask(options) {
        const { preparedPipeline, task } = options;
        return preparedPipeline.knowledgePieces.map(({ content }) => `- ${content}`).join('\n');
        //                                                      <- TODO: [🧠] Some smart aggregation of knowledge pieces, single-line vs multi-line vs mixed
    }

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function getReservedParametersForTask(options) {
        const { preparedPipeline, task, pipelineIdentification } = options;
        const context = await getContextForTask(); // <- [🏍]
        const knowledge = await getKnowledgeForTask({ preparedPipeline, task });
        const examples = await getExamplesForTask();
        const currentDate = new Date().toISOString(); // <- TODO: [🧠][💩] Better
        const modelName = RESERVED_PARAMETER_MISSING_VALUE;
        const reservedParameters = {
            content: RESERVED_PARAMETER_RESTRICTED,
            context,
            knowledge,
            examples,
            currentDate,
            modelName,
        };
        // Note: Doublecheck that ALL reserved parameters are defined:
        for (const parameterName of RESERVED_PARAMETER_NAMES) {
            if (reservedParameters[parameterName] === undefined) {
                throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                        Reserved parameter {${parameterName}} is not defined

                        ${block(pipelineIdentification)}
                    `));
            }
        }
        return reservedParameters;
    }

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function executeTask(options) {
        const { currentTask, preparedPipeline, parametersToPass, tools, onProgress, $executionReport, pipelineIdentification, maxExecutionAttempts, maxParallelCount, csvSettings, isVerbose, rootDirname, cacheDirname, intermediateFilesStrategy, isAutoInstalled, isNotPreparedWarningSupressed, } = options;
        const priority = preparedPipeline.tasks.length - preparedPipeline.tasks.indexOf(currentTask);
        await onProgress({
            outputParameters: {
                [currentTask.resultingParameterName]: '', // <- TODO: [🧠] What is the best value here?
            },
        });
        // Note: Check consistency of used and dependent parameters which was also done in `validatePipeline`, but it’s good to doublecheck
        const usedParameterNames = extractParameterNamesFromTask(currentTask);
        const dependentParameterNames = new Set(currentTask.dependentParameterNames);
        // TODO: [👩🏾‍🤝‍👩🏻] Use here `mapAvailableToExpectedParameters`
        if (union(difference(usedParameterNames, dependentParameterNames), difference(dependentParameterNames, usedParameterNames)).size !== 0) {
            throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                    Dependent parameters are not consistent with used parameters:

                    Dependent parameters:
                    ${Array.from(dependentParameterNames)
            .map((name) => `{${name}}`)
            .join(', ')}

                    Used parameters:
                    ${Array.from(usedParameterNames)
            .map((name) => `{${name}}`)
            .join(', ')}

                    ${block(pipelineIdentification)}

                `));
        }
        const definedParameters = Object.freeze({
            ...(await getReservedParametersForTask({
                preparedPipeline,
                task: currentTask,
                pipelineIdentification,
            })),
            ...parametersToPass,
        });
        const definedParameterNames = new Set(Object.keys(definedParameters));
        const parameters = {};
        // Note: [2] Check that all used parameters are defined and removing unused parameters for this task
        // TODO: [👩🏾‍🤝‍👩🏻] Use here `mapAvailableToExpectedParameters`
        for (const parameterName of Array.from(union(definedParameterNames, usedParameterNames, dependentParameterNames))) {
            // Situation: Parameter is defined and used
            if (definedParameterNames.has(parameterName) && usedParameterNames.has(parameterName)) {
                parameters[parameterName] = definedParameters[parameterName];
            }
            // Situation: Parameter is defined but NOT used
            else if (definedParameterNames.has(parameterName) && !usedParameterNames.has(parameterName)) ;
            // Situation: Parameter is NOT defined BUT used
            else if (!definedParameterNames.has(parameterName) && usedParameterNames.has(parameterName)) {
                // Houston, we have a problem
                // Note: Checking part is also done in `validatePipeline`, but it’s good to doublecheck
                throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                        Parameter \`{${parameterName}}\` is NOT defined
                        BUT used in task "${currentTask.title || currentTask.name}"

                        This should be catched in \`validatePipeline\`

                        ${block(pipelineIdentification)}

                    `));
            }
        }
        // Note: [👨‍👨‍👧] Now we can freeze `parameters` because we are sure that all and only used parameters are defined and are not going to be changed
        Object.freeze(parameters);
        const maxAttempts = currentTask.taskType === 'DIALOG_TASK' ? Infinity : maxExecutionAttempts; // <- Note: [💂]
        const jokerParameterNames = currentTask.jokerParameterNames || [];
        const preparedContent = (currentTask.preparedContent || '{content}').split('{content}').join(currentTask.content);
        //    <- TODO: [🍵] Use here `templateParameters` to replace {websiteContent} with option to ignore missing parameters
        const resultString = await executeFormatSubvalues({
            jokerParameterNames,
            priority,
            maxAttempts,
            preparedContent,
            parameters,
            task: currentTask,
            preparedPipeline,
            tools,
            $executionReport,
            pipelineIdentification,
            maxExecutionAttempts,
            maxParallelCount,
            csvSettings,
            isVerbose,
            rootDirname,
            cacheDirname,
            intermediateFilesStrategy,
            isAutoInstalled,
            isNotPreparedWarningSupressed,
        });
        await onProgress({
            outputParameters: {
                [currentTask.resultingParameterName]: resultString,
            },
        });
        return Object.freeze({
            [currentTask.resultingParameterName]: 
            // <- Note: [👩‍👩‍👧] No need to detect parameter collision here because pipeline checks logic consistency during construction
            resultString,
        });
    }
    /**
     * TODO: [🤹‍♂️]
     */

    /**
     * @@@
     *
     * @private internal utility of `createPipelineExecutor`
     */
    function filterJustOutputParameters(options) {
        const { preparedPipeline, parametersToPass, $warnings, pipelineIdentification } = options;
        const outputParameters = {};
        // Note: Filter ONLY output parameters
        // TODO: [👩🏾‍🤝‍👩🏻] Maybe use here `mapAvailableToExpectedParameters`
        for (const parameter of preparedPipeline.parameters.filter(({ isOutput }) => isOutput)) {
            if (parametersToPass[parameter.name] === undefined) {
                // [4]
                $warnings.push(new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                            Parameter \`{${parameter.name}}\` should be an output parameter, but it was not generated during pipeline execution

                            ${block(pipelineIdentification)}
                        `)));
                continue;
            }
            outputParameters[parameter.name] = parametersToPass[parameter.name] || '';
        }
        return outputParameters;
    }

    /**
     * @@@
     *
     * Note: This is not a `PipelineExecutor` (which is binded with one exact pipeline), but a utility function of `createPipelineExecutor` which creates `PipelineExecutor`
     *
     * @private internal utility of `createPipelineExecutor`
     */
    async function executePipeline(options) {
        const { inputParameters, tools, onProgress, pipeline, setPreparedPipeline, pipelineIdentification, maxParallelCount, rootDirname, isVerbose, } = options;
        let { preparedPipeline } = options;
        if (preparedPipeline === undefined) {
            preparedPipeline = await preparePipeline(pipeline, tools, {
                rootDirname,
                isVerbose,
                maxParallelCount,
            });
            setPreparedPipeline(preparedPipeline);
        }
        const errors = [];
        const warnings = [];
        const executionReport = {
            pipelineUrl: preparedPipeline.pipelineUrl,
            title: preparedPipeline.title,
            promptbookUsedVersion: PROMPTBOOK_ENGINE_VERSION,
            promptbookRequestedVersion: preparedPipeline.bookVersion,
            description: preparedPipeline.description,
            promptExecutions: [],
        };
        /**
         * Note: This is a flag to prevent `onProgress` call after the pipeline execution is finished
         */
        let isReturned = false;
        // Note: Check that all input input parameters are defined
        for (const parameter of preparedPipeline.parameters.filter(({ isInput }) => isInput)) {
            if (inputParameters[parameter.name] === undefined) {
                isReturned = true;
                if (onProgress !== undefined) {
                    // Note: Wait a short time to prevent race conditions
                    await waitasecond.forTime(IMMEDIATE_TIME);
                }
                return exportJson({
                    name: `executionReport`,
                    message: `Unuccessful PipelineExecutorResult (with missing parameter {${parameter.name}}) PipelineExecutorResult`,
                    order: [],
                    value: {
                        isSuccessful: false,
                        errors: [
                            new PipelineExecutionError(`Parameter \`{${parameter.name}}\` is required as an input parameter`),
                            ...errors,
                        ].map(serializeError),
                        warnings: [],
                        executionReport,
                        outputParameters: {},
                        usage: ZERO_USAGE,
                        preparedPipeline,
                    },
                });
            }
        }
        // Note: Check that no extra input parameters are passed
        for (const parameterName of Object.keys(inputParameters)) {
            const parameter = preparedPipeline.parameters.find(({ name }) => name === parameterName);
            if (parameter === undefined) {
                warnings.push(new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                            Extra parameter {${parameterName}} is being passed which is not part of the pipeline.

                            ${block(pipelineIdentification)}
                        `)));
            }
            else if (parameter.isInput === false) {
                isReturned = true;
                if (onProgress !== undefined) {
                    // Note: Wait a short time to prevent race conditions
                    await waitasecond.forTime(IMMEDIATE_TIME);
                }
                // TODO: [🧠] This should be also non-critical error
                return exportJson({
                    name: 'pipelineExecutorResult',
                    message: spaceTrim.spaceTrim((block) => `
                        Unuccessful PipelineExecutorResult (with extra parameter {${parameter.name}}) PipelineExecutorResult

                        ${block(pipelineIdentification)}
                    `),
                    order: [],
                    value: {
                        isSuccessful: false,
                        errors: [
                            new PipelineExecutionError(spaceTrim.spaceTrim((block) => `
                                    Parameter \`{${parameter.name}}\` is passed as input parameter but it is not input

                                    ${block(pipelineIdentification)}
                                `)),
                            ...errors,
                        ].map(serializeError),
                        warnings: warnings.map(serializeError),
                        executionReport,
                        outputParameters: {},
                        usage: ZERO_USAGE,
                        preparedPipeline,
                    },
                });
            }
        }
        let parametersToPass = Object.fromEntries(Object.entries(inputParameters).map(([key, value]) => [key, valueToString(value)]));
        try {
            let resovedParameterNames = preparedPipeline.parameters
                .filter(({ isInput }) => isInput)
                .map(({ name }) => name);
            let unresovedTasks = [...preparedPipeline.tasks];
            let resolving = [];
            let loopLimit = LOOP_LIMIT;
            while (unresovedTasks.length > 0) {
                if (loopLimit-- < 0) {
                    // Note: Really UnexpectedError not LimitReachedError - this should be catched during validatePipeline
                    throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                            Loop limit reached during resolving parameters pipeline execution

                            ${block(pipelineIdentification)}
                        `));
                }
                const currentTask = unresovedTasks.find((task) => task.dependentParameterNames.every((name) => [...resovedParameterNames, ...RESERVED_PARAMETER_NAMES].includes(name)));
                if (!currentTask && resolving.length === 0) {
                    throw new UnexpectedError(
                    // TODO: [🐎] DRY
                    spaceTrim.spaceTrim((block) => `
                            Can not resolve some parameters:

                            ${block(pipelineIdentification)}

                            **Can not resolve:**
                            ${block(unresovedTasks
                    .map(({ resultingParameterName, dependentParameterNames }) => `- Parameter \`{${resultingParameterName}}\` which depends on ${dependentParameterNames
                    .map((dependentParameterName) => `\`{${dependentParameterName}}\``)
                    .join(' and ')}`)
                    .join('\n'))}

                            **Resolved:**
                            ${block(resovedParameterNames
                    .filter((name) => !RESERVED_PARAMETER_NAMES.includes(name))
                    .map((name) => `- Parameter \`{${name}}\``)
                    .join('\n'))}

                            **Reserved (which are available):**
                            ${block(resovedParameterNames
                    .filter((name) => RESERVED_PARAMETER_NAMES.includes(name))
                    .map((name) => `- Parameter \`{${name}}\``)
                    .join('\n'))}

                            *Note: This should be catched in \`validatePipeline\`*
                        `));
                }
                else if (!currentTask) {
                    /* [🤹‍♂️] */ await Promise.race(resolving);
                }
                else {
                    unresovedTasks = unresovedTasks.filter((task) => task !== currentTask);
                    const work = /* [🤹‍♂️] not await */ executeTask({
                        ...options,
                        currentTask,
                        preparedPipeline,
                        parametersToPass,
                        tools,
                        onProgress(newOngoingResult) {
                            if (isReturned) {
                                throw new UnexpectedError(spaceTrim.spaceTrim((block) => `
                                        Can not call \`onProgress\` after pipeline execution is finished

                                        ${block(pipelineIdentification)}

                                        ${block(JSON.stringify(newOngoingResult, null, 4)
                                .split('\n')
                                .map((line) => `> ${line}`)
                                .join('\n'))}
                                    `));
                            }
                            if (onProgress) {
                                onProgress(newOngoingResult);
                            }
                        },
                        $executionReport: executionReport,
                        pipelineIdentification: spaceTrim.spaceTrim((block) => `
                            ${block(pipelineIdentification)}
                            Task name: ${currentTask.name}
                            Task title: ${currentTask.title}
                        `),
                    })
                        .then((newParametersToPass) => {
                        parametersToPass = { ...newParametersToPass, ...parametersToPass };
                        resovedParameterNames = [...resovedParameterNames, currentTask.resultingParameterName];
                    })
                        .then(() => {
                        resolving = resolving.filter((w) => w !== work);
                    });
                    // <- Note: Errors are catched here [3]
                    //    TODO: BUT if in multiple tasks are errors, only the first one is catched so maybe we should catch errors here and save them to errors array here
                    resolving.push(work);
                }
            }
            await Promise.all(resolving);
        }
        catch (error /* <- Note: [3] */) {
            assertsError(error);
            // Note: No need to rethrow UnexpectedError
            // if (error instanceof UnexpectedError) {
            // Note: Count usage, [🧠] Maybe put to separate function executionReportJsonToUsage + DRY [🤹‍♂️]
            const usage = addUsage(...executionReport.promptExecutions.map(({ result }) => (result === null || result === void 0 ? void 0 : result.usage) || ZERO_USAGE));
            // Note: Making this on separate line before `return` to grab errors [4]
            const outputParameters = filterJustOutputParameters({
                preparedPipeline,
                parametersToPass,
                $warnings: warnings,
                pipelineIdentification,
            });
            isReturned = true;
            if (onProgress !== undefined) {
                // Note: Wait a short time to prevent race conditions
                await waitasecond.forTime(IMMEDIATE_TIME);
            }
            return exportJson({
                name: 'pipelineExecutorResult',
                message: `Unuccessful PipelineExecutorResult (with misc errors) PipelineExecutorResult`,
                order: [],
                value: {
                    isSuccessful: false,
                    errors: [error, ...errors].map(serializeError),
                    warnings: warnings.map(serializeError),
                    usage,
                    executionReport,
                    outputParameters,
                    preparedPipeline,
                },
            });
        }
        // Note: Count usage, [🧠] Maybe put to separate function executionReportJsonToUsage + DRY [🤹‍♂️]
        const usage = addUsage(...executionReport.promptExecutions.map(({ result }) => (result === null || result === void 0 ? void 0 : result.usage) || ZERO_USAGE));
        // Note:  Making this on separate line before `return` to grab errors [4]
        const outputParameters = filterJustOutputParameters({
            preparedPipeline,
            parametersToPass,
            $warnings: warnings,
            pipelineIdentification,
        });
        isReturned = true;
        if (onProgress !== undefined) {
            // Note: Wait a short time to prevent race conditions
            await waitasecond.forTime(IMMEDIATE_TIME);
        }
        return exportJson({
            name: 'pipelineExecutorResult',
            message: `Successful PipelineExecutorResult`,
            order: [],
            value: {
                isSuccessful: true,
                errors: errors.map(serializeError),
                warnings: warnings.map(serializeError),
                usage,
                executionReport,
                outputParameters,
                preparedPipeline,
            },
        });
    }

    /**
     * Creates executor function from pipeline and execution tools.
     *
     * @returns The executor function
     * @throws {PipelineLogicError} on logical error in the pipeline
     * @public exported from `@promptbook/core`
     */
    function createPipelineExecutor(options) {
        const { pipeline, tools, maxExecutionAttempts = DEFAULT_MAX_EXECUTION_ATTEMPTS, maxParallelCount = DEFAULT_MAX_PARALLEL_COUNT, csvSettings = DEFAULT_CSV_SETTINGS, isVerbose = DEFAULT_IS_VERBOSE, isNotPreparedWarningSupressed = false, cacheDirname = DEFAULT_SCRAPE_CACHE_DIRNAME, intermediateFilesStrategy = DEFAULT_INTERMEDIATE_FILES_STRATEGY, isAutoInstalled = DEFAULT_IS_AUTO_INSTALLED, rootDirname = null, } = options;
        validatePipeline(pipeline);
        const pipelineIdentification = (() => {
            // Note: This is a 😐 implementation of [🚞]
            const _ = [];
            if (pipeline.sourceFile !== undefined) {
                _.push(`File: ${pipeline.sourceFile}`);
            }
            if (pipeline.pipelineUrl !== undefined) {
                _.push(`Url: ${pipeline.pipelineUrl}`);
            }
            return _.join('\n');
        })();
        let preparedPipeline;
        if (isPipelinePrepared(pipeline)) {
            preparedPipeline = pipeline;
        }
        else if (isNotPreparedWarningSupressed !== true) {
            console.warn(spaceTrim.spaceTrim((block) => `
                    Pipeline is not prepared

                    ${block(pipelineIdentification)}

                    It will be prepared ad-hoc before the first execution and **returned as \`preparedPipeline\` in \`PipelineExecutorResult\`**
                    But it is recommended to prepare the pipeline during collection preparation

                    @see more at https://ptbk.io/prepare-pipeline
                `));
            // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
        }
        let runCount = 0;
        const pipelineExecutorWithCallback = async (inputParameters, onProgress) => {
            runCount++;
            return /* not await */ executePipeline({
                pipeline,
                preparedPipeline,
                setPreparedPipeline: (newPreparedPipeline) => {
                    preparedPipeline = newPreparedPipeline;
                },
                inputParameters,
                tools,
                onProgress,
                pipelineIdentification: spaceTrim.spaceTrim((block) => `
                    ${block(pipelineIdentification)}
                    ${runCount === 1 ? '' : `Run #${runCount}`}
                `),
                maxExecutionAttempts,
                maxParallelCount,
                csvSettings,
                isVerbose,
                isNotPreparedWarningSupressed,
                rootDirname,
                cacheDirname,
                intermediateFilesStrategy,
                isAutoInstalled,
            });
        };
        const pipelineExecutor = (inputParameters) => createTask({
            taskType: 'EXECUTION',
            taskProcessCallback(updateOngoingResult) {
                return pipelineExecutorWithCallback(inputParameters, async (newOngoingResult) => {
                    updateOngoingResult(newOngoingResult);
                });
            },
        });
        //        <- TODO: Make types such as there is no need to do `as` for `createTask`
        return pipelineExecutor;
    }

    /**
     * Metadata of the scraper
     *
     * @private within the scraper directory
     */
    const markdownScraperMetadata = $deepFreeze({
        title: 'Markdown scraper',
        packageName: '@promptbook/markdown-utils',
        className: 'MarkdownScraper',
        mimeTypes: ['text/markdown', 'text/plain'],
        documentationUrl: 'https://github.com/webgptorg/promptbook/discussions/@@',
        isAvilableInBrowser: true,
        // <- Note: [🌏] This is the only scraper which makes sense to be available in the browser, for scraping non-markdown sources in the browser use a remote server
        requiredExecutables: [],
    }); /* <- Note: [🤛] */
    /**
     * Registration of known scraper metadata
     *
     * Warning: This is not useful for the end user, it is just a side effect of the mechanism that handles all available known scrapers
     *
     * @public exported from `@promptbook/core`
     * @public exported from `@promptbook/wizzard`
     * @public exported from `@promptbook/cli`
     */
    $scrapersMetadataRegister.register(markdownScraperMetadata);
    /**
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Scraper for markdown files
     *
     * @see `documentationUrl` for more details
     * @public exported from `@promptbook/markdown-utils`
     */
    class MarkdownScraper {
        /**
         * Metadata of the scraper which includes title, mime types, etc.
         */
        get metadata() {
            return markdownScraperMetadata;
        }
        constructor(tools, options) {
            this.tools = tools;
            this.options = options;
        }
        /**
         * Scrapes the markdown file and returns the knowledge pieces or `null` if it can't scrape it
         */
        async scrape(source) {
            const { maxParallelCount = DEFAULT_MAX_PARALLEL_COUNT, isVerbose = DEFAULT_IS_VERBOSE } = this.options;
            const { llm } = this.tools;
            if (llm === undefined) {
                throw new MissingToolsError('LLM tools are required for scraping external files');
                // <- Note: This scraper is used in all other scrapers, so saying "external files" not "markdown files"
            }
            // TODO: [🚐] Make arrayable LLMs -> single LLM DRY
            const _llms = arrayableToArray(llm);
            const llmTools = _llms.length === 1 ? _llms[0] : joinLlmExecutionTools(..._llms);
            // TODO: [🌼] In future use `ptbk make` and made getPipelineCollection
            const collection = createCollectionFromJson(...PipelineCollection);
            const prepareKnowledgeFromMarkdownExecutor = createPipelineExecutor({
                pipeline: await collection.getPipelineByUrl('https://promptbook.studio/promptbook/prepare-knowledge-from-markdown.book'),
                tools: {
                    llm: llm,
                },
            });
            const prepareTitleExecutor = createPipelineExecutor({
                pipeline: await collection.getPipelineByUrl('https://promptbook.studio/promptbook/prepare-knowledge-title.book'),
                tools: {
                    llm: llm,
                },
            });
            const prepareKeywordsExecutor = createPipelineExecutor({
                pipeline: await collection.getPipelineByUrl('https://promptbook.studio/promptbook/prepare-knowledge-keywords.book'),
                tools: {
                    llm: llm,
                },
            });
            const knowledgeContent = await source.asText();
            const result = await prepareKnowledgeFromMarkdownExecutor({ knowledgeContent }).asPromise();
            const { outputParameters } = result;
            const { knowledgePieces: knowledgePiecesRaw } = outputParameters;
            const knowledgeTextPieces = (knowledgePiecesRaw || '').split('\n---\n');
            //                                                               <- TODO: [main] Smarter split and filter out empty pieces
            if (isVerbose) {
                console.info('knowledgeTextPieces:', knowledgeTextPieces);
            }
            // const usage = ;
            const knowledge = await Promise.all(
            // TODO: [🪂] Do not send all at once but in chunks
            knowledgeTextPieces.map(async (knowledgeTextPiece, i) => {
                // Note: Theese are just default values, they will be overwritten by the actual values:
                let name = `piece-${i}`;
                let title = spaceTrim__default["default"](knowledgeTextPiece.substring(0, 100));
                const knowledgePieceContent = spaceTrim__default["default"](knowledgeTextPiece);
                let keywords = [];
                const index = [];
                /*
              TODO: [☀] Track line and column of the source
              const sources: KnowledgePiecePreparedJson['sources'] = [
              ];
              */
                try {
                    const titleResult = await prepareTitleExecutor({ knowledgePieceContent }).asPromise();
                    const { title: titleRaw = 'Untitled' } = titleResult.outputParameters;
                    title = spaceTrim__default["default"](titleRaw) /* <- TODO: Maybe do in pipeline */;
                    name = titleToName(title);
                    // --- Keywords
                    const keywordsResult = await prepareKeywordsExecutor({ knowledgePieceContent }).asPromise();
                    const { keywords: keywordsRaw = '' } = keywordsResult.outputParameters;
                    keywords = (keywordsRaw || '')
                        .split(',')
                        .map((keyword) => keyword.trim())
                        .filter((keyword) => keyword !== '');
                    if (isVerbose) {
                        console.info(`Keywords for "${title}":`, keywords);
                    }
                    // ---
                    if (!llmTools.callEmbeddingModel) {
                        // TODO: [🟥] Detect browser / node and make it colorfull
                        console.error('No callEmbeddingModel function provided');
                    }
                    else {
                        // TODO: [🧠][🎛] Embedding via multiple models
                        const embeddingResult = await llmTools.callEmbeddingModel({
                            title: `Embedding for ${title}` /* <- Note: No impact on embedding result itself, just for logging */,
                            parameters: {},
                            content: knowledgePieceContent,
                            modelRequirements: {
                                modelVariant: 'EMBEDDING',
                            },
                        });
                        index.push({
                            modelName: embeddingResult.modelName,
                            position: [...embeddingResult.content],
                            // <- TODO: [🪓] Here should be no need for spreading new array, just `position: embeddingResult.content`
                        });
                    }
                }
                catch (error) {
                    // Note: Here is expected error:
                    //     > PipelineExecutionError: You have not provided any `LlmExecutionTools` that support model variant "EMBEDDING
                    if (!(error instanceof PipelineExecutionError)) {
                        throw error;
                    }
                    // TODO: [🟥] Detect browser / node and make it colorfull
                    console.error(error, "<- Note: This error is not critical to prepare the pipeline, just knowledge pieces won't have embeddings");
                }
                return {
                    name,
                    title,
                    content: knowledgePieceContent,
                    keywords,
                    index,
                    // <- TODO: [☀] sources,
                };
            }));
            return knowledge;
        }
    }
    /**
     * TODO: [🪂] Do it in parallel 11:11
     * Note: No need to aggregate usage here, it is done by intercepting the llmTools
     */

    /**
     * @@@
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    const createMarkdownScraper = Object.assign((tools, options) => {
        return new MarkdownScraper(tools, options);
    }, markdownScraperMetadata); /* <- Note: [🤛] */
    /**
     * TODO: [🎶] Naming "constructor" vs "creator" vs "factory"
     */

    /**
     * Registration of known scraper
     *
     * Warning: This is not useful for the end user, it is just a side effect of the mechanism that handles all available known scrapers
     *
     * @public exported from `@promptbook/markdown-utils`
     * @public exported from `@promptbook/wizzard`
     * @public exported from `@promptbook/cli`
     */
    const _MarkdownScraperRegistration = $scrapersRegister.register(createMarkdownScraper);
    /**
     * TODO: [🎶] Naming "constructor" vs "creator" vs "factory"
     * Note: [💞] Ignore a discrepancy between file name and entity name
     */

    /**
     * Removes Markdown (or HTML) comments
     *
     * @param {string} content - The string to remove comments from.
     * @returns {string} The input string with all comments removed.
     * @public exported from `@promptbook/markdown-utils`
     */
    function removeMarkdownComments(content) {
        return spaceTrim.spaceTrim(content.replace(/<!--(.*?)-->/gs, ''));
    }

    /**
     * Add or modify an auto-generated section in a markdown file
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function addAutoGeneratedSection(content, options) {
        const { sectionName, sectionContent } = options;
        const warningLine = `<!-- ${GENERATOR_WARNING} -->`;
        const sectionRegex = new RegExp(`<!--${sectionName}-->([\\s\\S]*?)<!--/${sectionName}-->`, 'g');
        const sectionMatch = content.match(sectionRegex);
        const contentToInsert = spaceTrim.spaceTrim((block) => `
            <!--${sectionName}-->
            ${block(warningLine)}
            ${block(sectionContent)}
            <!--/${sectionName}-->
        `);
        if (sectionMatch) {
            return content.replace(sectionRegex, contentToInsert);
        }
        // Note: Following is the case when the section is not found in the file so we add it there
        const placeForSection = removeMarkdownComments(content).match(/^##.*$/im);
        if (placeForSection !== null) {
            const [heading] = placeForSection;
            return content.replace(heading, spaceTrim.spaceTrim((block) => `
                    ${block(contentToInsert)}

                    ${block(heading)}
                `));
        }
        console.warn(`No place where to put the section <!--${sectionName}-->, using the end of the file`);
        // <- TODO: [🏮] Some standard way how to transform errors into warnings and how to handle non-critical fails during the tasks
        // <- TODO: [🏮] Some better way how to get warnings from pipeline parsing / logic
        return spaceTrim.spaceTrim((block) => `
            ${block(content)}

            ${block(contentToInsert)}
        `);
    }
    /**
     * TODO: [🏛] This can be part of markdown builder
     */

    /**
     * Create a markdown table from a 2D array of strings
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function createMarkdownTable(table) {
        const columnWidths = table.reduce((widths, row) => {
            row.forEach((subformat, columnIndex) => {
                const cellLength = subformat.length;
                if (!widths[columnIndex] || cellLength > widths[columnIndex]) {
                    widths[columnIndex] = cellLength;
                }
            });
            return widths;
        }, []);
        const header = `| ${table[0]
        .map((subformat, columnIndex) => subformat.padEnd(columnWidths[columnIndex]))
        .join(' | ')} |`;
        const separator = `|${columnWidths.map((width) => '-'.repeat(width + 2)).join('|')}|`;
        const rows = table.slice(1).map((row) => {
            const paddedRow = row.map((subformat, columnIndex) => subformat.padEnd(columnWidths[columnIndex]));
            return `| ${paddedRow.join(' | ')} |`;
        });
        return [header, separator, ...rows].join('\n');
    }
    /**
     * TODO: [🏛] This can be part of markdown builder
     */

    /**
     * Function createMarkdownChart will draw a chart in markdown from ⬛+🟦 tiles
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function createMarkdownChart(options) {
        const { nameHeader, valueHeader, items, width, unitName } = options;
        const from = Math.min(...items.map((item) => item.from));
        const to = Math.max(...items.map((item) => item.to));
        const scale = width / (to - from);
        const table = [[nameHeader, valueHeader]];
        for (const item of items) {
            const before = Math.round((item.from - from) * scale);
            const during = Math.round((item.to - item.from) * scale);
            const after = width - before - during;
            table.push([removeEmojis(item.title).trim(), '░'.repeat(before) + '█'.repeat(during) + '░'.repeat(after)]);
        }
        const legend = `_Note: Each █ represents ${numberToString(1 / scale)} ${unitName}, width of ${valueHeader.toLowerCase()} is ${numberToString(to - from)} ${unitName} = ${width} squares_`;
        return createMarkdownTable(table) + '\n\n' + legend;
    }
    /**
     * TODO: Maybe use Mermain Gant Diagrams
     *       @see https://jojozhuang.github.io/tutorial/mermaid-cheat-sheet/
     */

    /**
     * Function escapeMarkdownBlock will escape markdown block if needed
     * It is useful when you want have block in block
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function escapeMarkdownBlock(value) {
        return value.replace(/```/g, '\\`\\`\\`');
    }
    /**
     * TODO: [🏛] This can be part of markdown builder
     */

    /**
     * Utility function to extract all list items from markdown
     *
     * Note: It works with both ul and ol
     * Note: It omits list items in code blocks
     * Note: It flattens nested lists
     * Note: It can not work with html syntax and comments
     *
     * @param markdown any valid markdown
     * @returns @@@
     * @public exported from `@promptbook/markdown-utils`
     */
    function extractAllListItemsFromMarkdown(markdown) {
        const lines = markdown.split('\n');
        const listItems = [];
        let isInCodeBlock = false;
        for (const line of lines) {
            const trimmedLine = line.trim();
            if (trimmedLine.startsWith('```')) {
                isInCodeBlock = !isInCodeBlock;
            }
            if (!isInCodeBlock && (trimmedLine.startsWith('-') || trimmedLine.match(/^\d+\./))) {
                const listItem = trimmedLine.replace(/^-|\d+\./, '').trim();
                listItems.push(listItem);
            }
        }
        return listItems;
    }

    /**
     * Parses markdown section to title its level and content
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function parseMarkdownSection(value) {
        var _a, _b;
        const lines = value.split('\n');
        if (!lines[0].startsWith('#')) {
            throw new ParseError('Markdown section must start with heading');
        }
        const title = lines[0].replace(/^#+\s*/, '');
        const level = (_b = (_a = lines[0].match(/^#+/)) === null || _a === void 0 ? void 0 : _a[0].length) !== null && _b !== void 0 ? _b : 0;
        const content = spaceTrim__default["default"](lines.slice(1).join('\n'));
        if (level < 1 || level > 6) {
            throw new ParseError('Markdown section must have heading level between 1 and 6');
        }
        return { title, level: level, content };
    }
    /**
     * Note: [🕞] In past (commit 42086e1603cbed506482997c00a8ee979af0a247) there was much more
     *       sophisticated implementation of this function through parsing markdown into JSON structure
     *       and flattening the actual structure
     *       NOW we are working just with markdown string and its good enough
     */

    /**
     * Splits the markdown into sections by headings
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function splitMarkdownIntoSections(markdown) {
        const lines = markdown.split('\n');
        const sections = [];
        // TODO: [🧽] DRY
        let currentType = 'MARKDOWN';
        let buffer = [];
        const finishSection = () => {
            if (buffer.length === 0) {
                return;
            }
            let section = spaceTrim__default["default"](buffer.join('\n'));
            if (section === '') {
                return;
            }
            if (!section.startsWith('#')) {
                section = `# ${DEFAULT_BOOK_TITLE}\n\n${section}`;
            }
            sections.push(section);
            buffer = [];
        };
        for (const line of lines) {
            if (currentType === 'MARKDOWN') {
                if (line.startsWith('#')) {
                    finishSection();
                }
                buffer.push(line);
                if (line.startsWith('```')) {
                    currentType = 'CODE_BLOCK';
                }
                else if (line.includes('<!--')) {
                    currentType = 'COMMENT';
                }
            }
            else if (currentType === 'CODE_BLOCK') {
                buffer.push(line);
                if (line.startsWith('```')) {
                    currentType = 'MARKDOWN';
                }
            }
            else if (currentType === 'COMMENT') {
                buffer.push(line);
                if (line.includes('-->')) {
                    currentType = 'MARKDOWN';
                }
            }
        }
        finishSection();
        return sections;
    }
    /**
     * TODO: [🏛] This can be part of markdown builder
     * Note: [🕞] In past (commit 42086e1603cbed506482997c00a8ee979af0a247) there was much more
     *       sophisticated implementation of this function through parsing markdown into JSON structure
     *       and flattening the actual structure
     *       NOW we are working just with markdown string and its good enough
     */

    /**
     * Normalizes the markdown by flattening the structure
     *
     * - It always have h1 - if there is no h1 in the markdown, it will be added `DEFAULT_BOOK_TITLE`
     * - All other headings are normalized to h2
     *
     * @public exported from `@promptbook/markdown-utils`
     */
    function flattenMarkdown(markdown) {
        const sections = splitMarkdownIntoSections(markdown);
        if (sections.length === 0) {
            return `# ${DEFAULT_BOOK_TITLE}`;
        }
        let flattenedMarkdown = '';
        const parsedSections = sections.map(parseMarkdownSection);
        const firstSection = parsedSections.shift();
        if (firstSection.level === 1) {
            flattenedMarkdown += `# ${firstSection.title}` + `\n\n`;
            flattenedMarkdown += firstSection.content + `\n\n`; // <- [🧠] Maybe 3 new lines?
        }
        else {
            parsedSections.unshift(firstSection);
            flattenedMarkdown += `# ${DEFAULT_BOOK_TITLE}` + `\n\n`; // <- [🧠] Maybe 3 new lines?
        }
        for (const { title, content } of parsedSections) {
            flattenedMarkdown += `## ${title}` + `\n\n`;
            flattenedMarkdown += content + `\n\n`; // <- [🧠] Maybe 3 new lines?
        }
        return spaceTrim__default["default"](flattenedMarkdown);
    }
    /**
     * TODO: [🏛] This can be part of markdown builder
     * Note: [🕞] In past (commit 42086e1603cbed506482997c00a8ee979af0a247) there was much more
     *       sophisticated implementation of this function through parsing markdown into JSON structure
     *       and flattening the actual structure
     *       NOW we are working just with markdown string and its good enough
     */

    /**
     * Removes Markdown formatting tags from a string.
     *
     * @param {string} str - The string to remove Markdown tags from.
     * @returns {string} The input string with all Markdown tags removed.
     * @public exported from `@promptbook/markdown-utils`
     */
    function removeMarkdownFormatting(str) {
        // Remove bold formatting
        str = str.replace(/\*\*(.*?)\*\*/g, '$1');
        // Remove italic formatting
        str = str.replace(/\*(.*?)\*/g, '$1');
        // Remove code formatting
        str = str.replace(/`(.*?)`/g, '$1');
        return str;
    }

    exports.BOOK_LANGUAGE_VERSION = BOOK_LANGUAGE_VERSION;
    exports.MarkdownScraper = MarkdownScraper;
    exports.PROMPTBOOK_ENGINE_VERSION = PROMPTBOOK_ENGINE_VERSION;
    exports._MarkdownScraperRegistration = _MarkdownScraperRegistration;
    exports.addAutoGeneratedSection = addAutoGeneratedSection;
    exports.createMarkdownChart = createMarkdownChart;
    exports.createMarkdownScraper = createMarkdownScraper;
    exports.createMarkdownTable = createMarkdownTable;
    exports.escapeMarkdownBlock = escapeMarkdownBlock;
    exports.extractAllBlocksFromMarkdown = extractAllBlocksFromMarkdown;
    exports.extractAllListItemsFromMarkdown = extractAllListItemsFromMarkdown;
    exports.extractBlock = extractBlock;
    exports.extractJsonBlock = extractJsonBlock;
    exports.extractOneBlockFromMarkdown = extractOneBlockFromMarkdown;
    exports.flattenMarkdown = flattenMarkdown;
    exports.parseMarkdownSection = parseMarkdownSection;
    exports.removeMarkdownComments = removeMarkdownComments;
    exports.removeMarkdownFormatting = removeMarkdownFormatting;
    exports.splitMarkdownIntoSections = splitMarkdownIntoSections;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=index.umd.js.map
